/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qrectf_wrapper.h"

// Extra includes
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRectF_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRectF >()))
        return -1;

    ::QRectF* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QRectF_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QRectF", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return -1;


    // Overloaded function decisor
    // 0: QRectF()
    // 1: QRectF(QPointF,QPointF)
    // 2: QRectF(QPointF,QSizeF)
    // 3: QRectF(QRect)
    // 4: QRectF(QRectF)
    // 5: QRectF(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QRectF()
    } else if (numArgs == 4
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        overloadId = 5; // QRectF(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QRect >::isConvertible(pyArgs[0])) {
        overloadId = 3; // QRectF(QRect)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QRectF >::isConvertible(pyArgs[0])) {
        overloadId = 4; // QRectF(QRectF)
    } else if (Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])) {
        if (numArgs == 2
            && Shiboken::Converter< ::QSizeF >::isConvertible(pyArgs[1])) {
            overloadId = 2; // QRectF(QPointF,QSizeF)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[1])) {
            overloadId = 1; // QRectF(QPointF,QPointF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectF_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QRectF()
        {

            if(!PyErr_Occurred()) {
                // QRectF()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRectF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QRectF(QPointF,QPointF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPointF cppArg1 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QRectF(QPointF,QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRectF(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QRectF(QPointF,QSizeF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QSizeF cppArg1 = Shiboken::Converter< ::QSizeF >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // QRectF(QPointF,QSizeF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRectF(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QRectF(QRect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRect cppArg0 = Shiboken::Converter< ::QRect >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QRectF(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRectF(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // QRectF(QRectF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QRectF(QRectF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRectF(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 5: // QRectF(qreal,qreal,qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
            qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
            qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);

            if(!PyErr_Occurred()) {
                // QRectF(qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRectF(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRectF >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QRectF_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QRectF_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPointF, PySide.QtCore.QPointF", "PySide.QtCore.QPointF, PySide.QtCore.QSizeF", "PySide.QtCore.QRect", "PySide.QtCore.QRectF", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF", overloads);
        return -1;
}

static PyObject* Sbk_QRectFFunc___reduce__(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __reduce__()
            // Begin code injection

            // TEMPLATE - reduce_code - START
            pyResult = Py_BuildValue("(N(dddd))", PyObject_Type(self), cppSelf->x(), cppSelf->y(), cppSelf->width(), cppSelf->height());
            // TEMPLATE - reduce_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc___repr__(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __repr__()
            // Begin code injection

            // TEMPLATE - repr_code - START
            QString format = QString().sprintf("%s(%f, %f, %f, %f)", ((PyObject*)self)->ob_type->tp_name, cppSelf->x(), cppSelf->y(), cppSelf->width(), cppSelf->height());
            pyResult = Shiboken::String::fromCString(qPrintable(format));
            // TEMPLATE - repr_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_adjust(PyObject* self, PyObject* args)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "adjust", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return 0;


    // Overloaded function decisor
    // 0: adjust(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        overloadId = 0; // adjust(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_adjust_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
        qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
        qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);

        if(!PyErr_Occurred()) {
            // adjust(qreal,qreal,qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->adjust(cppArg0, cppArg1, cppArg2, cppArg3);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_adjust_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.adjust", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_adjusted(PyObject* self, PyObject* args)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "adjusted", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return 0;


    // Overloaded function decisor
    // 0: adjusted(qreal,qreal,qreal,qreal)const
    if (numArgs == 4
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        overloadId = 0; // adjusted(qreal,qreal,qreal,qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_adjusted_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
        qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
        qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);

        if(!PyErr_Occurred()) {
            // adjusted(qreal,qreal,qreal,qreal)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRectF cppResult = const_cast<const ::QRectF*>(cppSelf)->adjusted(cppArg0, cppArg1, cppArg2, cppArg3);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc_adjusted_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.adjusted", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_bottom(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // bottom()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRectF*>(cppSelf)->bottom();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_bottomLeft(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // bottomLeft()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QRectF*>(cppSelf)->bottomLeft();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_bottomRight(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // bottomRight()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QRectF*>(cppSelf)->bottomRight();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_center(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // center()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QRectF*>(cppSelf)->center();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_contains(PyObject* self, PyObject* args)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "contains", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: contains(QPointF)const
    // 1: contains(QRectF)const
    // 2: contains(qreal,qreal)const
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 2; // contains(qreal,qreal)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QRectF >::isConvertible(pyArgs[0])) {
        overloadId = 1; // contains(QRectF)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])) {
        overloadId = 0; // contains(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_contains_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // contains(QPointF)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // contains(QPointF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const ::QRectF*>(cppSelf)->contains(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
        case 1: // contains(QRectF)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // contains(QRectF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const ::QRectF*>(cppSelf)->contains(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
        case 2: // contains(qreal,qreal)const
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // contains(qreal,qreal)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const ::QRectF*>(cppSelf)->contains(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "PySide.QtCore.QRectF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.contains", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_getCoords(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // getCoords(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection

            qreal a, b, c, d;
            cppSelf->getCoords(&a, &b, &c, &d);
            pyResult = Shiboken::makeTuple(a, b, c, d);

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_getRect(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // getRect(qreal*,qreal*,qreal*,qreal*)const
            // Begin code injection

            qreal a, b, c, d;
            cppSelf->getRect(&a, &b, &c, &d);
            pyResult = Shiboken::makeTuple(a, b, c, d);

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_height(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // height()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRectF*>(cppSelf)->height();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_intersect(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersect(QRectF)const
    if (Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // intersect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_intersect_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // intersect(QRectF)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRectF cppResult = const_cast<const ::QRectF*>(cppSelf)->intersect(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc_intersect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.intersect", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_intersected(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QRectF)const
    if (Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // intersected(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_intersected_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // intersected(QRectF)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRectF cppResult = const_cast<const ::QRectF*>(cppSelf)->intersected(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.intersected", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_intersects(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersects(QRectF)const
    if (Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // intersects(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_intersects_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // intersects(QRectF)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QRectF*>(cppSelf)->intersects(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc_intersects_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.intersects", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_isEmpty(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isEmpty()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QRectF*>(cppSelf)->isEmpty();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_isNull(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isNull()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QRectF*>(cppSelf)->isNull();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_isValid(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isValid()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QRectF*>(cppSelf)->isValid();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_left(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // left()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRectF*>(cppSelf)->left();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_moveBottom(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottom(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // moveBottom(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveBottom_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveBottom(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveBottom(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveBottom_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveBottom", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveBottomLeft(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottomLeft(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // moveBottomLeft(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveBottomLeft_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveBottomLeft(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveBottomLeft(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveBottomLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveBottomLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveBottomRight(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottomRight(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // moveBottomRight(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveBottomRight_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveBottomRight(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveBottomRight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveBottomRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveBottomRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveCenter(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveCenter(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // moveCenter(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveCenter_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveCenter(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveCenter(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveCenter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveCenter", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveLeft(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveLeft(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // moveLeft(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveLeft_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveLeft(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveLeft(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveLeft_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveRight(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveRight(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // moveRight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveRight_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveRight(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveRight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveRight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveTo(PyObject* self, PyObject* args)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "moveTo", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveTo(QPointF)
    // 1: moveTo(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 1; // moveTo(qreal,qreal)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])) {
        overloadId = 0; // moveTo(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveTo_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // moveTo(QPointF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // moveTo(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveTo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // moveTo(qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // moveTo(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveTo(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.moveTo", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveTop(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTop(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // moveTop(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveTop_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveTop(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveTop(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveTop_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveTop", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveTopLeft(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTopLeft(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // moveTopLeft(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveTopLeft_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveTopLeft(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveTopLeft(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveTopLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveTopLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_moveTopRight(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTopRight(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // moveTopRight(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_moveTopRight_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // moveTopRight(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->moveTopRight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_moveTopRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.moveTopRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_normalized(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // normalized()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRectF cppResult = const_cast<const ::QRectF*>(cppSelf)->normalized();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_right(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // right()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRectF*>(cppSelf)->right();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_setBottom(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottom(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setBottom(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setBottom_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setBottom(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBottom(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setBottom_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setBottom", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setBottomLeft(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomLeft(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // setBottomLeft(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setBottomLeft_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setBottomLeft(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBottomLeft(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setBottomLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setBottomLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setBottomRight(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomRight(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // setBottomRight(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setBottomRight_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setBottomRight(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBottomRight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setBottomRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setBottomRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setCoords(PyObject* self, PyObject* args)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCoords", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setCoords(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        overloadId = 0; // setCoords(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setCoords_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
        qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
        qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);

        if(!PyErr_Occurred()) {
            // setCoords(qreal,qreal,qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCoords(cppArg0, cppArg1, cppArg2, cppArg3);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setCoords_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.setCoords", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setHeight(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeight(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setHeight_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setHeight(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHeight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setHeight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setHeight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setLeft(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeft(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setLeft(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setLeft_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLeft(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLeft(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setLeft_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setRect(PyObject* self, PyObject* args)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRect", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])) {
        overloadId = 0; // setRect(qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setRect_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
        qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
        qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);

        if(!PyErr_Occurred()) {
            // setRect(qreal,qreal,qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setRect(cppArg0, cppArg1, cppArg2, cppArg3);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setRect_TypeError:
        const char* overloads[] = {"float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.setRect", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setRight(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRight(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setRight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setRight_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setRight(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setRight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setRight_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setSize(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSize(QSizeF)
    if (Shiboken::Converter< ::QSizeF >::isConvertible(pyArg)) {
        overloadId = 0; // setSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setSize_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QSizeF cppArg0 = Shiboken::Converter< ::QSizeF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setSize(QSizeF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setSize(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setSize", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setTop(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTop(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setTop(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setTop_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTop(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTop(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setTop_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setTop", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setTopLeft(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopLeft(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // setTopLeft(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setTopLeft_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTopLeft(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTopLeft(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setTopLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setTopLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setTopRight(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopRight(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 0; // setTopRight(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setTopRight_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTopRight(QPointF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTopRight(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setTopRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setTopRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setWidth(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setWidth_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setWidth(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setWidth(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setWidth", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setX(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setX_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setX(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setX(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setX_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setX", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_setY(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_setY_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setY(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setY(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_setY_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.setY", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_size(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // size()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSizeF cppResult = const_cast<const ::QRectF*>(cppSelf)->size();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSizeF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_toAlignedRect(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toAlignedRect()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRect cppResult = const_cast<const ::QRectF*>(cppSelf)->toAlignedRect();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_toRect(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toRect()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRect cppResult = const_cast<const ::QRectF*>(cppSelf)->toRect();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_top(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // top()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRectF*>(cppSelf)->top();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_topLeft(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // topLeft()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QRectF*>(cppSelf)->topLeft();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_topRight(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // topRight()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPointF cppResult = const_cast<const ::QRectF*>(cppSelf)->topRight();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_translate(PyObject* self, PyObject* args)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPointF)
    // 1: translate(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 1; // translate(qreal,qreal)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])) {
        overloadId = 0; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_translate_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // translate(QPointF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // translate(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->translate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // translate(qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->translate(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.translate", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_translated(PyObject* self, PyObject* args)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPointF)const
    // 1: translated(qreal,qreal)const
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 1; // translated(qreal,qreal)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])) {
        overloadId = 0; // translated(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_translated_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // translated(QPointF)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // translated(QPointF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const ::QRectF*>(cppSelf)->translated(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
            break;
        }
        case 1: // translated(qreal,qreal)const
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // translated(qreal,qreal)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const ::QRectF*>(cppSelf)->translated(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRectF.translated", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_unite(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unite(QRectF)const
    if (Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // unite(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_unite_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // unite(QRectF)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRectF cppResult = const_cast<const ::QRectF*>(cppSelf)->unite(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc_unite_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.unite", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_united(PyObject* self, PyObject* pyArg)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QRectF)const
    if (Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // united(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc_united_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // united(QRectF)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRectF cppResult = const_cast<const ::QRectF*>(cppSelf)->united(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.united", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc_width(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // width()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRectF*>(cppSelf)->width();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_x(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // x()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRectF*>(cppSelf)->x();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFFunc_y(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // y()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QRectF*>(cppSelf)->y();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectF___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QRectF& cppSelf = *(Shiboken::Converter< ::QRectF* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QRectF >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QRectF_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QRectFFunc___reduce__, METH_NOARGS},
    {"adjust", (PyCFunction)Sbk_QRectFFunc_adjust, METH_VARARGS},
    {"adjusted", (PyCFunction)Sbk_QRectFFunc_adjusted, METH_VARARGS},
    {"bottom", (PyCFunction)Sbk_QRectFFunc_bottom, METH_NOARGS},
    {"bottomLeft", (PyCFunction)Sbk_QRectFFunc_bottomLeft, METH_NOARGS},
    {"bottomRight", (PyCFunction)Sbk_QRectFFunc_bottomRight, METH_NOARGS},
    {"center", (PyCFunction)Sbk_QRectFFunc_center, METH_NOARGS},
    {"contains", (PyCFunction)Sbk_QRectFFunc_contains, METH_VARARGS},
    {"getCoords", (PyCFunction)Sbk_QRectFFunc_getCoords, METH_NOARGS},
    {"getRect", (PyCFunction)Sbk_QRectFFunc_getRect, METH_NOARGS},
    {"height", (PyCFunction)Sbk_QRectFFunc_height, METH_NOARGS},
    {"intersect", (PyCFunction)Sbk_QRectFFunc_intersect, METH_O},
    {"intersected", (PyCFunction)Sbk_QRectFFunc_intersected, METH_O},
    {"intersects", (PyCFunction)Sbk_QRectFFunc_intersects, METH_O},
    {"isEmpty", (PyCFunction)Sbk_QRectFFunc_isEmpty, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QRectFFunc_isNull, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QRectFFunc_isValid, METH_NOARGS},
    {"left", (PyCFunction)Sbk_QRectFFunc_left, METH_NOARGS},
    {"moveBottom", (PyCFunction)Sbk_QRectFFunc_moveBottom, METH_O},
    {"moveBottomLeft", (PyCFunction)Sbk_QRectFFunc_moveBottomLeft, METH_O},
    {"moveBottomRight", (PyCFunction)Sbk_QRectFFunc_moveBottomRight, METH_O},
    {"moveCenter", (PyCFunction)Sbk_QRectFFunc_moveCenter, METH_O},
    {"moveLeft", (PyCFunction)Sbk_QRectFFunc_moveLeft, METH_O},
    {"moveRight", (PyCFunction)Sbk_QRectFFunc_moveRight, METH_O},
    {"moveTo", (PyCFunction)Sbk_QRectFFunc_moveTo, METH_VARARGS},
    {"moveTop", (PyCFunction)Sbk_QRectFFunc_moveTop, METH_O},
    {"moveTopLeft", (PyCFunction)Sbk_QRectFFunc_moveTopLeft, METH_O},
    {"moveTopRight", (PyCFunction)Sbk_QRectFFunc_moveTopRight, METH_O},
    {"normalized", (PyCFunction)Sbk_QRectFFunc_normalized, METH_NOARGS},
    {"right", (PyCFunction)Sbk_QRectFFunc_right, METH_NOARGS},
    {"setBottom", (PyCFunction)Sbk_QRectFFunc_setBottom, METH_O},
    {"setBottomLeft", (PyCFunction)Sbk_QRectFFunc_setBottomLeft, METH_O},
    {"setBottomRight", (PyCFunction)Sbk_QRectFFunc_setBottomRight, METH_O},
    {"setCoords", (PyCFunction)Sbk_QRectFFunc_setCoords, METH_VARARGS},
    {"setHeight", (PyCFunction)Sbk_QRectFFunc_setHeight, METH_O},
    {"setLeft", (PyCFunction)Sbk_QRectFFunc_setLeft, METH_O},
    {"setRect", (PyCFunction)Sbk_QRectFFunc_setRect, METH_VARARGS},
    {"setRight", (PyCFunction)Sbk_QRectFFunc_setRight, METH_O},
    {"setSize", (PyCFunction)Sbk_QRectFFunc_setSize, METH_O},
    {"setTop", (PyCFunction)Sbk_QRectFFunc_setTop, METH_O},
    {"setTopLeft", (PyCFunction)Sbk_QRectFFunc_setTopLeft, METH_O},
    {"setTopRight", (PyCFunction)Sbk_QRectFFunc_setTopRight, METH_O},
    {"setWidth", (PyCFunction)Sbk_QRectFFunc_setWidth, METH_O},
    {"setX", (PyCFunction)Sbk_QRectFFunc_setX, METH_O},
    {"setY", (PyCFunction)Sbk_QRectFFunc_setY, METH_O},
    {"size", (PyCFunction)Sbk_QRectFFunc_size, METH_NOARGS},
    {"toAlignedRect", (PyCFunction)Sbk_QRectFFunc_toAlignedRect, METH_NOARGS},
    {"toRect", (PyCFunction)Sbk_QRectFFunc_toRect, METH_NOARGS},
    {"top", (PyCFunction)Sbk_QRectFFunc_top, METH_NOARGS},
    {"topLeft", (PyCFunction)Sbk_QRectFFunc_topLeft, METH_NOARGS},
    {"topRight", (PyCFunction)Sbk_QRectFFunc_topRight, METH_NOARGS},
    {"translate", (PyCFunction)Sbk_QRectFFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)Sbk_QRectFFunc_translated, METH_VARARGS},
    {"unite", (PyCFunction)Sbk_QRectFFunc_unite, METH_O},
    {"united", (PyCFunction)Sbk_QRectFFunc_united, METH_O},
    {"width", (PyCFunction)Sbk_QRectFFunc_width, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QRectFFunc_x, METH_NOARGS},
    {"y", (PyCFunction)Sbk_QRectFFunc_y, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QRectF___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QRectF___nb_bool(PyObject* self)
{
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return -1;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QRectFFunc___and__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QRectF >::checkType(pyArg)
                    && !Shiboken::Converter< ::QRectF >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QRectF)const
    if (!isReverse
        && Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // operator&(QRectF)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc___and___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator&(QRectF)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRectF cppResult = (*cppSelf) & (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.__and__", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc___iand__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QRectF >::checkType(pyArg)
                    && !Shiboken::Converter< ::QRectF >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator&=(QRectF)
    if (!isReverse
        && Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // operator&=(QRectF)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc___iand___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator&=(QRectF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            (*cppSelf) &= (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QRectFFunc___iand___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.__iand__", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc___or__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QRectF >::checkType(pyArg)
                    && !Shiboken::Converter< ::QRectF >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QRectF)const
    if (!isReverse
        && Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // operator|(QRectF)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc___or___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator|(QRectF)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRectF cppResult = (*cppSelf) | (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.__or__", overloads);
        return 0;
}

static PyObject* Sbk_QRectFFunc___ior__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QRectF >::checkType(pyArg)
                    && !Shiboken::Converter< ::QRectF >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QRectF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRectF* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QRectF)
    if (!isReverse
        && Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 0; // operator|=(QRectF)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFFunc___ior___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator|=(QRectF)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            (*cppSelf) |= (cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QRectFFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRectF.__ior__", overloads);
        return 0;
}

// Rich comparison
static PyObject* Sbk_QRectF_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QRectF& cppSelf = *(Shiboken::Converter< ::QRectF* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
                // operator!=(const QRectF & arg__2)
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
                // operator==(const QRectF & arg__2)
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QRectF_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QRectF_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QRectF_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QRectF_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QRectF_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QRectF",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QRectFFunc___repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QRectF_traverse,
    /*tp_clear*/            Sbk_QRectF_clear,
    /*tp_richcompare*/      Sbk_QRectF_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QRectF_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QRectF_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QRectF(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QRectF_Type.super.as_number, 0, sizeof(PyNumberMethods));
    Sbk_QRectF_Type.super.as_number.nb_inplace_or = Sbk_QRectFFunc___ior__;
    Sbk_QRectF_Type.super.as_number.nb_or = Sbk_QRectFFunc___or__;
    Sbk_QRectF_Type.super.as_number.nb_inplace_and = Sbk_QRectFFunc___iand__;
    Sbk_QRectF_Type.super.as_number.nb_and = Sbk_QRectFFunc___and__;
    SBK_NB_BOOL(Sbk_QRectF_Type.super.as_number) = Sbk_QRectF___nb_bool;
    Sbk_QRectF_Type.super.ht_type.tp_as_number = &Sbk_QRectF_Type.super.as_number;

    SbkPySide_QtCoreTypes[SBK_QRECTF_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QRectF_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QRectF", "QRectF",
        &Sbk_QRectF_Type, &Shiboken::callCppDestructor< ::QRectF >)) {
        return;
    }


    Shiboken::TypeResolver::createValueTypeResolver< ::QRectF >("QRectF");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QRectF >("QRectF*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QRectF >(typeid(::QRectF).name());
    qRegisterMetaType< ::QRectF >("QRectF");
}
