/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qregexp_wrapper.h"

// Extra includes
#include <QStringList>
#include <qregexp.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRegExp_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRegExp >()))
        return -1;

    ::QRegExp* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QRegExp", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return -1;


    // Overloaded function decisor
    // 0: QRegExp()
    // 1: QRegExp(QRegExp)
    // 2: QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
    if (numArgs == 0) {
        overloadId = 0; // QRegExp()
    } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
        } else if (Shiboken::Converter< ::Qt::CaseSensitivity >::isConvertible(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
            } else if (Shiboken::Converter< ::QRegExp::PatternSyntax >::isConvertible(pyArgs[2])) {
                overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
            }
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QRegExp >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QRegExp(QRegExp)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExp_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QRegExp()
        {

            if(!PyErr_Occurred()) {
                // QRegExp()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRegExp();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QRegExp(QRegExp)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRegExp cppArg0 = Shiboken::Converter< ::QRegExp >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QRegExp(QRegExp)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRegExp(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "cs");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "cs";
                    else if (Shiboken::Converter< ::Qt::CaseSensitivity >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QRegExp_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "syntax");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "syntax";
                    else if (Shiboken::Converter< ::QRegExp::PatternSyntax >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QRegExp_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
            Qt::CaseSensitivity cppArg1 = pyArgs[1] ? Shiboken::Converter< ::Qt::CaseSensitivity >::toCpp(pyArgs[1]) : Qt::CaseSensitive;
            QRegExp::PatternSyntax cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QRegExp::PatternSyntax >::toCpp(pyArgs[2]) : QRegExp::RegExp;

            if(!PyErr_Occurred()) {
                // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QRegExp(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRegExp >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QRegExp_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QRegExp_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRegExp", "unicode, PySide.QtCore.Qt.CaseSensitivity = Qt.CaseSensitive, PySide.QtCore.QRegExp.PatternSyntax = RegExp", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp", overloads);
        return -1;
}

static PyObject* Sbk_QRegExpFunc___reduce__(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __reduce__()
            // Begin code injection

            // TEMPLATE - reduce_code - START
            pyResult = Py_BuildValue("(N(sii))", PyObject_Type(self), qPrintable(cppSelf->pattern()), (int)cppSelf->caseSensitivity(), (int)cppSelf->patternSyntax());
            // TEMPLATE - reduce_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc___repr__(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __repr__()
            // Begin code injection

            // TEMPLATE - repr_code - START
            QString format = QString().sprintf("%s('%s', %i, %i)", ((PyObject*)self)->ob_type->tp_name, qPrintable(cppSelf->pattern()), (int)cppSelf->caseSensitivity(), (int)cppSelf->patternSyntax());
            pyResult = Shiboken::String::fromCString(qPrintable(format));
            // TEMPLATE - repr_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_cap(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.cap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:cap", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: cap(int)
    if (numArgs == 0) {
        overloadId = 0; // cap(int)
    } else if (SbkNumber_Check(pyArgs[0])) {
        overloadId = 0; // cap(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_cap_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "nth");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "nth";
                else if (SbkNumber_Check(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QRegExpFunc_cap_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.cap(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = pyArgs[0] ? Shiboken::Converter< int >::toCpp(pyArgs[0]) : 0;

        if(!PyErr_Occurred()) {
            // cap(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = cppSelf->cap(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_cap_TypeError:
        const char* overloads[] = {"int = 0", "int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.cap", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_captureCount(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // captureCount()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QRegExp*>(cppSelf)->captureCount();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_capturedTexts(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // capturedTexts()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = cppSelf->capturedTexts();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_caseSensitivity(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // caseSensitivity()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Qt::CaseSensitivity cppResult = const_cast<const ::QRegExp*>(cppSelf)->caseSensitivity();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Qt::CaseSensitivity >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_errorString(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // errorString()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = cppSelf->errorString();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_escape(PyObject* self, PyObject* pyArg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: escape(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // escape(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_escape_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // escape(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = QRegExp::escape(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_escape_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRegExp.escape", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_exactMatch(PyObject* self, PyObject* pyArg)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: exactMatch(QString)const
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // exactMatch(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_exactMatch_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // exactMatch(QString)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QRegExp*>(cppSelf)->exactMatch(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_exactMatch_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRegExp.exactMatch", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_indexIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:indexIn", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: indexIn(QString,int,QRegExp::CaretMode)const
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
        } else if (SbkNumber_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
            } else if (Shiboken::Converter< ::QRegExp::CaretMode >::isConvertible(pyArgs[2])) {
                overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_indexIn_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "offset");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "offset";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QRegExpFunc_indexIn_TypeError;
            }
            value = PyDict_GetItemString(kwds, "caretMode");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "caretMode";
                else if (Shiboken::Converter< ::QRegExp::CaretMode >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QRegExpFunc_indexIn_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : 0;
        QRegExp::CaretMode cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QRegExp::CaretMode >::toCpp(pyArgs[2]) : QRegExp::CaretAtZero;

        if(!PyErr_Occurred()) {
            // indexIn(QString,int,QRegExp::CaretMode)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QRegExp*>(cppSelf)->indexIn(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_indexIn_TypeError:
        const char* overloads[] = {"unicode, int = 0, PySide.QtCore.QRegExp.CaretMode = CaretAtZero", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.indexIn", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_isEmpty(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isEmpty()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QRegExp*>(cppSelf)->isEmpty();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_isMinimal(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isMinimal()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QRegExp*>(cppSelf)->isMinimal();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_isValid(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isValid()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QRegExp*>(cppSelf)->isValid();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_lastIndexIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:lastIndexIn", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexIn(QString,int,QRegExp::CaretMode)const
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
        } else if (SbkNumber_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
            } else if (Shiboken::Converter< ::QRegExp::CaretMode >::isConvertible(pyArgs[2])) {
                overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_lastIndexIn_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "offset");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "offset";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QRegExpFunc_lastIndexIn_TypeError;
            }
            value = PyDict_GetItemString(kwds, "caretMode");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "caretMode";
                else if (Shiboken::Converter< ::QRegExp::CaretMode >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QRegExpFunc_lastIndexIn_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : -1;
        QRegExp::CaretMode cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QRegExp::CaretMode >::toCpp(pyArgs[2]) : QRegExp::CaretAtZero;

        if(!PyErr_Occurred()) {
            // lastIndexIn(QString,int,QRegExp::CaretMode)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QRegExp*>(cppSelf)->lastIndexIn(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_lastIndexIn_TypeError:
        const char* overloads[] = {"unicode, int = -1, PySide.QtCore.QRegExp.CaretMode = CaretAtZero", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.lastIndexIn", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_matchedLength(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // matchedLength()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QRegExp*>(cppSelf)->matchedLength();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_numCaptures(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // numCaptures()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QRegExp*>(cppSelf)->numCaptures();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_pattern(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // pattern()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QRegExp*>(cppSelf)->pattern();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_patternSyntax(PyObject* self)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // patternSyntax()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRegExp::PatternSyntax cppResult = const_cast<const ::QRegExp*>(cppSelf)->patternSyntax();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRegExp::PatternSyntax >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_pos(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.pos(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:pos", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: pos(int)
    if (numArgs == 0) {
        overloadId = 0; // pos(int)
    } else if (SbkNumber_Check(pyArgs[0])) {
        overloadId = 0; // pos(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_pos_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "nth");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "nth";
                else if (SbkNumber_Check(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QRegExpFunc_pos_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.pos(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = pyArgs[0] ? Shiboken::Converter< int >::toCpp(pyArgs[0]) : 0;

        if(!PyErr_Occurred()) {
            // pos(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = cppSelf->pos(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_pos_TypeError:
        const char* overloads[] = {"int = 0", "int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.pos", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_replace(PyObject* self, PyObject* args)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(QString,QString)
    if (numArgs == 2
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
        overloadId = 0; // replace(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_replace_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        SBK_UNUSED(cppArg0)
        ::QString cppArg1 = Shiboken::Converter< ::QString >::toCpp(pyArgs[1]);
        SBK_UNUSED(cppArg1)

        if(!PyErr_Occurred()) {
            // replace(QString,QString)
            // Begin code injection

            cppArg0.replace(*cppSelf, cppArg1);
            pyResult = Shiboken::Converter< ::QString >::toPython(cppArg0);

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_replace_TypeError:
        const char* overloads[] = {"unicode, unicode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.replace", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_setCaseSensitivity(PyObject* self, PyObject* pyArg)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCaseSensitivity(Qt::CaseSensitivity)
    if (Shiboken::Converter< ::Qt::CaseSensitivity >::isConvertible(pyArg)) {
        overloadId = 0; // setCaseSensitivity(Qt::CaseSensitivity)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_setCaseSensitivity_TypeError;

    // Call function/method
    {
        Qt::CaseSensitivity cppArg0 = Shiboken::Converter< ::Qt::CaseSensitivity >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setCaseSensitivity(Qt::CaseSensitivity)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setCaseSensitivity(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_setCaseSensitivity_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.CaseSensitivity", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRegExp.setCaseSensitivity", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_setMinimal(PyObject* self, PyObject* pyArg)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimal(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setMinimal(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_setMinimal_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setMinimal(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setMinimal(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_setMinimal_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRegExp.setMinimal", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_setPattern(PyObject* self, PyObject* pyArg)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPattern(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setPattern(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_setPattern_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setPattern(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPattern(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_setPattern_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRegExp.setPattern", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_setPatternSyntax(PyObject* self, PyObject* pyArg)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPatternSyntax(QRegExp::PatternSyntax)
    if (Shiboken::Converter< ::QRegExp::PatternSyntax >::isConvertible(pyArg)) {
        overloadId = 0; // setPatternSyntax(QRegExp::PatternSyntax)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_setPatternSyntax_TypeError;

    // Call function/method
    {
        QRegExp::PatternSyntax cppArg0 = Shiboken::Converter< ::QRegExp::PatternSyntax >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setPatternSyntax(QRegExp::PatternSyntax)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPatternSyntax(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_setPatternSyntax_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRegExp.PatternSyntax", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRegExp.setPatternSyntax", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_swap(PyObject* self, PyObject* pyArg)
{
    ::QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QRegExp* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: swap(QRegExp&)
    if (Shiboken::Converter< ::QRegExp & >::isConvertible(pyArg)) {
        overloadId = 0; // swap(QRegExp&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_swap_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QRegExp & cppArg0 = Shiboken::Converter< ::QRegExp & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // swap(QRegExp&)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->swap(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_swap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRegExp", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QRegExp.swap", overloads);
        return 0;
}

static PyObject* Sbk_QRegExp___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QRegExp& cppSelf = *(Shiboken::Converter< ::QRegExp* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QRegExp >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QRegExp_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QRegExpFunc___reduce__, METH_NOARGS},
    {"cap", (PyCFunction)Sbk_QRegExpFunc_cap, METH_VARARGS|METH_KEYWORDS},
    {"captureCount", (PyCFunction)Sbk_QRegExpFunc_captureCount, METH_NOARGS},
    {"capturedTexts", (PyCFunction)Sbk_QRegExpFunc_capturedTexts, METH_NOARGS},
    {"caseSensitivity", (PyCFunction)Sbk_QRegExpFunc_caseSensitivity, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QRegExpFunc_errorString, METH_NOARGS},
    {"escape", (PyCFunction)Sbk_QRegExpFunc_escape, METH_O|METH_STATIC},
    {"exactMatch", (PyCFunction)Sbk_QRegExpFunc_exactMatch, METH_O},
    {"indexIn", (PyCFunction)Sbk_QRegExpFunc_indexIn, METH_VARARGS|METH_KEYWORDS},
    {"isEmpty", (PyCFunction)Sbk_QRegExpFunc_isEmpty, METH_NOARGS},
    {"isMinimal", (PyCFunction)Sbk_QRegExpFunc_isMinimal, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QRegExpFunc_isValid, METH_NOARGS},
    {"lastIndexIn", (PyCFunction)Sbk_QRegExpFunc_lastIndexIn, METH_VARARGS|METH_KEYWORDS},
    {"matchedLength", (PyCFunction)Sbk_QRegExpFunc_matchedLength, METH_NOARGS},
    {"numCaptures", (PyCFunction)Sbk_QRegExpFunc_numCaptures, METH_NOARGS},
    {"pattern", (PyCFunction)Sbk_QRegExpFunc_pattern, METH_NOARGS},
    {"patternSyntax", (PyCFunction)Sbk_QRegExpFunc_patternSyntax, METH_NOARGS},
    {"pos", (PyCFunction)Sbk_QRegExpFunc_pos, METH_VARARGS|METH_KEYWORDS},
    {"replace", (PyCFunction)Sbk_QRegExpFunc_replace, METH_VARARGS},
    {"setCaseSensitivity", (PyCFunction)Sbk_QRegExpFunc_setCaseSensitivity, METH_O},
    {"setMinimal", (PyCFunction)Sbk_QRegExpFunc_setMinimal, METH_O},
    {"setPattern", (PyCFunction)Sbk_QRegExpFunc_setPattern, METH_O},
    {"setPatternSyntax", (PyCFunction)Sbk_QRegExpFunc_setPatternSyntax, METH_O},
    {"swap", (PyCFunction)Sbk_QRegExpFunc_swap, METH_O},

    {"__copy__", (PyCFunction)Sbk_QRegExp___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QRegExp_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QRegExp& cppSelf = *(Shiboken::Converter< ::QRegExp* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QRegExp >::isConvertible(pyArg)) {
                // operator!=(const QRegExp & rx) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QRegExp cppArg0 = Shiboken::Converter< ::QRegExp >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QRegExp >::isConvertible(pyArg)) {
                // operator==(const QRegExp & rx) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QRegExp cppArg0 = Shiboken::Converter< ::QRegExp >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QRegExp_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QRegExp_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QRegExp_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QRegExp_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QRegExp_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QRegExp",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QRegExpFunc___repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QRegExp_traverse,
    /*tp_clear*/            Sbk_QRegExp_clear,
    /*tp_richcompare*/      Sbk_QRegExp_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QRegExp_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QRegExp_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QRegExp(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QREGEXP_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QRegExp_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QRegExp", "QRegExp",
        &Sbk_QRegExp_Type, &Shiboken::callCppDestructor< ::QRegExp >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'PatternSyntax'.
    SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QRegExp_Type,
        "PatternSyntax",
        "PySide.QtCore.QRegExp.PatternSyntax",
        "QRegExp::PatternSyntax");
    if (!SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX],
        &Sbk_QRegExp_Type, "RegExp", (long) QRegExp::RegExp))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX],
        &Sbk_QRegExp_Type, "Wildcard", (long) QRegExp::Wildcard))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX],
        &Sbk_QRegExp_Type, "FixedString", (long) QRegExp::FixedString))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX],
        &Sbk_QRegExp_Type, "RegExp2", (long) QRegExp::RegExp2))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX],
        &Sbk_QRegExp_Type, "WildcardUnix", (long) QRegExp::WildcardUnix))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX],
        &Sbk_QRegExp_Type, "W3CXmlSchema11", (long) QRegExp::W3CXmlSchema11))
        return ;
    // End of 'PatternSyntax' enum.

    // Initialization of enum 'CaretMode'.
    SbkPySide_QtCoreTypes[SBK_QREGEXP_CARETMODE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QRegExp_Type,
        "CaretMode",
        "PySide.QtCore.QRegExp.CaretMode",
        "QRegExp::CaretMode");
    if (!SbkPySide_QtCoreTypes[SBK_QREGEXP_CARETMODE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_CARETMODE_IDX],
        &Sbk_QRegExp_Type, "CaretAtZero", (long) QRegExp::CaretAtZero))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_CARETMODE_IDX],
        &Sbk_QRegExp_Type, "CaretAtOffset", (long) QRegExp::CaretAtOffset))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QREGEXP_CARETMODE_IDX],
        &Sbk_QRegExp_Type, "CaretWontMatch", (long) QRegExp::CaretWontMatch))
        return ;
    // End of 'CaretMode' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QRegExp >("QRegExp");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QRegExp >("QRegExp*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QRegExp >(typeid(::QRegExp).name());
    qRegisterMetaType< ::QRegExp >("QRegExp");
    qRegisterMetaType< ::QRegExp::PatternSyntax >("QRegExp::PatternSyntax");
    qRegisterMetaType< ::QRegExp::CaretMode >("QRegExp::CaretMode");
}
