/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtcore_python.h"

#include "qsocketnotifier_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsocketnotifier.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QSocketNotifierWrapper::QSocketNotifierWrapper(int socket, QSocketNotifier::Type arg__2, QObject * parent) : QSocketNotifier(socket, arg__2, parent) {
    // ... middle
}

void QSocketNotifierWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QSocketNotifierWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QSocketNotifierWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

void QSocketNotifierWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QSocketNotifierWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QSocketNotifier::event(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QSocketNotifier.event", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
    return cppResult;
}

bool QSocketNotifierWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidateArg2 = PyTuple_GET_ITEM(pyArgs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QSocketNotifier.eventFilter", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
    return cppResult;
}

void QSocketNotifierWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidateArg1 = PyTuple_GET_ITEM(pyArgs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
}

const QMetaObject* QSocketNotifierWrapper::metaObject() const
{
    #if QT_VERSION >= 0x040700
    if (QObject::d_ptr->metaObject) return QObject::d_ptr->metaObject;
    #endif
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return PySide::SignalManager::retriveMetaObject(reinterpret_cast<PyObject*>(pySelf));
}

int QSocketNotifierWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QSocketNotifier::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void* QSocketNotifierWrapper::qt_metacast(const char* _clname)
{
        if (!_clname) return 0;
        SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void*>(const_cast< QSocketNotifierWrapper* >(this));
        return QSocketNotifier::qt_metacast(_clname);
}

QSocketNotifierWrapper::~QSocketNotifierWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSocketNotifier_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSocketNotifier >()))
        return -1;

    ::QSocketNotifierWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSocketNotifier(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QSocketNotifier", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return -1;


    // Overloaded function decisor
    // 0: QSocketNotifier(PyObject*,QSocketNotifier::Type,QObject*)
    // 1: QSocketNotifier(int,QSocketNotifier::Type,QObject*)
    if (numArgs >= 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QSocketNotifier::Type >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QSocketNotifier(int,QSocketNotifier::Type,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[2])) {
            overloadId = 1; // QSocketNotifier(int,QSocketNotifier::Type,QObject*)
        }
    } else if (numArgs >= 2
        && PyObject_Check(pyArgs[0])
        && Shiboken::Converter< ::QSocketNotifier::Type >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // QSocketNotifier(PyObject*,QSocketNotifier::Type,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[2])) {
            overloadId = 0; // QSocketNotifier(PyObject*,QSocketNotifier::Type,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSocketNotifier_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QSocketNotifier(PyObject*,QSocketNotifier::Type,QObject*)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QSocketNotifier_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSocketNotifier(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QSocketNotifier::Type cppArg1 = Shiboken::Converter< ::QSocketNotifier::Type >::toCpp(pyArgs[1]);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject * cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[2]) : 0;
            SBK_UNUSED(cppArg2)

            if(!PyErr_Occurred()) {
                // QSocketNotifier(PyObject*,QSocketNotifier::Type,QObject*)
                // Begin code injection

                Shiboken::AutoDecRef fileNo(PyObject_GetAttrString(pyArgs[1-1], "fileno"));
                if (!fileNo.isNull()) {
                    Shiboken::AutoDecRef fileNoValue(PyObject_CallObject(fileNo, 0));
                    if (PyInt_Check(fileNoValue)) {
                        int cppFileNoValue = Shiboken::Converter< int >::toCpp(fileNoValue);
                        cptr = new QSocketNotifierWrapper(cppFileNoValue, cppArg1, cppArg2);
                    }
                }

                // End of code injection

                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
        case 1: // QSocketNotifier(int,QSocketNotifier::Type,QObject*)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QSocketNotifier_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSocketNotifier(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            QSocketNotifier::Type cppArg1 = Shiboken::Converter< ::QSocketNotifier::Type >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return -1;
            ::QObject * cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[2]) : 0;

            if(!PyErr_Occurred()) {
                // QSocketNotifier(int,QSocketNotifier::Type,QObject*)
                void* addr = PySide::nextQObjectMemoryAddr();
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = addr ? new (addr) ::QSocketNotifierWrapper(cppArg0, cppArg1, cppArg2) : new ::QSocketNotifierWrapper(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyArgs[2], self);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSocketNotifier >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSocketNotifier_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QSocketNotifier_Init_TypeError:
        const char* overloads[] = {"object, PySide.QtCore.QSocketNotifier.Type, PySide.QtCore.QObject = None", "int, PySide.QtCore.QSocketNotifier.Type, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSocketNotifier", overloads);
        return -1;
}

static PyObject* Sbk_QSocketNotifierFunc_event(PyObject* self, PyObject* pyArg)
{
    ::QSocketNotifier* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSocketNotifier* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(pyArg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSocketNotifierFunc_event_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QEvent * cppArg0 = Shiboken::Converter< ::QEvent * >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // event(QEvent*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? cppSelf->::QSocketNotifier::event(cppArg0) : cppSelf->event(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSocketNotifierFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QSocketNotifier.event", overloads);
        return 0;
}

static PyObject* Sbk_QSocketNotifierFunc_isEnabled(PyObject* self)
{
    ::QSocketNotifier* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSocketNotifier* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isEnabled()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QSocketNotifier*>(cppSelf)->isEnabled();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSocketNotifierFunc_setEnabled(PyObject* self, PyObject* pyArg)
{
    ::QSocketNotifier* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSocketNotifier* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSocketNotifierFunc_setEnabled_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setEnabled(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setEnabled(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSocketNotifierFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtCore.QSocketNotifier.setEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QSocketNotifierFunc_socket(PyObject* self)
{
    ::QSocketNotifier* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSocketNotifier* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // socket()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QSocketNotifier*>(cppSelf)->socket();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSocketNotifierFunc_type(PyObject* self)
{
    ::QSocketNotifier* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSocketNotifier* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // type()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSocketNotifier::Type cppResult = const_cast<const ::QSocketNotifier*>(cppSelf)->type();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSocketNotifier::Type >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QSocketNotifier_methods[] = {
    {"event", (PyCFunction)Sbk_QSocketNotifierFunc_event, METH_O},
    {"isEnabled", (PyCFunction)Sbk_QSocketNotifierFunc_isEnabled, METH_NOARGS},
    {"setEnabled", (PyCFunction)Sbk_QSocketNotifierFunc_setEnabled, METH_O},
    {"socket", (PyCFunction)Sbk_QSocketNotifierFunc_socket, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QSocketNotifierFunc_type, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QSocketNotifier_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QSocketNotifier_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSocketNotifier_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QSocketNotifier",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QSocketNotifier_traverse,
    /*tp_clear*/            Sbk_QSocketNotifier_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSocketNotifier_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSocketNotifier_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QSocketNotifier_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QSocketNotifier*>(reinterpret_cast< ::QObject*>(cptr));
    return 0;
}


void init_QSocketNotifier(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSOCKETNOTIFIER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSocketNotifier_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QSocketNotifier", "QSocketNotifier*",
        &Sbk_QSocketNotifier_Type, &Shiboken::callCppDestructor< ::QSocketNotifier >, (SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX])) {
        return;
    }

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QSocketNotifier_Type, &Sbk_QSocketNotifier_typeDiscovery);

    // Initialization of enums.

    // Initialization of enum 'Type'.
    SbkPySide_QtCoreTypes[SBK_QSOCKETNOTIFIER_TYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QSocketNotifier_Type,
        "Type",
        "PySide.QtCore.QSocketNotifier.Type",
        "QSocketNotifier::Type");
    if (!SbkPySide_QtCoreTypes[SBK_QSOCKETNOTIFIER_TYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSOCKETNOTIFIER_TYPE_IDX],
        &Sbk_QSocketNotifier_Type, "Read", (long) QSocketNotifier::Read))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSOCKETNOTIFIER_TYPE_IDX],
        &Sbk_QSocketNotifier_Type, "Write", (long) QSocketNotifier::Write))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSOCKETNOTIFIER_TYPE_IDX],
        &Sbk_QSocketNotifier_Type, "Exception", (long) QSocketNotifier::Exception))
        return ;
    // End of 'Type' enum.

    PySide::Signal::registerSignals(&Sbk_QSocketNotifier_Type, &::QSocketNotifier::staticMetaObject);

    Shiboken::TypeResolver::createObjectTypeResolver< ::QSocketNotifier >("QSocketNotifier*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QSocketNotifier >(typeid(::QSocketNotifier).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QSocketNotifier >(typeid(::QSocketNotifierWrapper).name());
    qRegisterMetaType< ::QSocketNotifier::Type >("QSocketNotifier::Type");
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QSocketNotifier_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QSocketNotifier_Type, &::QSocketNotifier::staticMetaObject, sizeof(::QSocketNotifier));
}
