/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qsystemsemaphore_wrapper.h"

// Extra includes
#include <qsystemsemaphore.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSystemSemaphore_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSystemSemaphore >()))
        return -1;

    ::QSystemSemaphore* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSystemSemaphore(): too many arguments");
        return -1;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSystemSemaphore(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QSystemSemaphore", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return -1;


    // Overloaded function decisor
    // 0: QSystemSemaphore(QString,int,QSystemSemaphore::AccessMode)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QSystemSemaphore(QString,int,QSystemSemaphore::AccessMode)
        } else if (SbkNumber_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // QSystemSemaphore(QString,int,QSystemSemaphore::AccessMode)
            } else if (Shiboken::Converter< ::QSystemSemaphore::AccessMode >::isConvertible(pyArgs[2])) {
                overloadId = 0; // QSystemSemaphore(QString,int,QSystemSemaphore::AccessMode)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSystemSemaphore_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "initialValue");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "initialValue";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QSystemSemaphore_Init_TypeError;
            }
            value = PyDict_GetItemString(kwds, "mode");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "mode";
                else if (Shiboken::Converter< ::QSystemSemaphore::AccessMode >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QSystemSemaphore_Init_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSystemSemaphore(): got multiple values for keyword argument '%s'", errorArgName);
                return -1;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : 0;
        QSystemSemaphore::AccessMode cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QSystemSemaphore::AccessMode >::toCpp(pyArgs[2]) : QSystemSemaphore::Open;

        if(!PyErr_Occurred()) {
            // QSystemSemaphore(QString,int,QSystemSemaphore::AccessMode)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = new ::QSystemSemaphore(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSystemSemaphore >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSystemSemaphore_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSystemSemaphore_Init_TypeError:
        const char* overloads[] = {"unicode, int = 0, PySide.QtCore.QSystemSemaphore.AccessMode = Open", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSystemSemaphore", overloads);
        return -1;
}

static PyObject* Sbk_QSystemSemaphoreFunc_acquire(PyObject* self)
{
    ::QSystemSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSystemSemaphore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // acquire()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->acquire();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSystemSemaphoreFunc_error(PyObject* self)
{
    ::QSystemSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSystemSemaphore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // error()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QSystemSemaphore::SystemSemaphoreError cppResult = const_cast<const ::QSystemSemaphore*>(cppSelf)->error();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QSystemSemaphore::SystemSemaphoreError >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSystemSemaphoreFunc_errorString(PyObject* self)
{
    ::QSystemSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSystemSemaphore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // errorString()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QSystemSemaphore*>(cppSelf)->errorString();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSystemSemaphoreFunc_key(PyObject* self)
{
    ::QSystemSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSystemSemaphore* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // key()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QSystemSemaphore*>(cppSelf)->key();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSystemSemaphoreFunc_release(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QSystemSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSystemSemaphore* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSystemSemaphore.release(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:release", &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: release(int)
    if (numArgs == 0) {
        overloadId = 0; // release(int)
    } else if (SbkNumber_Check(pyArgs[0])) {
        overloadId = 0; // release(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSystemSemaphoreFunc_release_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "n");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "n";
                else if (SbkNumber_Check(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QSystemSemaphoreFunc_release_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSystemSemaphore.release(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = pyArgs[0] ? Shiboken::Converter< int >::toCpp(pyArgs[0]) : 1;

        if(!PyErr_Occurred()) {
            // release(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = cppSelf->release(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSystemSemaphoreFunc_release_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSystemSemaphore.release", overloads);
        return 0;
}

static PyObject* Sbk_QSystemSemaphoreFunc_setKey(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QSystemSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSystemSemaphore* >::toCpp(self);
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSystemSemaphore.setKey(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSystemSemaphore.setKey(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:setKey", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setKey(QString,int,QSystemSemaphore::AccessMode)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setKey(QString,int,QSystemSemaphore::AccessMode)
        } else if (SbkNumber_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // setKey(QString,int,QSystemSemaphore::AccessMode)
            } else if (Shiboken::Converter< ::QSystemSemaphore::AccessMode >::isConvertible(pyArgs[2])) {
                overloadId = 0; // setKey(QString,int,QSystemSemaphore::AccessMode)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSystemSemaphoreFunc_setKey_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "initialValue");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "initialValue";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QSystemSemaphoreFunc_setKey_TypeError;
            }
            value = PyDict_GetItemString(kwds, "mode");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "mode";
                else if (Shiboken::Converter< ::QSystemSemaphore::AccessMode >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QSystemSemaphoreFunc_setKey_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSystemSemaphore.setKey(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : 0;
        QSystemSemaphore::AccessMode cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QSystemSemaphore::AccessMode >::toCpp(pyArgs[2]) : QSystemSemaphore::Open;

        if(!PyErr_Occurred()) {
            // setKey(QString,int,QSystemSemaphore::AccessMode)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setKey(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSystemSemaphoreFunc_setKey_TypeError:
        const char* overloads[] = {"unicode, int = 0, PySide.QtCore.QSystemSemaphore.AccessMode = Open", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSystemSemaphore.setKey", overloads);
        return 0;
}

static PyMethodDef Sbk_QSystemSemaphore_methods[] = {
    {"acquire", (PyCFunction)Sbk_QSystemSemaphoreFunc_acquire, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QSystemSemaphoreFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QSystemSemaphoreFunc_errorString, METH_NOARGS},
    {"key", (PyCFunction)Sbk_QSystemSemaphoreFunc_key, METH_NOARGS},
    {"release", (PyCFunction)Sbk_QSystemSemaphoreFunc_release, METH_VARARGS|METH_KEYWORDS},
    {"setKey", (PyCFunction)Sbk_QSystemSemaphoreFunc_setKey, METH_VARARGS|METH_KEYWORDS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QSystemSemaphore_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QSystemSemaphore_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSystemSemaphore_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtCore.QSystemSemaphore",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QSystemSemaphore_traverse,
    /*tp_clear*/            Sbk_QSystemSemaphore_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSystemSemaphore_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSystemSemaphore_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSystemSemaphore(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSystemSemaphore_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QSystemSemaphore", "QSystemSemaphore*",
        &Sbk_QSystemSemaphore_Type, &Shiboken::callCppDestructor< ::QSystemSemaphore >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'AccessMode'.
    SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_ACCESSMODE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QSystemSemaphore_Type,
        "AccessMode",
        "PySide.QtCore.QSystemSemaphore.AccessMode",
        "QSystemSemaphore::AccessMode");
    if (!SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_ACCESSMODE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_ACCESSMODE_IDX],
        &Sbk_QSystemSemaphore_Type, "Open", (long) QSystemSemaphore::Open))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_ACCESSMODE_IDX],
        &Sbk_QSystemSemaphore_Type, "Create", (long) QSystemSemaphore::Create))
        return ;
    // End of 'AccessMode' enum.

    // Initialization of enum 'SystemSemaphoreError'.
    SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QSystemSemaphore_Type,
        "SystemSemaphoreError",
        "PySide.QtCore.QSystemSemaphore.SystemSemaphoreError",
        "QSystemSemaphore::SystemSemaphoreError");
    if (!SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX],
        &Sbk_QSystemSemaphore_Type, "NoError", (long) QSystemSemaphore::NoError))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX],
        &Sbk_QSystemSemaphore_Type, "PermissionDenied", (long) QSystemSemaphore::PermissionDenied))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX],
        &Sbk_QSystemSemaphore_Type, "KeyError", (long) QSystemSemaphore::KeyError))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX],
        &Sbk_QSystemSemaphore_Type, "AlreadyExists", (long) QSystemSemaphore::AlreadyExists))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX],
        &Sbk_QSystemSemaphore_Type, "NotFound", (long) QSystemSemaphore::NotFound))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX],
        &Sbk_QSystemSemaphore_Type, "OutOfResources", (long) QSystemSemaphore::OutOfResources))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtCoreTypes[SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX],
        &Sbk_QSystemSemaphore_Type, "UnknownError", (long) QSystemSemaphore::UnknownError))
        return ;
    // End of 'SystemSemaphoreError' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QSystemSemaphore >("QSystemSemaphore*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QSystemSemaphore >(typeid(::QSystemSemaphore).name());
    qRegisterMetaType< ::QSystemSemaphore::AccessMode >("QSystemSemaphore::AccessMode");
    qRegisterMetaType< ::QSystemSemaphore::SystemSemaphoreError >("QSystemSemaphore::SystemSemaphoreError");
}
