/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfileiconprovider_wrapper.h"

// Extra includes
#include <qfileiconprovider.h>
#include <qfileinfo.h>
#include <qicon.h>


// Native ---------------------------------------------------------

QFileIconProviderWrapper::QFileIconProviderWrapper() : QFileIconProvider() {
    // ... middle
}

QIcon QFileIconProviderWrapper::icon(QFileIconProvider::IconType type) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QIcon();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "icon"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QFileIconProvider::icon(type);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFileIconProvider::IconType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QIcon();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QIcon >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QFileIconProvider.icon", Shiboken::SbkType< QIcon >()->tp_name, pyResult->ob_type->tp_name);
        return ::QIcon();
    }
    QIcon cppResult = Shiboken::Converter< ::QIcon >::toCpp(pyResult);
    return cppResult;
}

QIcon QFileIconProviderWrapper::icon(const QFileInfo & info) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QIcon();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "icon"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QFileIconProvider::icon(info);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFileInfo >::toPython(info)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QIcon();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QIcon >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QFileIconProvider.icon", Shiboken::SbkType< QIcon >()->tp_name, pyResult->ob_type->tp_name);
        return ::QIcon();
    }
    QIcon cppResult = Shiboken::Converter< ::QIcon >::toCpp(pyResult);
    return cppResult;
}

QString QFileIconProviderWrapper::type(const QFileInfo & info) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QString();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "type"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QFileIconProvider::type(info);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFileInfo >::toPython(info)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QFileIconProvider.type", "QString", pyResult->ob_type->tp_name);
        return ::QString();
    }
    ::QString cppResult = Shiboken::Converter< ::QString >::toCpp(pyResult);
    return cppResult;
}

QFileIconProviderWrapper::~QFileIconProviderWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileIconProvider_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFileIconProvider >()))
        return -1;

    ::QFileIconProviderWrapper* cptr = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // QFileIconProvider()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = new ::QFileIconProviderWrapper();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFileIconProvider >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QFileIconProviderFunc_icon(PyObject* self, PyObject* pyArg)
{
    ::QFileIconProvider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QFileIconProvider* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: icon(QFileIconProvider::IconType)const
    // 1: icon(QFileInfo)const
    if (Shiboken::Converter< ::QFileInfo >::isConvertible(pyArg)) {
        overloadId = 1; // icon(QFileInfo)const
    } else if (Shiboken::Converter< ::QFileIconProvider::IconType >::isConvertible(pyArg)) {
        overloadId = 0; // icon(QFileIconProvider::IconType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileIconProviderFunc_icon_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // icon(QFileIconProvider::IconType)const
        {
            QFileIconProvider::IconType cppArg0 = Shiboken::Converter< ::QFileIconProvider::IconType >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // icon(QFileIconProvider::IconType)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QFileIconProvider*>(cppSelf)->::QFileIconProvider::icon(cppArg0) : const_cast<const ::QFileIconProvider*>(cppSelf)->icon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
            break;
        }
        case 1: // icon(QFileInfo)const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QFileInfo cppArg0 = Shiboken::Converter< ::QFileInfo >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // icon(QFileInfo)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QFileIconProvider*>(cppSelf)->::QFileIconProvider::icon(cppArg0) : const_cast<const ::QFileIconProvider*>(cppSelf)->icon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileIconProviderFunc_icon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFileIconProvider.IconType", "PySide.QtCore.QFileInfo", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QFileIconProvider.icon", overloads);
        return 0;
}

static PyObject* Sbk_QFileIconProviderFunc_type(PyObject* self, PyObject* pyArg)
{
    ::QFileIconProvider* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QFileIconProvider* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: type(QFileInfo)const
    if (Shiboken::Converter< ::QFileInfo >::isConvertible(pyArg)) {
        overloadId = 0; // type(QFileInfo)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFileIconProviderFunc_type_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QFileInfo cppArg0 = Shiboken::Converter< ::QFileInfo >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // type(QFileInfo)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self)) ? const_cast<const ::QFileIconProvider*>(cppSelf)->::QFileIconProvider::type(cppArg0) : const_cast<const ::QFileIconProvider*>(cppSelf)->type(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFileIconProviderFunc_type_TypeError:
        const char* overloads[] = {"PySide.QtCore.QFileInfo", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QFileIconProvider.type", overloads);
        return 0;
}

static PyMethodDef Sbk_QFileIconProvider_methods[] = {
    {"icon", (PyCFunction)Sbk_QFileIconProviderFunc_icon, METH_O},
    {"type", (PyCFunction)Sbk_QFileIconProviderFunc_type, METH_O},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QFileIconProvider_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QFileIconProvider_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QFileIconProvider_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QFileIconProvider",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QFileIconProvider_traverse,
    /*tp_clear*/            Sbk_QFileIconProvider_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QFileIconProvider_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QFileIconProvider_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QFileIconProvider(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QFileIconProvider_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QFileIconProvider", "QFileIconProvider*",
        &Sbk_QFileIconProvider_Type, &Shiboken::callCppDestructor< ::QFileIconProvider >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'IconType'.
    SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QFileIconProvider_Type,
        "IconType",
        "PySide.QtGui.QFileIconProvider.IconType",
        "QFileIconProvider::IconType");
    if (!SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX],
        &Sbk_QFileIconProvider_Type, "Computer", (long) QFileIconProvider::Computer))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX],
        &Sbk_QFileIconProvider_Type, "Desktop", (long) QFileIconProvider::Desktop))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX],
        &Sbk_QFileIconProvider_Type, "Trashcan", (long) QFileIconProvider::Trashcan))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX],
        &Sbk_QFileIconProvider_Type, "Network", (long) QFileIconProvider::Network))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX],
        &Sbk_QFileIconProvider_Type, "Drive", (long) QFileIconProvider::Drive))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX],
        &Sbk_QFileIconProvider_Type, "Folder", (long) QFileIconProvider::Folder))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QFILEICONPROVIDER_ICONTYPE_IDX],
        &Sbk_QFileIconProvider_Type, "File", (long) QFileIconProvider::File))
        return ;
    // End of 'IconType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QFileIconProvider >("QFileIconProvider*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QFileIconProvider >(typeid(::QFileIconProvider).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QFileIconProvider >(typeid(::QFileIconProviderWrapper).name());
    qRegisterMetaType< ::QFileIconProvider::IconType >("QFileIconProvider::IconType");
}
