/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpainterpath_element_wrapper.h"

// Extra includes
#include <QPainterPath>
#include <qpoint.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPainterPath_Element_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPainterPath::Element >()))
        return -1;

    ::QPainterPath::Element* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "Element", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: Element()
    // 1: Element(QPainterPath::Element)
    if (numArgs == 0) {
        overloadId = 0; // Element()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPainterPath::Element >::isConvertible(pyArgs[0])) {
        overloadId = 1; // Element(QPainterPath::Element)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPath_Element_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // Element()
        {

            if(!PyErr_Occurred()) {
                // Element()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPainterPath::Element();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // Element(QPainterPath::Element)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPainterPath::Element cppArg0 = Shiboken::Converter< ::QPainterPath::Element >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // Element(QPainterPath::Element)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPainterPath::Element(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPainterPath::Element >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPainterPath_Element_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPainterPath_Element_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPainterPath::Element", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.Element", overloads);
        return -1;
}

static PyObject* Sbk_QPainterPath_ElementFunc_isCurveTo(PyObject* self)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isCurveTo()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPainterPath::Element*>(cppSelf)->isCurveTo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPath_ElementFunc_isLineTo(PyObject* self)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isLineTo()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPainterPath::Element*>(cppSelf)->isLineTo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPath_ElementFunc_isMoveTo(PyObject* self)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isMoveTo()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPainterPath::Element*>(cppSelf)->isMoveTo();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPath_Element___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QPainterPath::Element& cppSelf = *(Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QPainterPath::Element >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QPainterPath_Element_methods[] = {
    {"isCurveTo", (PyCFunction)Sbk_QPainterPath_ElementFunc_isCurveTo, METH_NOARGS},
    {"isLineTo", (PyCFunction)Sbk_QPainterPath_ElementFunc_isLineTo, METH_NOARGS},
    {"isMoveTo", (PyCFunction)Sbk_QPainterPath_ElementFunc_isMoveTo, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QPainterPath_Element___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QPainterPath_Element_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QPainterPath::Element& cppSelf = *(Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QPainterPath::Element >::isConvertible(pyArg)) {
                // operator!=(const QPainterPath::Element & e) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QPainterPath::Element cppArg0 = Shiboken::Converter< ::QPainterPath::Element >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QPainterPath::Element >::isConvertible(pyArg)) {
                // operator==(const QPainterPath::Element & e) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QPainterPath::Element cppArg0 = Shiboken::Converter< ::QPainterPath::Element >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QPainterPath_Element_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QPainterPath_Element_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

static PyObject* Sbk_QPainterPath_Element_get_x(PyObject* self, void*)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    PyObject* value = Shiboken::Converter< double >::toPython(cppSelf->x);
    return value;
}
static int Sbk_QPainterPath_Element_set_x(PyObject* self, PyObject* value, void*)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'x' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'x', 'qreal' or convertible type expected");
        return -1;
    }

    cppSelf->x = Shiboken::Converter< double >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QPainterPath_Element_get_y(PyObject* self, void*)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    PyObject* value = Shiboken::Converter< double >::toPython(cppSelf->y);
    return value;
}
static int Sbk_QPainterPath_Element_set_y(PyObject* self, PyObject* value, void*)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'y' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'y', 'qreal' or convertible type expected");
        return -1;
    }

    cppSelf->y = Shiboken::Converter< double >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QPainterPath_Element_get_type(PyObject* self, void*)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QPainterPath::ElementType >::toPython(cppSelf->type);
    return value;
}
static int Sbk_QPainterPath_Element_set_type(PyObject* self, PyObject* value, void*)
{
    ::QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPainterPath::Element* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'type' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QPainterPath::ElementType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'type', 'ElementType' or convertible type expected");
        return -1;
    }

    cppSelf->type = Shiboken::Converter< ::QPainterPath::ElementType >::toCpp(value);

    return 0;
}

// Getters and Setters for Element
static PyGetSetDef Sbk_QPainterPath_Element_getsetlist[] = {
    {const_cast<char*>("x"), Sbk_QPainterPath_Element_get_x, Sbk_QPainterPath_Element_set_x},
    {const_cast<char*>("y"), Sbk_QPainterPath_Element_get_y, Sbk_QPainterPath_Element_set_y},
    {const_cast<char*>("type"), Sbk_QPainterPath_Element_get_type, Sbk_QPainterPath_Element_set_type},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QPainterPath_Element_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QPainterPath_Element_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPainterPath_Element_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QPainterPath.Element",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QPainterPath_Element_traverse,
    /*tp_clear*/            Sbk_QPainterPath_Element_clear,
    /*tp_richcompare*/      Sbk_QPainterPath_Element_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPainterPath_Element_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QPainterPath_Element_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPainterPath_Element_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPainterPath_Element(PyObject* enclosingClass)
{
    SbkPySide_QtGuiTypes[SBK_QPAINTERPATH_ELEMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPainterPath_Element_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(enclosingClass, "Element", "QPainterPath::Element",
        &Sbk_QPainterPath_Element_Type, &Shiboken::callCppDestructor< ::QPainterPath::Element >, 0, 0, true)) {
        return;
    }


    Shiboken::TypeResolver::createValueTypeResolver< ::QPainterPath::Element >("QPainterPath::Element");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QPainterPath::Element >("QPainterPath::Element*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QPainterPath::Element >(typeid(::QPainterPath::Element).name());
    qRegisterMetaType< ::QPainterPath::Element >("Element");
    qRegisterMetaType< ::QPainterPath::Element >("QPainterPath::Element");
}
