/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpolygon_wrapper.h"

// Extra includes
#include <QList>
#include <QMatrix>
#include <QTransform>
#include <QVector>
#include <qdatastream.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPolygon_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPolygon >()))
        return -1;

    ::QPolygon* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QPolygon", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QPolygon()
    // 1: QPolygon(QPolygon)
    // 2: QPolygon(QRect,bool)
    // 3: QPolygon(QVector<QPoint>)
    // 4: QPolygon(int)
    if (numArgs == 0) {
        overloadId = 0; // QPolygon()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 4; // QPolygon(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyArgs[0])) {
        overloadId = 3; // QPolygon(QVector<QPoint>)
    } else if (Shiboken::Converter< ::QRect >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QPolygon(QRect,bool)
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 2; // QPolygon(QRect,bool)
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPolygon >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QPolygon(QPolygon)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygon_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QPolygon()
        {

            if(!PyErr_Occurred()) {
                // QPolygon()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPolygon();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QPolygon(QPolygon)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPolygon cppArg0 = Shiboken::Converter< ::QPolygon >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QPolygon(QPolygon)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPolygon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QPolygon(QRect,bool)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "closed");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "closed";
                    else if (SbkNumber_Check(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QPolygon_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRect cppArg0 = Shiboken::Converter< ::QRect >::toCpp(pyArgs[0]);
            bool cppArg1 = pyArgs[1] ? Shiboken::Converter< bool >::toCpp(pyArgs[1]) : false;

            if(!PyErr_Occurred()) {
                // QPolygon(QRect,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPolygon(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QPolygon(QVector<QPoint>)
        {
            ::QVector<QPoint > cppArg0 = Shiboken::Converter< ::QVector<QPoint > >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QPolygon(QVector<QPoint>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPolygon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // QPolygon(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QPolygon(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QPolygon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPolygon >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPolygon_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPolygon_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPolygon", "PySide.QtCore.QRect, bool = false", "list", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon", overloads);
        return -1;
}

static PyObject* Sbk_QPolygonFunc___reduce__(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __reduce__()
            // Begin code injection

            PyObject* points = PyList_New(cppSelf->count());
            for (int i = 0, max = cppSelf->count(); i < max; ++i){
                int x, y;
                cppSelf->point(i, &x, &y);
                QPoint pt = QPoint(x, y);
                PyList_SET_ITEM(points, i, Shiboken::Converter< ::QPoint >::toPython(pt));
            }
            // TEMPLATE - reduce_code - START
            pyResult = Py_BuildValue("(N(N))", PyObject_Type(self), points);
            // TEMPLATE - reduce_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_append(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // append(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_append_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // append(QPoint)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->append(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.append", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_at(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_at_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // at(int)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QPoint & cppResult = const_cast<const ::QPolygon*>(cppSelf)->at(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.at", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_boundingRect(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // boundingRect()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QRect cppResult = const_cast<const ::QPolygon*>(cppSelf)->boundingRect();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_capacity(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // capacity()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QPolygon*>(cppSelf)->capacity();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_clear(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // clear()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->clear();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPolygonFunc_constData(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // constData()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QPoint * cppResult = const_cast<const ::QPolygon*>(cppSelf)->constData();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPoint * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_contains(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // contains(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_contains_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // contains(QPoint)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPolygon*>(cppSelf)->contains(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.contains", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_containsPoint(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "containsPoint", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: containsPoint(QPoint,Qt::FillRule)const
    if (numArgs == 2
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::Qt::FillRule >::isConvertible(pyArgs[1])) {
        overloadId = 0; // containsPoint(QPoint,Qt::FillRule)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_containsPoint_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);
        Qt::FillRule cppArg1 = Shiboken::Converter< ::Qt::FillRule >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // containsPoint(QPoint,Qt::FillRule)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPolygon*>(cppSelf)->containsPoint(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_containsPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtCore.Qt.FillRule", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.containsPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_count(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "count", 0, 1, &(pyArgs[0])))
        return 0;


    // Overloaded function decisor
    // 0: count()const
    // 1: count(QPoint)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])) {
        overloadId = 1; // count(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_count_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // count()const
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QPolygon*>(cppSelf)->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
        case 1: // count(QPoint)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // count(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const ::QPolygon*>(cppSelf)->count(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_count_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.count", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_data(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // data()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPoint * cppResult = cppSelf->data();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPoint * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_empty(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // empty()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPolygon*>(cppSelf)->empty();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_endsWith(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endsWith(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // endsWith(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_endsWith_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // endsWith(QPoint)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPolygon*>(cppSelf)->endsWith(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_endsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.endsWith", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_erase(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "erase", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: erase(QPoint*,QPoint*)
    if (numArgs == 2
        && Shiboken::Converter< ::QPoint * >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QPoint * >::isConvertible(pyArgs[1])) {
        overloadId = 0; // erase(QPoint*,QPoint*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_erase_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QPoint * cppArg0 = Shiboken::Converter< ::QPoint * >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QPoint * cppArg1 = Shiboken::Converter< ::QPoint * >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // erase(QPoint*,QPoint*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPoint * cppResult = cppSelf->erase(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPoint * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_erase_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.erase", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_fill(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.fill(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.fill(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fill", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fill(QPoint,int)
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fill(QPoint,int)
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 0; // fill(QPoint,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_fill_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "size");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "size";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QPolygonFunc_fill_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.fill(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : -1;

        if(!PyErr_Occurred()) {
            // fill(QPoint,int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVector<QPoint > & cppResult = cppSelf->fill(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVector<QPoint > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_fill_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.fill", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_first(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // first()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPoint & cppResult = cppSelf->first();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPoint & >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_fromList(PyObject* self, PyObject* pyArg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromList(QList<QPoint>)
    if (Shiboken::Converter< ::QList<QPoint > >::isConvertible(pyArg)) {
        overloadId = 0; // fromList(QList<QPoint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_fromList_TypeError;

    // Call function/method
    {
        ::QList<QPoint > cppArg0 = Shiboken::Converter< ::QList<QPoint > >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // fromList(QList<QPoint>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVector<QPoint > cppResult = QPolygon::fromList(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVector<QPoint > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_fromList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.fromList", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_front(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // front()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPoint & cppResult = cppSelf->front();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPoint & >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_indexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.indexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.indexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOf", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(QPoint,int)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QPoint,int)const
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 0; // indexOf(QPoint,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_indexOf_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "from");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "from";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QPolygonFunc_indexOf_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : 0;

        if(!PyErr_Occurred()) {
            // indexOf(QPoint,int)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QPolygon*>(cppSelf)->indexOf(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.indexOf", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_insert(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insert", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insert(QPoint*,int,QPoint)
    // 1: insert(int,QPoint)
    // 2: insert(int,int,QPoint)
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 3
            && SbkNumber_Check(pyArgs[1])
            && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[2])) {
            overloadId = 2; // insert(int,int,QPoint)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[1])) {
            overloadId = 1; // insert(int,QPoint)
        }
    } else if (numArgs == 3
        && Shiboken::Converter< ::QPoint * >::isConvertible(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[2])) {
        overloadId = 0; // insert(QPoint*,int,QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_insert_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // insert(QPoint*,int,QPoint)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPoint * cppArg0 = Shiboken::Converter< ::QPoint * >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return 0;
            ::QPoint cppArg2 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // insert(QPoint*,int,QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint * cppResult = cppSelf->insert(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // insert(int,QPoint)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QPoint cppArg1 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // insert(int,QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insert(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 2: // insert(int,int,QPoint)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return 0;
            ::QPoint cppArg2 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // insert(int,int,QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insert(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_insert_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int, PySide.QtCore.QPoint", "int, PySide.QtCore.QPoint", "int, int, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.insert", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_intersected(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QPolygon)const
    if (Shiboken::Converter< ::QPolygon >::isConvertible(pyArg)) {
        overloadId = 0; // intersected(QPolygon)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_intersected_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPolygon cppArg0 = Shiboken::Converter< ::QPolygon >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // intersected(QPolygon)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPolygon cppResult = const_cast<const ::QPolygon*>(cppSelf)->intersected(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.intersected", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_isEmpty(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isEmpty()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPolygon*>(cppSelf)->isEmpty();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_isSharedWith(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSharedWith(QVector<QPoint>)const
    if (Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyArg)) {
        overloadId = 0; // isSharedWith(QVector<QPoint>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_isSharedWith_TypeError;

    // Call function/method
    {
        ::QVector<QPoint > cppArg0 = Shiboken::Converter< ::QVector<QPoint > >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // isSharedWith(QVector<QPoint>)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPolygon*>(cppSelf)->isSharedWith(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_isSharedWith_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.isSharedWith", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_last(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // last()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPoint & cppResult = cppSelf->last();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPoint & >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_lastIndexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.lastIndexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.lastIndexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(QPoint,int)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QPoint,int)const
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 0; // lastIndexOf(QPoint,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_lastIndexOf_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "from");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "from";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QPolygonFunc_lastIndexOf_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : -1;

        if(!PyErr_Occurred()) {
            // lastIndexOf(QPoint,int)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QPolygon*>(cppSelf)->lastIndexOf(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_lastIndexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.lastIndexOf", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_mid(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.mid(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygon.mid(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:mid", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mid(int,int)const
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // mid(int,int)const
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 0; // mid(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_mid_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "length");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "length";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QPolygonFunc_mid_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygon.mid(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : -1;

        if(!PyErr_Occurred()) {
            // mid(int,int)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVector<QPoint > cppResult = const_cast<const ::QPolygon*>(cppSelf)->mid(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVector<QPoint > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_mid_TypeError:
        const char* overloads[] = {"int, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.mid", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_pop_back(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // pop_back()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->pop_back();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPolygonFunc_pop_front(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // pop_front()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->pop_front();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPolygonFunc_prepend(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepend(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // prepend(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_prepend_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // prepend(QPoint)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->prepend(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_prepend_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.prepend", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_push_back(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_back(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // push_back(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_push_back_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // push_back(QPoint)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->push_back(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_push_back_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.push_back", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_push_front(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_front(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // push_front(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_push_front_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // push_front(QPoint)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->push_front(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_push_front_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.push_front", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_remove(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "remove", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: remove(int)
    // 1: remove(int,int)
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // remove(int)
        } else if (numArgs == 2
            && SbkNumber_Check(pyArgs[1])) {
            overloadId = 1; // remove(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_remove_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // remove(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // remove(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->remove(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // remove(int,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // remove(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->remove(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_remove_TypeError:
        const char* overloads[] = {"int", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.remove", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_replace(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(int,QPoint)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[1])) {
        overloadId = 0; // replace(int,QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_replace_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QPoint cppArg1 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // replace(int,QPoint)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->replace(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_replace_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.replace", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_reserve(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: reserve(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // reserve(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_reserve_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // reserve(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->reserve(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_reserve_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.reserve", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_resize(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_resize_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // resize(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->resize(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.resize", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_setSharable(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSharable(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setSharable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_setSharable_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setSharable(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setSharable(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_setSharable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.setSharable", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_size(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // size()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QPolygon*>(cppSelf)->size();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_squeeze(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // squeeze()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->squeeze();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPolygonFunc_startsWith(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startsWith(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // startsWith(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_startsWith_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // startsWith(QPoint)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QPolygon*>(cppSelf)->startsWith(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_startsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.startsWith", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_subtracted(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtracted(QPolygon)const
    if (Shiboken::Converter< ::QPolygon >::isConvertible(pyArg)) {
        overloadId = 0; // subtracted(QPolygon)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_subtracted_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPolygon cppArg0 = Shiboken::Converter< ::QPolygon >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // subtracted(QPolygon)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPolygon cppResult = const_cast<const ::QPolygon*>(cppSelf)->subtracted(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_subtracted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.subtracted", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_swap(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: swap(QPolygon&)
    if (Shiboken::Converter< ::QPolygon & >::isConvertible(pyArg)) {
        overloadId = 0; // swap(QPolygon&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_swap_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QPolygon & cppArg0 = Shiboken::Converter< ::QPolygon & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // swap(QPolygon&)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->swap(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_swap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.swap", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_toList(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toList()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QPoint > cppResult = const_cast<const ::QPolygon*>(cppSelf)->toList();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QPoint > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFunc_translate(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPoint)
    // 1: translate(int,int)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 1; // translate(int,int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])) {
        overloadId = 0; // translate(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_translate_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // translate(QPoint)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // translate(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->translate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // translate(int,int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // translate(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->translate(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.translate", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_translated(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPoint)const
    // 1: translated(int,int)const
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 1; // translated(int,int)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])) {
        overloadId = 0; // translated(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_translated_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // translated(QPoint)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // translated(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygon cppResult = const_cast<const ::QPolygon*>(cppSelf)->translated(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
            }
            break;
        }
        case 1: // translated(int,int)const
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            int cppArg1 = Shiboken::Converter< int >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // translated(int,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygon cppResult = const_cast<const ::QPolygon*>(cppSelf)->translated(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.translated", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_united(PyObject* self, PyObject* pyArg)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QPolygon)const
    if (Shiboken::Converter< ::QPolygon >::isConvertible(pyArg)) {
        overloadId = 0; // united(QPolygon)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_united_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QPolygon cppArg0 = Shiboken::Converter< ::QPolygon >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // united(QPolygon)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPolygon cppResult = const_cast<const ::QPolygon*>(cppSelf)->united(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygon", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.united", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc_value(PyObject* self, PyObject* args)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "value", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(int)const
    // 1: value(int,QPoint)const
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // value(int)const
        } else if (numArgs == 2
            && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[1])) {
            overloadId = 1; // value(int,QPoint)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc_value_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // value(int)const
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // value(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const ::QPolygon*>(cppSelf)->value(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
            break;
        }
        case 1: // value(int,QPoint)const
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QPoint cppArg1 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // value(int,QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const ::QPolygon*>(cppSelf)->value(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc_value_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygon.value", overloads);
        return 0;
}

static PyObject* Sbk_QPolygon___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QPolygon& cppSelf = *(Shiboken::Converter< ::QPolygon* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QPolygon_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QPolygonFunc___reduce__, METH_NOARGS},
    {"append", (PyCFunction)Sbk_QPolygonFunc_append, METH_O},
    {"at", (PyCFunction)Sbk_QPolygonFunc_at, METH_O},
    {"boundingRect", (PyCFunction)Sbk_QPolygonFunc_boundingRect, METH_NOARGS},
    {"capacity", (PyCFunction)Sbk_QPolygonFunc_capacity, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QPolygonFunc_clear, METH_NOARGS},
    {"constData", (PyCFunction)Sbk_QPolygonFunc_constData, METH_NOARGS},
    {"contains", (PyCFunction)Sbk_QPolygonFunc_contains, METH_O},
    {"containsPoint", (PyCFunction)Sbk_QPolygonFunc_containsPoint, METH_VARARGS},
    {"count", (PyCFunction)Sbk_QPolygonFunc_count, METH_VARARGS},
    {"data", (PyCFunction)Sbk_QPolygonFunc_data, METH_NOARGS},
    {"empty", (PyCFunction)Sbk_QPolygonFunc_empty, METH_NOARGS},
    {"endsWith", (PyCFunction)Sbk_QPolygonFunc_endsWith, METH_O},
    {"erase", (PyCFunction)Sbk_QPolygonFunc_erase, METH_VARARGS},
    {"fill", (PyCFunction)Sbk_QPolygonFunc_fill, METH_VARARGS|METH_KEYWORDS},
    {"first", (PyCFunction)Sbk_QPolygonFunc_first, METH_NOARGS},
    {"fromList", (PyCFunction)Sbk_QPolygonFunc_fromList, METH_O|METH_STATIC},
    {"front", (PyCFunction)Sbk_QPolygonFunc_front, METH_NOARGS},
    {"indexOf", (PyCFunction)Sbk_QPolygonFunc_indexOf, METH_VARARGS|METH_KEYWORDS},
    {"insert", (PyCFunction)Sbk_QPolygonFunc_insert, METH_VARARGS},
    {"intersected", (PyCFunction)Sbk_QPolygonFunc_intersected, METH_O},
    {"isEmpty", (PyCFunction)Sbk_QPolygonFunc_isEmpty, METH_NOARGS},
    {"isSharedWith", (PyCFunction)Sbk_QPolygonFunc_isSharedWith, METH_O},
    {"last", (PyCFunction)Sbk_QPolygonFunc_last, METH_NOARGS},
    {"lastIndexOf", (PyCFunction)Sbk_QPolygonFunc_lastIndexOf, METH_VARARGS|METH_KEYWORDS},
    {"mid", (PyCFunction)Sbk_QPolygonFunc_mid, METH_VARARGS|METH_KEYWORDS},
    {"pop_back", (PyCFunction)Sbk_QPolygonFunc_pop_back, METH_NOARGS},
    {"pop_front", (PyCFunction)Sbk_QPolygonFunc_pop_front, METH_NOARGS},
    {"prepend", (PyCFunction)Sbk_QPolygonFunc_prepend, METH_O},
    {"push_back", (PyCFunction)Sbk_QPolygonFunc_push_back, METH_O},
    {"push_front", (PyCFunction)Sbk_QPolygonFunc_push_front, METH_O},
    {"remove", (PyCFunction)Sbk_QPolygonFunc_remove, METH_VARARGS},
    {"replace", (PyCFunction)Sbk_QPolygonFunc_replace, METH_VARARGS},
    {"reserve", (PyCFunction)Sbk_QPolygonFunc_reserve, METH_O},
    {"resize", (PyCFunction)Sbk_QPolygonFunc_resize, METH_O},
    {"setSharable", (PyCFunction)Sbk_QPolygonFunc_setSharable, METH_O},
    {"size", (PyCFunction)Sbk_QPolygonFunc_size, METH_NOARGS},
    {"squeeze", (PyCFunction)Sbk_QPolygonFunc_squeeze, METH_NOARGS},
    {"startsWith", (PyCFunction)Sbk_QPolygonFunc_startsWith, METH_O},
    {"subtracted", (PyCFunction)Sbk_QPolygonFunc_subtracted, METH_O},
    {"swap", (PyCFunction)Sbk_QPolygonFunc_swap, METH_O},
    {"toList", (PyCFunction)Sbk_QPolygonFunc_toList, METH_NOARGS},
    {"translate", (PyCFunction)Sbk_QPolygonFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)Sbk_QPolygonFunc_translated, METH_VARARGS},
    {"united", (PyCFunction)Sbk_QPolygonFunc_united, METH_O},
    {"value", (PyCFunction)Sbk_QPolygonFunc_value, METH_VARARGS},

    {"__copy__", (PyCFunction)Sbk_QPolygon___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QPolygonFunc___mul__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QPolygon >::checkType(pyArg)
                    && !Shiboken::Converter< ::QPolygon >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QPolygon,QMatrix)
    // 1: operator*(QPolygon,QTransform)
    if (!isReverse
        && Shiboken::Converter< ::QTransform >::isConvertible(pyArg)) {
        overloadId = 1; // operator*(QPolygon,QTransform)
    } else if (!isReverse
        && Shiboken::Converter< ::QMatrix >::isConvertible(pyArg)) {
        overloadId = 0; // operator*(QPolygon,QMatrix)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc___mul___TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // operator*(QPolygon,QMatrix)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QMatrix cppArg0 = Shiboken::Converter< ::QMatrix >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*(QPolygon,QMatrix)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygon cppResult = (*cppSelf) * (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
            }
            break;
        }
        case 1: // operator*(QPolygon,QTransform)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QTransform cppArg0 = Shiboken::Converter< ::QTransform >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*(QPolygon,QTransform)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygon cppResult = (*cppSelf) * (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
            }
            break;
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc___add__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QPolygon >::checkType(pyArg)
                    && !Shiboken::Converter< ::QPolygon >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QVector<QPoint>)const
    if (!isReverse
        && Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyArg)) {
        overloadId = 0; // operator+(QVector<QPoint>)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc___add___TypeError;

    // Call function/method
    {
        ::QVector<QPoint > cppArg0 = Shiboken::Converter< ::QVector<QPoint > >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator+(QVector<QPoint>)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QVector<QPoint > cppResult = (*cppSelf) + cppArg0;
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QVector<QPoint > >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc___add___TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc___iadd__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QPolygon >::checkType(pyArg)
                    && !Shiboken::Converter< ::QPolygon >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QPoint)
    // 1: operator+=(QVector<QPoint>)
    // 2: operator+=(QVector<QPoint>)
    if (!isReverse
        && Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyArg)) {
        overloadId = 1; // operator+=(QVector<QPoint>)
    } else if (!isReverse
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 0; // operator+=(QPoint)
    } else if (!isReverse
        && Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyArg)) {
        overloadId = 2; // operator+=(QVector<QPoint>)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc___iadd___TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // operator+=(QPoint)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator+=(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // operator+=(QVector<QPoint>)
        {
            ::QVector<QPoint > cppArg0 = Shiboken::Converter< ::QVector<QPoint > >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator+=(QVector<QPoint>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // operator+=(QVector<QPoint>)
        {
            ::QVector<QPoint > cppArg0 = Shiboken::Converter< ::QVector<QPoint > >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator+=(QVector<QPoint>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QPolygonFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "list", "list", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc___lshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QPolygon >::checkType(pyArg)
                    && !Shiboken::Converter< ::QPolygon >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPolygon)
    // 1: operator<<(QPoint)
    // 2: operator<<(QVector<QPoint>)
    if (!isReverse
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 1; // operator<<(QPoint)
    } else if (!isReverse
        && Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyArg)) {
        overloadId = 2; // operator<<(QVector<QPoint>)
    } else if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator<<(QDataStream&,QPolygon)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc___lshift___TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // operator<<(QDataStream&,QPolygon)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QPolygon) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
            }
            break;
        }
        case 1: // operator<<(QPoint)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator<<(QPoint)
                // Begin code injection

                // operator<<()
                *cppSelf << cppArg0;
                pyResult = Shiboken::Converter< ::QPolygon * >::toPython(cppSelf);

                // End of code injection


            }
            break;
        }
        case 2: // operator<<(QVector<QPoint>)
        {
            ::QVector<QPoint > cppArg0 = Shiboken::Converter< ::QVector<QPoint > >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator<<(QVector<QPoint>)
                // Begin code injection

                // operator<<()
                *cppSelf << cppArg0;
                pyResult = Shiboken::Converter< ::QPolygon * >::toPython(cppSelf);

                // End of code injection


            }
            break;
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", "PySide.QtCore.QPoint", "list", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFunc___rshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QPolygon >::checkType(pyArg)
                    && !Shiboken::Converter< ::QPolygon >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPolygon&)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator>>(QDataStream&,QPolygon&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFunc___rshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QPolygon&) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) >> (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QPolygon.__rshift__", overloads);
        return 0;
}

Py_ssize_t Sbk_QPolygon__len__(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    return cppSelf->size();
}
PyObject* Sbk_QPolygon__getitem__(PyObject* self, Py_ssize_t _i)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf->size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    }
    QPolygon::iterator _item = cppSelf->begin();
    for(Py_ssize_t pos=0; pos < _i; pos++) _item++;
    return Shiboken::Converter< ::QPolygon::value_type>::toPython(*_item);
}
int Sbk_QPolygon__setitem__(PyObject* self, Py_ssize_t _i, PyObject* _value)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return -1;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf->size()) {
        PyErr_SetString(PyExc_IndexError, "list assignment index out of range");
        return -1;
    }
    QPolygon::iterator _item = cppSelf->begin();
    for(Py_ssize_t pos=0; pos < _i; pos++) _item++;
    QPolygon::value_type cppValue = Shiboken::Converter< ::QPolygon::value_type>::toCpp(_value);
    *_item = cppValue;
    return 0;
}
// Rich comparison
static PyObject* Sbk_QPolygon_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QPolygon& cppSelf = *(Shiboken::Converter< ::QPolygon* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyArg)) {
                // operator!=(const QVector<QPoint > & v) const
                ::QVector<QPoint > cppArg0 = Shiboken::Converter< ::QVector<QPoint > >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QVector<QPoint > >::isConvertible(pyArg)) {
                // operator==(const QVector<QPoint > & v) const
                ::QVector<QPoint > cppArg0 = Shiboken::Converter< ::QVector<QPoint > >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QPolygon_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QPolygon_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QPolygon_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QPolygon_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
extern "C"
{
static PyObject* Sbk_QPolygon__repr__(PyObject* self)
{
    ::QPolygon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QPolygon* >::toCpp(self);
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    int idx = str.indexOf('(');
    if (idx >= 0)
        str.replace(0, idx, Py_TYPE(self)->tp_name);
    PyObject* mod = PyDict_GetItemString(Py_TYPE(self)->tp_dict, "__module__");
    if (mod)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    else
        return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPolygon_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QPolygon",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QPolygon__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QPolygon_traverse,
    /*tp_clear*/            Sbk_QPolygon_clear,
    /*tp_richcompare*/      Sbk_QPolygon_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPolygon_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPolygon_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPolygon(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QPolygon_Type.super.as_number, 0, sizeof(PyNumberMethods));
    Sbk_QPolygon_Type.super.as_number.nb_rshift = Sbk_QPolygonFunc___rshift__;
    Sbk_QPolygon_Type.super.as_number.nb_lshift = Sbk_QPolygonFunc___lshift__;
    Sbk_QPolygon_Type.super.as_number.nb_inplace_add = Sbk_QPolygonFunc___iadd__;
    Sbk_QPolygon_Type.super.as_number.nb_add = Sbk_QPolygonFunc___add__;
    Sbk_QPolygon_Type.super.as_number.nb_multiply = Sbk_QPolygonFunc___mul__;
    Sbk_QPolygon_Type.super.ht_type.tp_as_number = &Sbk_QPolygon_Type.super.as_number;

    // type supports sequence protocol
    memset(&Sbk_QPolygon_Type.super.as_sequence, 0, sizeof(PySequenceMethods));
    Sbk_QPolygon_Type.super.as_sequence.sq_length = Sbk_QPolygon__len__;
    Sbk_QPolygon_Type.super.as_sequence.sq_item = Sbk_QPolygon__getitem__;
    Sbk_QPolygon_Type.super.as_sequence.sq_ass_item = Sbk_QPolygon__setitem__;
    Sbk_QPolygon_Type.super.ht_type.tp_as_sequence = &Sbk_QPolygon_Type.super.as_sequence;

    SbkPySide_QtGuiTypes[SBK_QPOLYGON_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPolygon_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QPolygon", "QPolygon",
        &Sbk_QPolygon_Type, &Shiboken::callCppDestructor< ::QPolygon >)) {
        return;
    }


    Shiboken::TypeResolver::createValueTypeResolver< ::QPolygon >("QPolygon");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QPolygon >("QPolygon*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QPolygon >(typeid(::QPolygon).name());
    qRegisterMetaType< ::QPolygon >("QPolygon");
}
