/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstylehintreturn_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleHintReturn_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleHintReturn >()))
        return -1;

    ::QStyleHintReturn* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyleHintReturn(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QStyleHintReturn", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleHintReturn(int,int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleHintReturn(int,int)
    } else if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QStyleHintReturn(int,int)
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 0; // QStyleHintReturn(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleHintReturn_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "version");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "version";
                else if (SbkNumber_Check(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QStyleHintReturn_Init_TypeError;
            }
            value = PyDict_GetItemString(kwds, "type");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "type";
                else if (SbkNumber_Check(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QStyleHintReturn_Init_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyleHintReturn(): got multiple values for keyword argument '%s'", errorArgName);
                return -1;
            }
        }
        int cppArg0 = pyArgs[0] ? Shiboken::Converter< int >::toCpp(pyArgs[0]) : QStyleOption::Version;
        int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : QStyleHintReturn::SH_Default;

        if(!PyErr_Occurred()) {
            // QStyleHintReturn(int,int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = new ::QStyleHintReturn(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleHintReturn >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleHintReturn_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleHintReturn_Init_TypeError:
        const char* overloads[] = {"int = QStyleOption.Version, int = SH_Default", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleHintReturn", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleHintReturn_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleHintReturn_get_version(PyObject* self, void*)
{
    ::QStyleHintReturn* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleHintReturn* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->version);
    return value;
}
static int Sbk_QStyleHintReturn_set_version(PyObject* self, PyObject* value, void*)
{
    ::QStyleHintReturn* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleHintReturn* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'version' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'version', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->version = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleHintReturn_get_type(PyObject* self, void*)
{
    ::QStyleHintReturn* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleHintReturn* >::toCpp(self);
    PyObject* value = Shiboken::Converter< int >::toPython(cppSelf->type);
    return value;
}
static int Sbk_QStyleHintReturn_set_type(PyObject* self, PyObject* value, void*)
{
    ::QStyleHintReturn* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleHintReturn* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'type' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'type', 'int' or convertible type expected");
        return -1;
    }

    cppSelf->type = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleHintReturn
static PyGetSetDef Sbk_QStyleHintReturn_getsetlist[] = {
    {const_cast<char*>("version"), Sbk_QStyleHintReturn_get_version, Sbk_QStyleHintReturn_set_version},
    {const_cast<char*>("type"), Sbk_QStyleHintReturn_get_type, Sbk_QStyleHintReturn_set_type},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleHintReturn_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleHintReturn_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleHintReturn_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleHintReturn",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleHintReturn_traverse,
    /*tp_clear*/            Sbk_QStyleHintReturn_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleHintReturn_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleHintReturn_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleHintReturn_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleHintReturn(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleHintReturn_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleHintReturn", "QStyleHintReturn*",
        &Sbk_QStyleHintReturn_Type, &Shiboken::callCppDestructor< ::QStyleHintReturn >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'HintReturnType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_HINTRETURNTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleHintReturn_Type,
        "HintReturnType",
        "PySide.QtGui.QStyleHintReturn.HintReturnType",
        "QStyleHintReturn::HintReturnType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_HINTRETURNTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_HINTRETURNTYPE_IDX],
        &Sbk_QStyleHintReturn_Type, "SH_Default", (long) QStyleHintReturn::SH_Default))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_HINTRETURNTYPE_IDX],
        &Sbk_QStyleHintReturn_Type, "SH_Mask", (long) QStyleHintReturn::SH_Mask))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_HINTRETURNTYPE_IDX],
        &Sbk_QStyleHintReturn_Type, "SH_Variant", (long) QStyleHintReturn::SH_Variant))
        return ;
    // End of 'HintReturnType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleHintReturn_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleHintReturn.StyleOptionVersion",
        "QStyleHintReturn::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleHintReturn_Type, "Version", (long) QStyleHintReturn::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleHintReturn_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleHintReturn.StyleOptionType",
        "QStyleHintReturn::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEHINTRETURN_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleHintReturn_Type, "Type", (long) QStyleHintReturn::Type))
        return ;
    // End of 'StyleOptionType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleHintReturn >("QStyleHintReturn*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleHintReturn >(typeid(::QStyleHintReturn).name());
    qRegisterMetaType< ::QStyleHintReturn::HintReturnType >("QStyleHintReturn::HintReturnType");
    qRegisterMetaType< ::QStyleHintReturn::StyleOptionVersion >("QStyleHintReturn::StyleOptionVersion");
    qRegisterMetaType< ::QStyleHintReturn::StyleOptionType >("QStyleHintReturn::StyleOptionType");
}
