/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptioncomplex_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionComplex_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionComplex >()))
        return -1;

    ::QStyleOptionComplex* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QStyleOptionComplex(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QStyleOptionComplex", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionComplex(QStyleOptionComplex)
    // 1: QStyleOptionComplex(int,int)
    if (numArgs == 0) {
        overloadId = 1; // QStyleOptionComplex(int,int)
    } else if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QStyleOptionComplex(int,int)
        } else if (SbkNumber_Check(pyArgs[1])) {
            overloadId = 1; // QStyleOptionComplex(int,int)
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionComplex >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QStyleOptionComplex(QStyleOptionComplex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionComplex_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionComplex(QStyleOptionComplex)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionComplex & cppArg0 = Shiboken::Converter< ::QStyleOptionComplex >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionComplex(QStyleOptionComplex)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionComplex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionComplex(int,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "version");
                if (value) {
                    if (pyArgs[0])
                        errorArgName = "version";
                    else if (SbkNumber_Check(value))
                        pyArgs[0] = value;
                    else
                        goto Sbk_QStyleOptionComplex_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "type";
                    else if (SbkNumber_Check(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QStyleOptionComplex_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QStyleOptionComplex(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cppArg0 = pyArgs[0] ? Shiboken::Converter< int >::toCpp(pyArgs[0]) : QStyleOptionComplex::Version;
            int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : QStyleOptionComplex::SO_Complex;

            if(!PyErr_Occurred()) {
                // QStyleOptionComplex(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionComplex(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionComplex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionComplex_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionComplex_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyleOptionComplex", "int = QStyleOptionComplex.Version, int = SO_Complex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionComplex", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionComplex_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionComplex_get_subControls(PyObject* self, void*)
{
    ::QStyleOptionComplex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionComplex* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<QStyle::SubControl> >::toPython(cppSelf->subControls);
    return value;
}
static int Sbk_QStyleOptionComplex_set_subControls(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionComplex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionComplex* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'subControls' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QStyle::SubControl> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'subControls', 'SubControls' or convertible type expected");
        return -1;
    }

    cppSelf->subControls = Shiboken::Converter< ::QFlags<QStyle::SubControl> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionComplex_get_activeSubControls(PyObject* self, void*)
{
    ::QStyleOptionComplex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionComplex* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QFlags<QStyle::SubControl> >::toPython(cppSelf->activeSubControls);
    return value;
}
static int Sbk_QStyleOptionComplex_set_activeSubControls(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionComplex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionComplex* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'activeSubControls' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QStyle::SubControl> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'activeSubControls', 'SubControls' or convertible type expected");
        return -1;
    }

    cppSelf->activeSubControls = Shiboken::Converter< ::QFlags<QStyle::SubControl> >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionComplex
static PyGetSetDef Sbk_QStyleOptionComplex_getsetlist[] = {
    {const_cast<char*>("subControls"), Sbk_QStyleOptionComplex_get_subControls, Sbk_QStyleOptionComplex_set_subControls},
    {const_cast<char*>("activeSubControls"), Sbk_QStyleOptionComplex_get_activeSubControls, Sbk_QStyleOptionComplex_set_activeSubControls},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionComplex_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionComplex_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionComplex_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionComplex",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionComplex_traverse,
    /*tp_clear*/            Sbk_QStyleOptionComplex_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionComplex_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionComplex_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionComplex_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionComplex(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionComplex_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionComplex", "QStyleOptionComplex*",
        &Sbk_QStyleOptionComplex_Type, &Shiboken::callCppDestructor< ::QStyleOptionComplex >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionComplex_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionComplex.StyleOptionVersion",
        "QStyleOptionComplex::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionComplex_Type, "Version", (long) QStyleOptionComplex::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionComplex_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionComplex.StyleOptionType",
        "QStyleOptionComplex::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionComplex_Type, "Type", (long) QStyleOptionComplex::Type))
        return ;
    // End of 'StyleOptionType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionComplex >("QStyleOptionComplex*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionComplex >(typeid(::QStyleOptionComplex).name());
    qRegisterMetaType< ::QStyleOptionComplex::StyleOptionVersion >("QStyleOptionComplex::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionComplex::StyleOptionType >("QStyleOptionComplex::StyleOptionType");
}
