/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionsizegrip_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionSizeGrip_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionSizeGrip >()))
        return -1;

    ::QStyleOptionSizeGrip* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionSizeGrip", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionSizeGrip()
    // 1: QStyleOptionSizeGrip(QStyleOptionSizeGrip)
    // 2: QStyleOptionSizeGrip(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionSizeGrip()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionSizeGrip(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionSizeGrip >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionSizeGrip(QStyleOptionSizeGrip)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionSizeGrip_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionSizeGrip()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionSizeGrip()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSizeGrip();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionSizeGrip(QStyleOptionSizeGrip)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionSizeGrip & cppArg0 = Shiboken::Converter< ::QStyleOptionSizeGrip >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionSizeGrip(QStyleOptionSizeGrip)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSizeGrip(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionSizeGrip(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionSizeGrip(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionSizeGrip(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionSizeGrip >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionSizeGrip_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionSizeGrip_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionSizeGrip", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionSizeGrip", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionSizeGrip_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionSizeGrip_get_corner(PyObject* self, void*)
{
    ::QStyleOptionSizeGrip* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSizeGrip* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::Qt::Corner >::toPython(cppSelf->corner);
    return value;
}
static int Sbk_QStyleOptionSizeGrip_set_corner(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionSizeGrip* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionSizeGrip* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'corner' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::Corner >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'corner', 'Corner' or convertible type expected");
        return -1;
    }

    cppSelf->corner = Shiboken::Converter< ::Qt::Corner >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionSizeGrip
static PyGetSetDef Sbk_QStyleOptionSizeGrip_getsetlist[] = {
    {const_cast<char*>("corner"), Sbk_QStyleOptionSizeGrip_get_corner, Sbk_QStyleOptionSizeGrip_set_corner},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionSizeGrip_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionSizeGrip_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionSizeGrip_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionSizeGrip",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionSizeGrip_traverse,
    /*tp_clear*/            Sbk_QStyleOptionSizeGrip_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionSizeGrip_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionSizeGrip_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionSizeGrip_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionSizeGrip(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSIZEGRIP_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionSizeGrip_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionSizeGrip", "QStyleOptionSizeGrip*",
        &Sbk_QStyleOptionSizeGrip_Type, &Shiboken::callCppDestructor< ::QStyleOptionSizeGrip >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSIZEGRIP_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionSizeGrip_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionSizeGrip.StyleOptionVersion",
        "QStyleOptionSizeGrip::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSIZEGRIP_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSIZEGRIP_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionSizeGrip_Type, "Version", (long) QStyleOptionSizeGrip::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSIZEGRIP_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionSizeGrip_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionSizeGrip.StyleOptionType",
        "QStyleOptionSizeGrip::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSIZEGRIP_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONSIZEGRIP_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionSizeGrip_Type, "Type", (long) QStyleOptionSizeGrip::Type))
        return ;
    // End of 'StyleOptionType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionSizeGrip >("QStyleOptionSizeGrip*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionSizeGrip >(typeid(::QStyleOptionSizeGrip).name());
    qRegisterMetaType< ::QStyleOptionSizeGrip::StyleOptionVersion >("QStyleOptionSizeGrip::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionSizeGrip::StyleOptionType >("QStyleOptionSizeGrip::StyleOptionType");
}
