/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiontabbarbase_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionTabBarBase_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionTabBarBase >()))
        return -1;

    ::QStyleOptionTabBarBase* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionTabBarBase", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionTabBarBase()
    // 1: QStyleOptionTabBarBase(QStyleOptionTabBarBase)
    // 2: QStyleOptionTabBarBase(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionTabBarBase()
    } else if (numArgs == 1
        && SbkNumber_Check(pyArgs[0])) {
        overloadId = 2; // QStyleOptionTabBarBase(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QStyleOptionTabBarBase >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QStyleOptionTabBarBase(QStyleOptionTabBarBase)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionTabBarBase_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionTabBarBase()
        {

            if(!PyErr_Occurred()) {
                // QStyleOptionTabBarBase()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionTabBarBase();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QStyleOptionTabBarBase(QStyleOptionTabBarBase)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            const QStyleOptionTabBarBase & cppArg0 = Shiboken::Converter< ::QStyleOptionTabBarBase >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionTabBarBase(QStyleOptionTabBarBase)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionTabBarBase(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QStyleOptionTabBarBase(int)
        {
            int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QStyleOptionTabBarBase(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QStyleOptionTabBarBase(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionTabBarBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionTabBarBase_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionTabBarBase_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionTabBarBase", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionTabBarBase", overloads);
        return -1;
}

static PyMethodDef Sbk_QStyleOptionTabBarBase_methods[] = {

    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionTabBarBase_get_selectedTabRect(PyObject* self, void*)
{
    ::QStyleOptionTabBarBase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabBarBase* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QRECT_IDX], &(cppSelf->selectedTabRect), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionTabBarBase_set_selectedTabRect(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionTabBarBase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabBarBase* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'selectedTabRect' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QRect >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'selectedTabRect', 'QRect' or convertible type expected");
        return -1;
    }

    cppSelf->selectedTabRect = Shiboken::Converter< ::QRect >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTabBarBase_get_shape(PyObject* self, void*)
{
    ::QStyleOptionTabBarBase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabBarBase* >::toCpp(self);
    PyObject* value = Shiboken::Converter< ::QTabBar::Shape >::toPython(cppSelf->shape);
    return value;
}
static int Sbk_QStyleOptionTabBarBase_set_shape(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionTabBarBase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabBarBase* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'shape' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QTabBar::Shape >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'shape', 'Shape' or convertible type expected");
        return -1;
    }

    cppSelf->shape = Shiboken::Converter< ::QTabBar::Shape >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTabBarBase_get_tabBarRect(PyObject* self, void*)
{
    ::QStyleOptionTabBarBase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabBarBase* >::toCpp(self);
    PyObject* value = Shiboken::Object::newObject((SbkObjectType*)SbkPySide_QtCoreTypes[SBK_QRECT_IDX], &(cppSelf->tabBarRect), false, true);
    Shiboken::Object::setParent(self, value);
    return value;
}
static int Sbk_QStyleOptionTabBarBase_set_tabBarRect(PyObject* self, PyObject* value, void*)
{
    ::QStyleOptionTabBarBase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QStyleOptionTabBarBase* >::toCpp(self);
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'tabBarRect' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QRect >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'tabBarRect', 'QRect' or convertible type expected");
        return -1;
    }

    cppSelf->tabBarRect = Shiboken::Converter< ::QRect >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionTabBarBase
static PyGetSetDef Sbk_QStyleOptionTabBarBase_getsetlist[] = {
    {const_cast<char*>("selectedTabRect"), Sbk_QStyleOptionTabBarBase_get_selectedTabRect, Sbk_QStyleOptionTabBarBase_set_selectedTabRect},
    {const_cast<char*>("shape"), Sbk_QStyleOptionTabBarBase_get_shape, Sbk_QStyleOptionTabBarBase_set_shape},
    {const_cast<char*>("tabBarRect"), Sbk_QStyleOptionTabBarBase_get_tabBarRect, Sbk_QStyleOptionTabBarBase_set_tabBarRect},
    {0}  // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionTabBarBase_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QStyleOptionTabBarBase_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionTabBarBase_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QStyleOptionTabBarBase",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QStyleOptionTabBarBase_traverse,
    /*tp_clear*/            Sbk_QStyleOptionTabBarBase_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionTabBarBase_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionTabBarBase_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionTabBarBase_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionTabBarBase(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABBARBASE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionTabBarBase_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QStyleOptionTabBarBase", "QStyleOptionTabBarBase*",
        &Sbk_QStyleOptionTabBarBase_Type, &Shiboken::callCppDestructor< ::QStyleOptionTabBarBase >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'StyleOptionVersion'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABBARBASE_STYLEOPTIONVERSION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionTabBarBase_Type,
        "StyleOptionVersion",
        "PySide.QtGui.QStyleOptionTabBarBase.StyleOptionVersion",
        "QStyleOptionTabBarBase::StyleOptionVersion");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABBARBASE_STYLEOPTIONVERSION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABBARBASE_STYLEOPTIONVERSION_IDX],
        &Sbk_QStyleOptionTabBarBase_Type, "Version", (long) QStyleOptionTabBarBase::Version))
        return ;
    // End of 'StyleOptionVersion' enum.

    // Initialization of enum 'StyleOptionType'.
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABBARBASE_STYLEOPTIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QStyleOptionTabBarBase_Type,
        "StyleOptionType",
        "PySide.QtGui.QStyleOptionTabBarBase.StyleOptionType",
        "QStyleOptionTabBarBase::StyleOptionType");
    if (!SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABBARBASE_STYLEOPTIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTABBARBASE_STYLEOPTIONTYPE_IDX],
        &Sbk_QStyleOptionTabBarBase_Type, "Type", (long) QStyleOptionTabBarBase::Type))
        return ;
    // End of 'StyleOptionType' enum.


    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionTabBarBase >("QStyleOptionTabBarBase*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QStyleOptionTabBarBase >(typeid(::QStyleOptionTabBarBase).name());
    qRegisterMetaType< ::QStyleOptionTabBarBase::StyleOptionVersion >("QStyleOptionTabBarBase::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionTabBarBase::StyleOptionType >("QStyleOptionTabBarBase::StyleOptionType");
}
