/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextframeformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qpen.h>
#include <qtextformat.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextFrameFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextFrameFormat >()))
        return -1;

    ::QTextFrameFormat* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextFrameFormat", 0, 1, &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QTextFrameFormat()
    // 1: QTextFrameFormat(QTextFormat)
    // 2: QTextFrameFormat(QTextFrameFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextFrameFormat()
    } else if (numArgs == 1
        && Shiboken::Converter< ::QTextFrameFormat >::isConvertible(pyArgs[0])) {
        overloadId = 2; // QTextFrameFormat(QTextFrameFormat)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QTextFormat >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QTextFrameFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormat_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextFrameFormat()
        {

            if(!PyErr_Occurred()) {
                // QTextFrameFormat()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTextFrameFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QTextFrameFormat(QTextFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFormat cppArg0 = Shiboken::Converter< ::QTextFormat >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QTextFrameFormat(QTextFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTextFrameFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QTextFrameFormat(QTextFrameFormat)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextFrameFormat cppArg0 = Shiboken::Converter< ::QTextFrameFormat >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QTextFrameFormat(QTextFrameFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTextFrameFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextFrameFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextFrameFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextFrameFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextFormat", "PySide.QtGui.QTextFrameFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextFrameFormat", overloads);
        return -1;
}

static PyObject* Sbk_QTextFrameFormatFunc_border(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // border()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->border();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_borderBrush(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // borderBrush()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QBrush cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->borderBrush();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_borderStyle(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // borderStyle()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextFrameFormat::BorderStyle cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->borderStyle();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextFrameFormat::BorderStyle >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_bottomMargin(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // bottomMargin()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->bottomMargin();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_height(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // height()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextLength cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->height();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextLength >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_isValid(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isValid()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->isValid();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_leftMargin(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // leftMargin()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->leftMargin();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_margin(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // margin()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->margin();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_padding(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // padding()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->padding();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_pageBreakPolicy(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // pageBreakPolicy()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QFlags<QTextFormat::PageBreakFlag> cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->pageBreakPolicy();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QFlags<QTextFormat::PageBreakFlag> >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_position(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // position()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextFrameFormat::Position cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->position();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextFrameFormat::Position >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_rightMargin(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // rightMargin()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->rightMargin();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_setBorder(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBorder(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setBorder(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setBorder_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setBorder(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBorder(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setBorder_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setBorder", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setBorderBrush(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBorderBrush(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(pyArg)) {
        overloadId = 0; // setBorderBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setBorderBrush_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QBrush cppArg0 = Shiboken::Converter< ::QBrush >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setBorderBrush(QBrush)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBorderBrush(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setBorderBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setBorderBrush", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setBorderStyle(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBorderStyle(QTextFrameFormat::BorderStyle)
    if (Shiboken::Converter< ::QTextFrameFormat::BorderStyle >::isConvertible(pyArg)) {
        overloadId = 0; // setBorderStyle(QTextFrameFormat::BorderStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setBorderStyle_TypeError;

    // Call function/method
    {
        QTextFrameFormat::BorderStyle cppArg0 = Shiboken::Converter< ::QTextFrameFormat::BorderStyle >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setBorderStyle(QTextFrameFormat::BorderStyle)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBorderStyle(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setBorderStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFrameFormat.BorderStyle", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setBorderStyle", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setBottomMargin(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomMargin(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setBottomMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setBottomMargin_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setBottomMargin(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setBottomMargin(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setBottomMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setBottomMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setHeight(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeight(QTextLength)
    // 1: setHeight(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 1; // setHeight(qreal)
    } else if (Shiboken::Converter< ::QTextLength >::isConvertible(pyArg)) {
        overloadId = 0; // setHeight(QTextLength)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setHeight_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setHeight(QTextLength)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QTextLength cppArg0 = Shiboken::Converter< ::QTextLength >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // setHeight(QTextLength)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setHeight(qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // setHeight(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setHeight_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextLength", "float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setHeight", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setLeftMargin(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeftMargin(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setLeftMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setLeftMargin_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLeftMargin(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLeftMargin(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setLeftMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setLeftMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setMargin(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMargin(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setMargin_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setMargin(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setMargin(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setPadding(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPadding(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setPadding_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setPadding(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPadding(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setPadding", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setPageBreakPolicy(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
    if (Shiboken::Converter< ::QFlags<QTextFormat::PageBreakFlag> >::isConvertible(pyArg)) {
        overloadId = 0; // setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setPageBreakPolicy_TypeError;

    // Call function/method
    {
        QFlags<QTextFormat::PageBreakFlag> cppArg0 = Shiboken::Converter< ::QFlags<QTextFormat::PageBreakFlag> >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPageBreakPolicy(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setPageBreakPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFormat.PageBreakFlags", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setPageBreakPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setPosition(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPosition(QTextFrameFormat::Position)
    if (Shiboken::Converter< ::QTextFrameFormat::Position >::isConvertible(pyArg)) {
        overloadId = 0; // setPosition(QTextFrameFormat::Position)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setPosition_TypeError;

    // Call function/method
    {
        QTextFrameFormat::Position cppArg0 = Shiboken::Converter< ::QTextFrameFormat::Position >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setPosition(QTextFrameFormat::Position)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setPosition(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setPosition_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFrameFormat.Position", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setPosition", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setRightMargin(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRightMargin(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setRightMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setRightMargin_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setRightMargin(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setRightMargin(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setRightMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setRightMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setTopMargin(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopMargin(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setTopMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setTopMargin_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setTopMargin(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setTopMargin(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setTopMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setTopMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_setWidth(PyObject* self, PyObject* pyArg)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(QTextLength)
    // 1: setWidth(qreal)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 1; // setWidth(qreal)
    } else if (Shiboken::Converter< ::QTextLength >::isConvertible(pyArg)) {
        overloadId = 0; // setWidth(QTextLength)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFrameFormatFunc_setWidth_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // setWidth(QTextLength)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QTextLength cppArg0 = Shiboken::Converter< ::QTextLength >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // setWidth(QTextLength)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // setWidth(qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // setWidth(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFrameFormatFunc_setWidth_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextLength", "float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTextFrameFormat.setWidth", overloads);
        return 0;
}

static PyObject* Sbk_QTextFrameFormatFunc_topMargin(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // topMargin()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->topMargin();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormatFunc_width(PyObject* self)
{
    ::QTextFrameFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // width()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTextLength cppResult = const_cast<const ::QTextFrameFormat*>(cppSelf)->width();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTextLength >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFrameFormat___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QTextFrameFormat& cppSelf = *(Shiboken::Converter< ::QTextFrameFormat* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QTextFrameFormat >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QTextFrameFormat_methods[] = {
    {"border", (PyCFunction)Sbk_QTextFrameFormatFunc_border, METH_NOARGS},
    {"borderBrush", (PyCFunction)Sbk_QTextFrameFormatFunc_borderBrush, METH_NOARGS},
    {"borderStyle", (PyCFunction)Sbk_QTextFrameFormatFunc_borderStyle, METH_NOARGS},
    {"bottomMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_bottomMargin, METH_NOARGS},
    {"height", (PyCFunction)Sbk_QTextFrameFormatFunc_height, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QTextFrameFormatFunc_isValid, METH_NOARGS},
    {"leftMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_leftMargin, METH_NOARGS},
    {"margin", (PyCFunction)Sbk_QTextFrameFormatFunc_margin, METH_NOARGS},
    {"padding", (PyCFunction)Sbk_QTextFrameFormatFunc_padding, METH_NOARGS},
    {"pageBreakPolicy", (PyCFunction)Sbk_QTextFrameFormatFunc_pageBreakPolicy, METH_NOARGS},
    {"position", (PyCFunction)Sbk_QTextFrameFormatFunc_position, METH_NOARGS},
    {"rightMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_rightMargin, METH_NOARGS},
    {"setBorder", (PyCFunction)Sbk_QTextFrameFormatFunc_setBorder, METH_O},
    {"setBorderBrush", (PyCFunction)Sbk_QTextFrameFormatFunc_setBorderBrush, METH_O},
    {"setBorderStyle", (PyCFunction)Sbk_QTextFrameFormatFunc_setBorderStyle, METH_O},
    {"setBottomMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_setBottomMargin, METH_O},
    {"setHeight", (PyCFunction)Sbk_QTextFrameFormatFunc_setHeight, METH_O},
    {"setLeftMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_setLeftMargin, METH_O},
    {"setMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_setMargin, METH_O},
    {"setPadding", (PyCFunction)Sbk_QTextFrameFormatFunc_setPadding, METH_O},
    {"setPageBreakPolicy", (PyCFunction)Sbk_QTextFrameFormatFunc_setPageBreakPolicy, METH_O},
    {"setPosition", (PyCFunction)Sbk_QTextFrameFormatFunc_setPosition, METH_O},
    {"setRightMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_setRightMargin, METH_O},
    {"setTopMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_setTopMargin, METH_O},
    {"setWidth", (PyCFunction)Sbk_QTextFrameFormatFunc_setWidth, METH_O},
    {"topMargin", (PyCFunction)Sbk_QTextFrameFormatFunc_topMargin, METH_NOARGS},
    {"width", (PyCFunction)Sbk_QTextFrameFormatFunc_width, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextFrameFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static int Sbk_QTextFrameFormat_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QTextFrameFormat_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextFrameFormat_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QTextFrameFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QTextFrameFormat_traverse,
    /*tp_clear*/            Sbk_QTextFrameFormat_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextFrameFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextFrameFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextFrameFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextFrameFormat_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QTextFrameFormat", "QTextFrameFormat",
        &Sbk_QTextFrameFormat_Type, &Shiboken::callCppDestructor< ::QTextFrameFormat >, (SbkObjectType*)SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_IDX])) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'Position'.
    SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_POSITION_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QTextFrameFormat_Type,
        "Position",
        "PySide.QtGui.QTextFrameFormat.Position",
        "QTextFrameFormat::Position");
    if (!SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_POSITION_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_POSITION_IDX],
        &Sbk_QTextFrameFormat_Type, "InFlow", (long) QTextFrameFormat::InFlow))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_POSITION_IDX],
        &Sbk_QTextFrameFormat_Type, "FloatLeft", (long) QTextFrameFormat::FloatLeft))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_POSITION_IDX],
        &Sbk_QTextFrameFormat_Type, "FloatRight", (long) QTextFrameFormat::FloatRight))
        return ;
    // End of 'Position' enum.

    // Initialization of enum 'BorderStyle'.
    SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QTextFrameFormat_Type,
        "BorderStyle",
        "PySide.QtGui.QTextFrameFormat.BorderStyle",
        "QTextFrameFormat::BorderStyle");
    if (!SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_None", (long) QTextFrameFormat::BorderStyle_None))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_Dotted", (long) QTextFrameFormat::BorderStyle_Dotted))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_Dashed", (long) QTextFrameFormat::BorderStyle_Dashed))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_Solid", (long) QTextFrameFormat::BorderStyle_Solid))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_Double", (long) QTextFrameFormat::BorderStyle_Double))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_DotDash", (long) QTextFrameFormat::BorderStyle_DotDash))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_DotDotDash", (long) QTextFrameFormat::BorderStyle_DotDotDash))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_Groove", (long) QTextFrameFormat::BorderStyle_Groove))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_Ridge", (long) QTextFrameFormat::BorderStyle_Ridge))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_Inset", (long) QTextFrameFormat::BorderStyle_Inset))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTEXTFRAMEFORMAT_BORDERSTYLE_IDX],
        &Sbk_QTextFrameFormat_Type, "BorderStyle_Outset", (long) QTextFrameFormat::BorderStyle_Outset))
        return ;
    // End of 'BorderStyle' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QTextFrameFormat >("QTextFrameFormat");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QTextFrameFormat >("QTextFrameFormat*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QTextFrameFormat >(typeid(::QTextFrameFormat).name());
    qRegisterMetaType< ::QTextFrameFormat >("QTextFrameFormat");
    qRegisterMetaType< ::QTextFrameFormat::Position >("QTextFrameFormat::Position");
    qRegisterMetaType< ::QTextFrameFormat::BorderStyle >("QTextFrameFormat::BorderStyle");
}
