/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtransform_wrapper.h"

// Extra includes
#include <qdatastream.h>
#include <qline.h>
#include <qmatrix.h>
#include <qpainterpath.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>
#include <qtransform.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTransform_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTransform >()))
        return -1;

    ::QTransform* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 9) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform(): too many arguments");
        return -1;
    } else if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 7)
        goto Sbk_QTransform_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOOOOOOO:QTransform", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])))
        return -1;


    // Overloaded function decisor
    // 0: QTransform()
    // 1: QTransform(QMatrix)
    // 2: QTransform(QTransform)
    // 3: QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    // 4: QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QTransform()
    } else if (numArgs >= 6
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])
        && SbkNumber_Check(pyArgs[4])
        && SbkNumber_Check(pyArgs[5])) {
        if (numArgs == 6) {
            overloadId = 4; // QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
        } else if (numArgs >= 8
            && SbkNumber_Check(pyArgs[6])
            && SbkNumber_Check(pyArgs[7])) {
            if (numArgs == 8) {
                overloadId = 3; // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            } else if (SbkNumber_Check(pyArgs[8])) {
                overloadId = 3; // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            }
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QTransform >::isConvertible(pyArgs[0])) {
        overloadId = 2; // QTransform(QTransform)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QMatrix >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QTransform(QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransform_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QTransform()
        {

            if(!PyErr_Occurred()) {
                // QTransform()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTransform();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QTransform(QMatrix)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QMatrix cppArg0 = Shiboken::Converter< ::QMatrix >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QTransform(QMatrix)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTransform(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QTransform(QTransform)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTransform cppArg0 = Shiboken::Converter< ::QTransform >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QTransform(QTransform)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTransform(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "h33");
                if (value) {
                    if (pyArgs[8])
                        errorArgName = "h33";
                    else if (SbkNumber_Check(value))
                        pyArgs[8] = value;
                    else
                        goto Sbk_QTransform_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
            qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
            qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);
            qreal cppArg4 = Shiboken::Converter< double >::toCpp(pyArgs[4]);
            qreal cppArg5 = Shiboken::Converter< double >::toCpp(pyArgs[5]);
            qreal cppArg6 = Shiboken::Converter< double >::toCpp(pyArgs[6]);
            qreal cppArg7 = Shiboken::Converter< double >::toCpp(pyArgs[7]);
            qreal cppArg8 = pyArgs[8] ? Shiboken::Converter< double >::toCpp(pyArgs[8]) : 1.0;

            if(!PyErr_Occurred()) {
                // QTransform(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTransform(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
            qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
            qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);
            qreal cppArg4 = Shiboken::Converter< double >::toCpp(pyArgs[4]);
            qreal cppArg5 = Shiboken::Converter< double >::toCpp(pyArgs[5]);

            if(!PyErr_Occurred()) {
                // QTransform(qreal,qreal,qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QTransform(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTransform >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTransform_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTransform_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", "float, float, float, float, float, float, float, float, float = 1.0", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform", overloads);
        return -1;
}

static PyObject* Sbk_QTransformFunc___reduce__(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __reduce__()
            // Begin code injection

            // TEMPLATE - reduce_code - START
            pyResult = Py_BuildValue("(N(ddddddddd))", PyObject_Type(self), cppSelf->m11(), cppSelf->m12(), cppSelf->m13(), cppSelf->m21(), cppSelf->m22(), cppSelf->m23(), cppSelf->m31(), cppSelf->m32(), cppSelf->m33());
            // TEMPLATE - reduce_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc___repr__(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // __repr__()
            // Begin code injection

            // TEMPLATE - repr_code - START
            QString format = QString().sprintf("%s(%f, %f, %f, %f, %f, %f, %f, %f, %f)", ((PyObject*)self)->ob_type->tp_name, cppSelf->m11(), cppSelf->m12(), cppSelf->m13(), cppSelf->m21(), cppSelf->m22(), cppSelf->m23(), cppSelf->m31(), cppSelf->m32(), cppSelf->m33());
            pyResult = Shiboken::String::fromCString(qPrintable(format));
            // TEMPLATE - repr_code - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_adjoint(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // adjoint()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform cppResult = const_cast<const ::QTransform*>(cppSelf)->adjoint();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_det(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // det()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->det();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_determinant(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // determinant()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->determinant();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_dx(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // dx()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->dx();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_dy(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // dy()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->dy();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_fromScale(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromScale", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromScale(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 0; // fromScale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_fromScale_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // fromScale(qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform cppResult = QTransform::fromScale(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_fromScale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.fromScale", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_fromTranslate(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromTranslate", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromTranslate(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 0; // fromTranslate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_fromTranslate_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // fromTranslate(qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform cppResult = QTransform::fromTranslate(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_fromTranslate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.fromTranslate", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_inverted(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {
        bool* removed_cppArg0 = 0;
        SBK_UNUSED(removed_cppArg0)

        if(!PyErr_Occurred()) {
            // inverted(bool*)const
            // Begin code injection

            // TEMPLATE - fix_bool* - START
            bool ok_;
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform retval_ = cppSelf->inverted(&ok_);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::makeTuple(retval_, ok_);
            // TEMPLATE - fix_bool* - END

            // End of code injection


        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_isAffine(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isAffine()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTransform*>(cppSelf)->isAffine();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_isIdentity(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isIdentity()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTransform*>(cppSelf)->isIdentity();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_isInvertible(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isInvertible()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTransform*>(cppSelf)->isInvertible();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_isRotating(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isRotating()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTransform*>(cppSelf)->isRotating();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_isScaling(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isScaling()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTransform*>(cppSelf)->isScaling();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_isTranslating(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isTranslating()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QTransform*>(cppSelf)->isTranslating();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m11(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m11()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m11();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m12(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m12()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m12();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m13(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m13()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m13();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m21(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m21()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m21();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m22(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m22()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m22();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m23(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m23()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m23();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m31(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m31()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m31();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m32(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m32()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m32();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_m33(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // m33()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qreal cppResult = const_cast<const ::QTransform*>(cppSelf)->m33();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< double >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_map(PyObject* self, PyObject* args)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "map", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: map(QLine)const
    // 1: map(QLineF)const
    // 2: map(QPainterPath)const
    // 3: map(QPoint)const
    // 4: map(QPointF)const
    // 5: map(QPolygon)const
    // 6: map(QPolygonF)const
    // 7: map(QRegion)const
    // 8: map(qreal,qreal,qreal*,qreal*)const
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 8; // map(qreal,qreal,qreal*,qreal*)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPolygon >::isConvertible(pyArgs[0])) {
        overloadId = 5; // map(QPolygon)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QRegion >::isConvertible(pyArgs[0])) {
        overloadId = 7; // map(QRegion)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPolygonF >::isConvertible(pyArgs[0])) {
        overloadId = 6; // map(QPolygonF)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[0])) {
        overloadId = 3; // map(QPoint)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArgs[0])) {
        overloadId = 4; // map(QPointF)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPainterPath >::isConvertible(pyArgs[0])) {
        overloadId = 2; // map(QPainterPath)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QLine >::isConvertible(pyArgs[0])) {
        overloadId = 0; // map(QLine)const
    } else if (numArgs == 1
        && Shiboken::Converter< ::QLineF >::isConvertible(pyArgs[0])) {
        overloadId = 1; // map(QLineF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_map_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // map(QLine)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QLine cppArg0 = Shiboken::Converter< ::QLine >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // map(QLine)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLine cppResult = const_cast<const ::QTransform*>(cppSelf)->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLine >::toPython(cppResult);
            }
            break;
        }
        case 1: // map(QLineF)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QLineF cppArg0 = Shiboken::Converter< ::QLineF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // map(QLineF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLineF cppResult = const_cast<const ::QTransform*>(cppSelf)->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLineF >::toPython(cppResult);
            }
            break;
        }
        case 2: // map(QPainterPath)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPainterPath cppArg0 = Shiboken::Converter< ::QPainterPath >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // map(QPainterPath)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPainterPath cppResult = const_cast<const ::QTransform*>(cppSelf)->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
            }
            break;
        }
        case 3: // map(QPoint)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // map(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const ::QTransform*>(cppSelf)->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
            break;
        }
        case 4: // map(QPointF)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // map(QPointF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const ::QTransform*>(cppSelf)->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
            break;
        }
        case 5: // map(QPolygon)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPolygon cppArg0 = Shiboken::Converter< ::QPolygon >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // map(QPolygon)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygon cppResult = const_cast<const ::QTransform*>(cppSelf)->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
            }
            break;
        }
        case 6: // map(QPolygonF)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPolygonF cppArg0 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // map(QPolygonF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygonF cppResult = const_cast<const ::QTransform*>(cppSelf)->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
            }
            break;
        }
        case 7: // map(QRegion)const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QRegion cppArg0 = Shiboken::Converter< ::QRegion >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // map(QRegion)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRegion cppResult = const_cast<const ::QTransform*>(cppSelf)->map(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRegion >::toPython(cppResult);
            }
            break;
        }
        case 8: // map(qreal,qreal,qreal*,qreal*)const
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
            qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // map(qreal,qreal,qreal*,qreal*)const
                // Begin code injection

                // TEMPLATE - fix_args,number*,number* - START
                qreal a, b;
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->map(cppArg0, cppArg1, &a, &b);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(a, b);
                // TEMPLATE - fix_args,number*,number* - END

                // End of code injection


            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_map_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtGui.QPainterPath", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", "PySide.QtGui.QRegion", "float, float, PySide.QtCore.qreal, PySide.QtCore.qreal", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.map", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_mapRect(PyObject* self, PyObject* pyArg)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapRect(QRect)const
    // 1: mapRect(QRectF)const
    if (Shiboken::Converter< ::QRect >::isConvertible(pyArg)) {
        overloadId = 0; // mapRect(QRect)const
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyArg)) {
        overloadId = 1; // mapRect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_mapRect_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // mapRect(QRect)const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QRect cppArg0 = Shiboken::Converter< ::QRect >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // mapRect(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const ::QTransform*>(cppSelf)->mapRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
            break;
        }
        case 1: // mapRect(QRectF)const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QRectF cppArg0 = Shiboken::Converter< ::QRectF >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // mapRect(QRectF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = const_cast<const ::QTransform*>(cppSelf)->mapRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_mapRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.mapRect", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_mapToPolygon(PyObject* self, PyObject* pyArg)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapToPolygon(QRect)const
    if (Shiboken::Converter< ::QRect >::isConvertible(pyArg)) {
        overloadId = 0; // mapToPolygon(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_mapToPolygon_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QRect cppArg0 = Shiboken::Converter< ::QRect >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // mapToPolygon(QRect)const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QPolygon cppResult = const_cast<const ::QTransform*>(cppSelf)->mapToPolygon(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_mapToPolygon_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.mapToPolygon", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_quadToQuad(PyObject* self, PyObject* args)
{
    ::QTransform* cppSelf = 0;
    if (self) {
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    }
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "quadToQuad", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: quadToQuad(QPolygonF,QPolygonF)
    // 1: quadToQuad(QPolygonF,QPolygonF,QTransform&)
    if (numArgs >= 2
        && Shiboken::Converter< ::QPolygonF >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QPolygonF >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // quadToQuad(QPolygonF,QPolygonF)
        } else if (numArgs == 3
            && Shiboken::Converter< ::QTransform & >::isConvertible(pyArgs[2])) {
            overloadId = 1; // quadToQuad(QPolygonF,QPolygonF,QTransform&)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_quadToQuad_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // quadToQuad(QPolygonF,QPolygonF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            QPolygonF cppArg0 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[0]);
            SBK_UNUSED(cppArg0)
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            QPolygonF cppArg1 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[1]);
            SBK_UNUSED(cppArg1)

            if(!PyErr_Occurred()) {
                // quadToQuad(QPolygonF,QPolygonF)
                // Begin code injection

                QTransform _result;
                if (QTransform::quadToQuad(cppArg0, cppArg1, _result)) {
                    pyResult = Shiboken::Converter< ::QTransform >::toPython(_result);
                } else {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                }

                // End of code injection


            }
            break;
        }
        case 1: // quadToQuad(QPolygonF,QPolygonF,QTransform&)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPolygonF cppArg0 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            ::QPolygonF cppArg1 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[1]);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return 0;
            QTransform & cppArg2 = Shiboken::Converter< ::QTransform & >::toCpp(pyArgs[2]);

            if(!PyErr_Occurred()) {
                // quadToQuad(QPolygonF,QPolygonF,QTransform&)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QTransform::quadToQuad(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_quadToQuad_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF, PySide.QtGui.QPolygonF", "PySide.QtGui.QPolygonF, PySide.QtGui.QPolygonF, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.quadToQuad", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_quadToSquare(PyObject* self, PyObject* args)
{
    ::QTransform* cppSelf = 0;
    if (self) {
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    }
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "quadToSquare", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: quadToSquare(QPolygonF)
    // 1: quadToSquare(QPolygonF,QTransform&)
    if (Shiboken::Converter< ::QPolygonF >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // quadToSquare(QPolygonF)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QTransform & >::isConvertible(pyArgs[1])) {
            overloadId = 1; // quadToSquare(QPolygonF,QTransform&)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_quadToSquare_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // quadToSquare(QPolygonF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            QPolygonF cppArg0 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[0]);
            SBK_UNUSED(cppArg0)

            if(!PyErr_Occurred()) {
                // quadToSquare(QPolygonF)
                // Begin code injection

                QTransform _result;
                if (QTransform::quadToSquare(cppArg0, _result)) {
                    pyResult = Shiboken::Converter< ::QTransform >::toPython(_result);
                } else {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                }

                // End of code injection


            }
            break;
        }
        case 1: // quadToSquare(QPolygonF,QTransform&)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPolygonF cppArg0 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            QTransform & cppArg1 = Shiboken::Converter< ::QTransform & >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // quadToSquare(QPolygonF,QTransform&)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QTransform::quadToSquare(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_quadToSquare_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", "PySide.QtGui.QPolygonF, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.quadToSquare", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_reset(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // reset()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->reset();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTransformFunc_rotate(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform.rotate(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform.rotate(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:rotate", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rotate(qreal,Qt::Axis)
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // rotate(qreal,Qt::Axis)
        } else if (Shiboken::Converter< ::Qt::Axis >::isConvertible(pyArgs[1])) {
            overloadId = 0; // rotate(qreal,Qt::Axis)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_rotate_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "axis");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "axis";
                else if (Shiboken::Converter< ::Qt::Axis >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QTransformFunc_rotate_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform.rotate(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        Qt::Axis cppArg1 = pyArgs[1] ? Shiboken::Converter< ::Qt::Axis >::toCpp(pyArgs[1]) : Qt::ZAxis;

        if(!PyErr_Occurred()) {
            // rotate(qreal,Qt::Axis)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform & cppResult = cppSelf->rotate(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform & >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_rotate_TypeError:
        const char* overloads[] = {"float, PySide.QtCore.Qt.Axis = Qt.ZAxis", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.rotate", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_rotateRadians(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform.rotateRadians(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTransform.rotateRadians(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:rotateRadians", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: rotateRadians(qreal,Qt::Axis)
    if (SbkNumber_Check(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // rotateRadians(qreal,Qt::Axis)
        } else if (Shiboken::Converter< ::Qt::Axis >::isConvertible(pyArgs[1])) {
            overloadId = 0; // rotateRadians(qreal,Qt::Axis)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_rotateRadians_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "axis");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "axis";
                else if (Shiboken::Converter< ::Qt::Axis >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QTransformFunc_rotateRadians_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTransform.rotateRadians(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        Qt::Axis cppArg1 = pyArgs[1] ? Shiboken::Converter< ::Qt::Axis >::toCpp(pyArgs[1]) : Qt::ZAxis;

        if(!PyErr_Occurred()) {
            // rotateRadians(qreal,Qt::Axis)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform & cppResult = cppSelf->rotateRadians(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform & >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_rotateRadians_TypeError:
        const char* overloads[] = {"float, PySide.QtCore.Qt.Axis = Qt.ZAxis", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.rotateRadians", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_scale(PyObject* self, PyObject* args)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_scale_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // scale(qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform & cppResult = cppSelf->scale(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform & >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_scale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.scale", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_setMatrix(PyObject* self, PyObject* args)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMatrix", 9, 9, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])))
        return 0;


    // Overloaded function decisor
    // 0: setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 9
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])
        && SbkNumber_Check(pyArgs[2])
        && SbkNumber_Check(pyArgs[3])
        && SbkNumber_Check(pyArgs[4])
        && SbkNumber_Check(pyArgs[5])
        && SbkNumber_Check(pyArgs[6])
        && SbkNumber_Check(pyArgs[7])
        && SbkNumber_Check(pyArgs[8])) {
        overloadId = 0; // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_setMatrix_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);
        qreal cppArg2 = Shiboken::Converter< double >::toCpp(pyArgs[2]);
        qreal cppArg3 = Shiboken::Converter< double >::toCpp(pyArgs[3]);
        qreal cppArg4 = Shiboken::Converter< double >::toCpp(pyArgs[4]);
        qreal cppArg5 = Shiboken::Converter< double >::toCpp(pyArgs[5]);
        qreal cppArg6 = Shiboken::Converter< double >::toCpp(pyArgs[6]);
        qreal cppArg7 = Shiboken::Converter< double >::toCpp(pyArgs[7]);
        qreal cppArg8 = Shiboken::Converter< double >::toCpp(pyArgs[8]);

        if(!PyErr_Occurred()) {
            // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setMatrix(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTransformFunc_setMatrix_TypeError:
        const char* overloads[] = {"float, float, float, float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.setMatrix", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_shear(PyObject* self, PyObject* args)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_shear_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // shear(qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform & cppResult = cppSelf->shear(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform & >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.shear", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_squareToQuad(PyObject* self, PyObject* args)
{
    ::QTransform* cppSelf = 0;
    if (self) {
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    }
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "squareToQuad", 1, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: squareToQuad(QPolygonF)
    // 1: squareToQuad(QPolygonF,QTransform&)
    if (Shiboken::Converter< ::QPolygonF >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // squareToQuad(QPolygonF)
        } else if (numArgs == 2
            && Shiboken::Converter< ::QTransform & >::isConvertible(pyArgs[1])) {
            overloadId = 1; // squareToQuad(QPolygonF,QTransform&)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_squareToQuad_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // squareToQuad(QPolygonF)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            QPolygonF cppArg0 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[0]);
            SBK_UNUSED(cppArg0)

            if(!PyErr_Occurred()) {
                // squareToQuad(QPolygonF)
                // Begin code injection

                QTransform _result;
                if (QTransform::squareToQuad(cppArg0, _result)) {
                    pyResult = Shiboken::Converter< ::QTransform >::toPython(_result);
                } else {
                    Py_INCREF(Py_None);
                    pyResult = Py_None;
                }

                // End of code injection


            }
            break;
        }
        case 1: // squareToQuad(QPolygonF,QTransform&)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return 0;
            ::QPolygonF cppArg0 = Shiboken::Converter< ::QPolygonF >::toCpp(pyArgs[0]);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return 0;
            QTransform & cppArg1 = Shiboken::Converter< ::QTransform & >::toCpp(pyArgs[1]);

            if(!PyErr_Occurred()) {
                // squareToQuad(QPolygonF,QTransform&)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QTransform::squareToQuad(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
            break;
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_squareToQuad_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", "PySide.QtGui.QPolygonF, PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.squareToQuad", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_toAffine(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // toAffine()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QMatrix & cppResult = const_cast<const ::QTransform*>(cppSelf)->toAffine();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QMatrix >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_translate(PyObject* self, PyObject* args)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(qreal,qreal)
    if (numArgs == 2
        && SbkNumber_Check(pyArgs[0])
        && SbkNumber_Check(pyArgs[1])) {
        overloadId = 0; // translate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc_translate_TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArgs[0]);
        qreal cppArg1 = Shiboken::Converter< double >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // translate(qreal,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform & cppResult = cppSelf->translate(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform & >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc_translate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTransform.translate", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc_transposed(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // transposed()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform cppResult = const_cast<const ::QTransform*>(cppSelf)->transposed();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransformFunc_type(PyObject* self)
{
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // type()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform::TransformationType cppResult = const_cast<const ::QTransform*>(cppSelf)->type();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform::TransformationType >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTransform___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QTransform& cppSelf = *(Shiboken::Converter< ::QTransform* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QTransform >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QTransformMethod_quadToQuad = {
    "quadToQuad", (PyCFunction)Sbk_QTransformFunc_quadToQuad, METH_VARARGS|METH_STATIC
};

static PyMethodDef Sbk_QTransformMethod_quadToSquare = {
    "quadToSquare", (PyCFunction)Sbk_QTransformFunc_quadToSquare, METH_VARARGS|METH_STATIC
};

static PyMethodDef Sbk_QTransformMethod_squareToQuad = {
    "squareToQuad", (PyCFunction)Sbk_QTransformFunc_squareToQuad, METH_VARARGS|METH_STATIC
};

static PyMethodDef Sbk_QTransform_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QTransformFunc___reduce__, METH_NOARGS},
    {"adjoint", (PyCFunction)Sbk_QTransformFunc_adjoint, METH_NOARGS},
    {"det", (PyCFunction)Sbk_QTransformFunc_det, METH_NOARGS},
    {"determinant", (PyCFunction)Sbk_QTransformFunc_determinant, METH_NOARGS},
    {"dx", (PyCFunction)Sbk_QTransformFunc_dx, METH_NOARGS},
    {"dy", (PyCFunction)Sbk_QTransformFunc_dy, METH_NOARGS},
    {"fromScale", (PyCFunction)Sbk_QTransformFunc_fromScale, METH_VARARGS|METH_STATIC},
    {"fromTranslate", (PyCFunction)Sbk_QTransformFunc_fromTranslate, METH_VARARGS|METH_STATIC},
    {"inverted", (PyCFunction)Sbk_QTransformFunc_inverted, METH_NOARGS},
    {"isAffine", (PyCFunction)Sbk_QTransformFunc_isAffine, METH_NOARGS},
    {"isIdentity", (PyCFunction)Sbk_QTransformFunc_isIdentity, METH_NOARGS},
    {"isInvertible", (PyCFunction)Sbk_QTransformFunc_isInvertible, METH_NOARGS},
    {"isRotating", (PyCFunction)Sbk_QTransformFunc_isRotating, METH_NOARGS},
    {"isScaling", (PyCFunction)Sbk_QTransformFunc_isScaling, METH_NOARGS},
    {"isTranslating", (PyCFunction)Sbk_QTransformFunc_isTranslating, METH_NOARGS},
    {"m11", (PyCFunction)Sbk_QTransformFunc_m11, METH_NOARGS},
    {"m12", (PyCFunction)Sbk_QTransformFunc_m12, METH_NOARGS},
    {"m13", (PyCFunction)Sbk_QTransformFunc_m13, METH_NOARGS},
    {"m21", (PyCFunction)Sbk_QTransformFunc_m21, METH_NOARGS},
    {"m22", (PyCFunction)Sbk_QTransformFunc_m22, METH_NOARGS},
    {"m23", (PyCFunction)Sbk_QTransformFunc_m23, METH_NOARGS},
    {"m31", (PyCFunction)Sbk_QTransformFunc_m31, METH_NOARGS},
    {"m32", (PyCFunction)Sbk_QTransformFunc_m32, METH_NOARGS},
    {"m33", (PyCFunction)Sbk_QTransformFunc_m33, METH_NOARGS},
    {"map", (PyCFunction)Sbk_QTransformFunc_map, METH_VARARGS},
    {"mapRect", (PyCFunction)Sbk_QTransformFunc_mapRect, METH_O},
    {"mapToPolygon", (PyCFunction)Sbk_QTransformFunc_mapToPolygon, METH_O},
    Sbk_QTransformMethod_quadToQuad,
    Sbk_QTransformMethod_quadToSquare,
    {"reset", (PyCFunction)Sbk_QTransformFunc_reset, METH_NOARGS},
    {"rotate", (PyCFunction)Sbk_QTransformFunc_rotate, METH_VARARGS|METH_KEYWORDS},
    {"rotateRadians", (PyCFunction)Sbk_QTransformFunc_rotateRadians, METH_VARARGS|METH_KEYWORDS},
    {"scale", (PyCFunction)Sbk_QTransformFunc_scale, METH_VARARGS},
    {"setMatrix", (PyCFunction)Sbk_QTransformFunc_setMatrix, METH_VARARGS},
    {"shear", (PyCFunction)Sbk_QTransformFunc_shear, METH_VARARGS},
    Sbk_QTransformMethod_squareToQuad,
    {"toAffine", (PyCFunction)Sbk_QTransformFunc_toAffine, METH_NOARGS},
    {"translate", (PyCFunction)Sbk_QTransformFunc_translate, METH_VARARGS},
    {"transposed", (PyCFunction)Sbk_QTransformFunc_transposed, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QTransformFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTransform___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QTransform_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        // Search the method in the instance dict
        if (reinterpret_cast<SbkObject*>(self)->ob_dict) {
            PyObject* meth = PyDict_GetItem(reinterpret_cast<SbkObject*>(self)->ob_dict, name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        // Search the method in the type dict
        if (Shiboken::Object::isUserType(self)) {
            PyObject* meth = PyDict_GetItem(self->ob_type->tp_dict, name);
            if (meth)
                return PyFunction_Check(meth) ? SBK_PyMethod_New(meth, self) : PyObject_GenericGetAttr(self, name);
        }
        if (Shiboken::String::compare(name, "quadToQuad") == 0)
            return PyCFunction_NewEx(&Sbk_QTransformMethod_quadToQuad, self, 0);
        if (Shiboken::String::compare(name, "quadToSquare") == 0)
            return PyCFunction_NewEx(&Sbk_QTransformMethod_quadToSquare, self, 0);
        if (Shiboken::String::compare(name, "squareToQuad") == 0)
            return PyCFunction_NewEx(&Sbk_QTransformMethod_squareToQuad, self, 0);
    }
    return PyObject_GenericGetAttr(self, name);
}

static PyObject* Sbk_QTransformFunc___mul__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QLine,QTransform)
    // 1: operator*(QLineF,QTransform)
    // 2: operator*(QPoint,QTransform)
    // 3: operator*(QPointF,QTransform)
    // 4: operator*(QTransform)const
    // 5: operator*(QTransform,qreal)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 5; // operator*(QTransform,qreal)
    } else if (!isReverse
        && Shiboken::Converter< ::QTransform >::isConvertible(pyArg)) {
        overloadId = 4; // operator*(QTransform)const
    } else if (isReverse
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArg)) {
        overloadId = 2; // operator*(QPoint,QTransform)
    } else if (isReverse
        && Shiboken::Converter< ::QPointF >::isConvertible(pyArg)) {
        overloadId = 3; // operator*(QPointF,QTransform)
    } else if (isReverse
        && Shiboken::Converter< ::QLine >::isConvertible(pyArg)) {
        overloadId = 0; // operator*(QLine,QTransform)
    } else if (isReverse
        && Shiboken::Converter< ::QLineF >::isConvertible(pyArg)) {
        overloadId = 1; // operator*(QLineF,QTransform)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___mul___TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // operator*(QLine,QTransform)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QLine cppArg0 = Shiboken::Converter< ::QLine >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*(QLine,QTransform) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLine cppResult = (cppArg0) * (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLine >::toPython(cppResult);
            }
            break;
        }
        case 1: // operator*(QLineF,QTransform)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QLineF cppArg0 = Shiboken::Converter< ::QLineF >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*(QLineF,QTransform) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLineF cppResult = (cppArg0) * (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLineF >::toPython(cppResult);
            }
            break;
        }
        case 2: // operator*(QPoint,QTransform)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QPoint cppArg0 = Shiboken::Converter< ::QPoint >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*(QPoint,QTransform) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = (cppArg0) * (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
            break;
        }
        case 3: // operator*(QPointF,QTransform)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QPointF cppArg0 = Shiboken::Converter< ::QPointF >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*(QPointF,QTransform) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = (cppArg0) * (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
            break;
        }
        case 4: // operator*(QTransform)const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QTransform cppArg0 = Shiboken::Converter< ::QTransform >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*(QTransform)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTransform cppResult = (*cppSelf) * (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
            break;
        }
        case 5: // operator*(QTransform,qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*(QTransform,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTransform cppResult = (*cppSelf) * cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
            }
            break;
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QTransform", "float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___imul__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QTransform)
    // 1: operator*=(qreal)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse
        && Shiboken::Converter< ::QTransform >::isConvertible(pyArg)) {
        overloadId = 0; // operator*=(QTransform)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___imul___TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // operator*=(QTransform)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return 0;
            ::QTransform cppArg0 = Shiboken::Converter< ::QTransform >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*=(QTransform)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) *= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // operator*=(qreal)
        {
            qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

            if(!PyErr_Occurred()) {
                // operator*=(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) *= cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QTransformFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform", "float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__imul__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___add__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QTransform,qreal)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 0; // operator+(QTransform,qreal)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___add___TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator+(QTransform,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform cppResult = (*cppSelf) + cppArg0;
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc___add___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___iadd__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(qreal)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 0; // operator+=(qreal)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___iadd___TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator+=(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            (*cppSelf) += cppArg0;
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QTransformFunc___iadd___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___sub__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QTransform,qreal)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 0; // operator-(QTransform,qreal)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___sub___TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator-(QTransform,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform cppResult = (*cppSelf) - cppArg0;
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc___sub___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__sub__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___isub__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(qreal)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 0; // operator-=(qreal)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___isub___TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator-=(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            (*cppSelf) -= cppArg0;
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QTransformFunc___isub___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__isub__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___div__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QTransform,qreal)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 0; // operator/(QTransform,qreal)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___div___TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator/(QTransform,qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTransform cppResult = (*cppSelf) / cppArg0;
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__div__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___idiv__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse
        && SbkNumber_Check(pyArg)) {
        overloadId = 0; // operator/=(qreal)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___idiv___TypeError;

    // Call function/method
    {
        qreal cppArg0 = Shiboken::Converter< double >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator/=(qreal)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            (*cppSelf) /= cppArg0;
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QTransformFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__idiv__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___lshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QTransform)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator<<(QDataStream&,QTransform)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___lshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator<<(QDataStream&,QTransform) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) << (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QTransformFunc___rshift__(PyObject* self, PyObject* pyArg)
{
    bool isReverse = Shiboken::Converter< ::QTransform >::checkType(pyArg)
                    && !Shiboken::Converter< ::QTransform >::checkType(self);
    if (isReverse)
        std::swap(self, pyArg);
    ::QTransform* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTransform* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttrString(pyArg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(pyArg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QTransform&)
    if (isReverse
        && Shiboken::Converter< ::QDataStream & >::isConvertible(pyArg)) {
        overloadId = 0; // operator>>(QDataStream&,QTransform&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTransformFunc___rshift___TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        QDataStream & cppArg0 = Shiboken::Converter< ::QDataStream & >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // operator>>(QDataStream&,QTransform&) [reverse operator]
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QDataStream & cppResult = (cppArg0) >> (*cppSelf);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
        }
    }

    } // End of "if (!pyResult)"

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTransformFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtGui.QTransform.__rshift__", overloads);
        return 0;
}

// Rich comparison
static PyObject* Sbk_QTransform_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QTransform& cppSelf = *(Shiboken::Converter< ::QTransform* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QTransform >::isConvertible(pyArg)) {
                // operator!=(const QTransform & arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QTransform cppArg0 = Shiboken::Converter< ::QTransform >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QTransform >::isConvertible(pyArg)) {
                // operator==(const QTransform & arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QTransform cppArg0 = Shiboken::Converter< ::QTransform >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QTransform_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QTransform_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QTransform_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QTransform_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTransform_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtGui.QTransform",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QTransformFunc___repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         Sbk_QTransform_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QTransform_traverse,
    /*tp_clear*/            Sbk_QTransform_clear,
    /*tp_richcompare*/      Sbk_QTransform_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTransform_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTransform_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTransform(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QTransform_Type.super.as_number, 0, sizeof(PyNumberMethods));
    Sbk_QTransform_Type.super.as_number.nb_rshift = Sbk_QTransformFunc___rshift__;
    Sbk_QTransform_Type.super.as_number.nb_subtract = Sbk_QTransformFunc___sub__;
#ifndef IS_PY3K
    Sbk_QTransform_Type.super.as_number.nb_divide = Sbk_QTransformFunc___idiv__;
#endif
    Sbk_QTransform_Type.super.as_number.nb_inplace_subtract = Sbk_QTransformFunc___isub__;
    Sbk_QTransform_Type.super.as_number.nb_lshift = Sbk_QTransformFunc___lshift__;
    Sbk_QTransform_Type.super.as_number.nb_multiply = Sbk_QTransformFunc___imul__;
#ifndef IS_PY3K
    Sbk_QTransform_Type.super.as_number.nb_divide = Sbk_QTransformFunc___div__;
#endif
    Sbk_QTransform_Type.super.as_number.nb_inplace_add = Sbk_QTransformFunc___iadd__;
    Sbk_QTransform_Type.super.as_number.nb_add = Sbk_QTransformFunc___add__;
    Sbk_QTransform_Type.super.as_number.nb_multiply = Sbk_QTransformFunc___mul__;
    Sbk_QTransform_Type.super.as_number.nb_true_divide = Sbk_QTransformFunc___div__;
    Sbk_QTransform_Type.super.ht_type.tp_as_number = &Sbk_QTransform_Type.super.as_number;

    SbkPySide_QtGuiTypes[SBK_QTRANSFORM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTransform_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QTransform", "QTransform",
        &Sbk_QTransform_Type, &Shiboken::callCppDestructor< ::QTransform >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'TransformationType'.
    SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QTransform_Type,
        "TransformationType",
        "PySide.QtGui.QTransform.TransformationType",
        "QTransform::TransformationType");
    if (!SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX],
        &Sbk_QTransform_Type, "TxNone", (long) QTransform::TxNone))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX],
        &Sbk_QTransform_Type, "TxTranslate", (long) QTransform::TxTranslate))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX],
        &Sbk_QTransform_Type, "TxScale", (long) QTransform::TxScale))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX],
        &Sbk_QTransform_Type, "TxRotate", (long) QTransform::TxRotate))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX],
        &Sbk_QTransform_Type, "TxShear", (long) QTransform::TxShear))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtGuiTypes[SBK_QTRANSFORM_TRANSFORMATIONTYPE_IDX],
        &Sbk_QTransform_Type, "TxProject", (long) QTransform::TxProject))
        return ;
    // End of 'TransformationType' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QTransform >("QTransform");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QTransform >("QTransform*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QTransform >(typeid(::QTransform).name());
    qRegisterMetaType< ::QTransform >("QTransform");
    qRegisterMetaType< ::QTransform::TransformationType >("QTransform::TransformationType");
}
