/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtmultimedia_python.h"

#include "qaudioengineplugin_wrapper.h"

// Extra includes
#include <QList>
#include <qaudioengine.h>
#include <qaudioformat.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QAudioEnginePluginWrapper::QAudioEnginePluginWrapper(QObject * parent) : QAudioEnginePlugin(parent) {
    // ... middle
}

QList<QByteArray > QAudioEnginePluginWrapper::availableDevices(QAudio::Mode arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QList<QByteArray >();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "availableDevices"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.availableDevices()' not implemented.");
        return ::QList<QByteArray >();
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAudio::Mode >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QList<QByteArray >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QByteArray > >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.availableDevices", "list", pyResult->ob_type->tp_name);
        return ::QList<QByteArray >();
    }
    ::QList<QByteArray > cppResult = Shiboken::Converter< ::QList<QByteArray > >::toCpp(pyResult);
    return cppResult;
}

void QAudioEnginePluginWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QAudioEnginePluginWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QAbstractAudioDeviceInfo * QAudioEnginePluginWrapper::createDeviceInfo(const QByteArray & device, QAudio::Mode mode)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QAbstractAudioDeviceInfo*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createDeviceInfo"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createDeviceInfo()' not implemented.");
        return ((::QAbstractAudioDeviceInfo*)0);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QByteArray >::toPython(device),
        Shiboken::Converter< ::QAudio::Mode >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QAbstractAudioDeviceInfo*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAbstractAudioDeviceInfo * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.createDeviceInfo", Shiboken::SbkType< QAbstractAudioDeviceInfo >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QAbstractAudioDeviceInfo*)0);
    }
    ::QAbstractAudioDeviceInfo * cppResult = Shiboken::Converter< ::QAbstractAudioDeviceInfo * >::toCpp(pyResult);
    return cppResult;
}

QAbstractAudioInput * QAudioEnginePluginWrapper::createInput(const QByteArray & device, const QAudioFormat & format)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QAbstractAudioInput*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createInput"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createInput()' not implemented.");
        return ((::QAbstractAudioInput*)0);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QByteArray >::toPython(device),
        Shiboken::Converter< ::QAudioFormat >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QAbstractAudioInput*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAbstractAudioInput * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.createInput", Shiboken::SbkType< QAbstractAudioInput >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QAbstractAudioInput*)0);
    }
    ::QAbstractAudioInput * cppResult = Shiboken::Converter< ::QAbstractAudioInput * >::toCpp(pyResult);
    return cppResult;
}

QAbstractAudioOutput * QAudioEnginePluginWrapper::createOutput(const QByteArray & device, const QAudioFormat & format)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((::QAbstractAudioOutput*)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "createOutput"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createOutput()' not implemented.");
        return ((::QAbstractAudioOutput*)0);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QByteArray >::toPython(device),
        Shiboken::Converter< ::QAudioFormat >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((::QAbstractAudioOutput*)0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QAbstractAudioOutput * >::isConvertible(pyResult);
    if (!typeIsValid && pyResult != Py_None) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.createOutput", Shiboken::SbkType< QAbstractAudioOutput >()->tp_name, pyResult->ob_type->tp_name);
        return ((::QAbstractAudioOutput*)0);
    }
    ::QAbstractAudioOutput * cppResult = Shiboken::Converter< ::QAbstractAudioOutput * >::toCpp(pyResult);
    return cppResult;
}

void QAudioEnginePluginWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QAudioEnginePluginWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QAudioEnginePluginWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.event", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

bool QAudioEnginePluginWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ((bool)0);
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ((bool)0);
    }
    // Check return type
    bool typeIsValid = SbkNumber_Check(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.eventFilter", "bool", pyResult->ob_type->tp_name);
        return ((bool)0);
    }
    bool cppResult = Shiboken::Converter< bool >::toCpp(pyResult);
    return cppResult;
}

QStringList QAudioEnginePluginWrapper::keys() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ::QStringList();
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "keys"));
    if (pyOverride.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.keys()' not implemented.");
        return ::QStringList();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ::QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        Shiboken::warning(PyExc_RuntimeWarning, 2, "Invalid return value in function %s, expected %s, got %s.", "QAudioEnginePlugin.keys", "QStringList", pyResult->ob_type->tp_name);
        return ::QStringList();
    }
    ::QStringList cppResult = Shiboken::Converter< ::QStringList >::toCpp(pyResult);
    return cppResult;
}

void QAudioEnginePluginWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (pyOverride.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

const QMetaObject* QAudioEnginePluginWrapper::metaObject() const
{
    #if QT_VERSION >= 0x040700
    if (QObject::d_ptr->metaObject) return QObject::d_ptr->metaObject;
    #endif
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return PySide::SignalManager::retriveMetaObject(reinterpret_cast<PyObject*>(pySelf));
}

int QAudioEnginePluginWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAudioEnginePlugin::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void* QAudioEnginePluginWrapper::qt_metacast(const char* _clname)
{
        if (!_clname) return 0;
        SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
        if (pySelf && PySide::inherits(Py_TYPE(pySelf), _clname))
                return static_cast<void*>(const_cast< QAudioEnginePluginWrapper* >(this));
        return QAudioEnginePlugin::qt_metacast(_clname);
}

QAudioEnginePluginWrapper::~QAudioEnginePluginWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAudioEnginePlugin_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEPLUGIN_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAudioEnginePlugin' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }

        Shiboken::ObjectType::copyMultimpleheritance(type, myType);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAudioEnginePlugin >()))
        return -1;

    ::QAudioEnginePluginWrapper* cptr = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QAudioEnginePlugin", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QAudioEnginePlugin(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QAudioEnginePlugin(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QAudioEnginePlugin(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEnginePlugin_Init_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "parent");
            if (value) {
                if (pyArgs[0])
                    errorArgName = "parent";
                else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                    pyArgs[0] = value;
                else
                    goto Sbk_QAudioEnginePlugin_Init_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin(): got multiple values for keyword argument '%s'", errorArgName);
                return -1;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject * cppArg0 = pyArgs[0] ? Shiboken::Converter< ::QObject * >::toCpp(pyArgs[0]) : 0;

        if(!PyErr_Occurred()) {
            // QAudioEnginePlugin(QObject*)
            void* addr = PySide::nextQObjectMemoryAddr();
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cptr = addr ? new (addr) ::QAudioEnginePluginWrapper(cppArg0) : new ::QAudioEnginePluginWrapper(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAudioEnginePlugin >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QAudioEnginePlugin_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QAudioEnginePlugin_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEnginePlugin", overloads);
        return -1;
}

static PyObject* Sbk_QAudioEnginePluginFunc_availableDevices(PyObject* self, PyObject* pyArg)
{
    ::QAudioEnginePlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QAudioEnginePlugin* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: availableDevices(QAudio::Mode)const
    if (Shiboken::Converter< ::QAudio::Mode >::isConvertible(pyArg)) {
        overloadId = 0; // availableDevices(QAudio::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEnginePluginFunc_availableDevices_TypeError;

    // Call function/method
    {
        QAudio::Mode cppArg0 = Shiboken::Converter< ::QAudio::Mode >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // availableDevices(QAudio::Mode)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.availableDevices()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QByteArray > cppResult = const_cast<const ::QAudioEnginePlugin*>(cppSelf)->availableDevices(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QByteArray > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAudioEnginePluginFunc_availableDevices_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAudio.Mode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtMultimedia.QAudioEnginePlugin.availableDevices", overloads);
        return 0;
}

static PyObject* Sbk_QAudioEnginePluginFunc_createDeviceInfo(PyObject* self, PyObject* args)
{
    ::QAudioEnginePlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QAudioEnginePlugin* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createDeviceInfo", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createDeviceInfo(QByteArray,QAudio::Mode)
    if (numArgs == 2
        && Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[0])
        && Shiboken::Converter< ::QAudio::Mode >::isConvertible(pyArgs[1])) {
        overloadId = 0; // createDeviceInfo(QByteArray,QAudio::Mode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEnginePluginFunc_createDeviceInfo_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[0]);
        QAudio::Mode cppArg1 = Shiboken::Converter< ::QAudio::Mode >::toCpp(pyArgs[1]);

        if(!PyErr_Occurred()) {
            // createDeviceInfo(QByteArray,QAudio::Mode)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createDeviceInfo()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QAbstractAudioDeviceInfo * cppResult = cppSelf->createDeviceInfo(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QAbstractAudioDeviceInfo * >::toPython(cppResult);

            // Ownership transferences.
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAudioEnginePluginFunc_createDeviceInfo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudio.Mode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEnginePlugin.createDeviceInfo", overloads);
        return 0;
}

static PyObject* Sbk_QAudioEnginePluginFunc_createInput(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QAudioEnginePlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QAudioEnginePlugin* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createInput(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createInput(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createInput", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createInput(QByteArray,QAudioFormat)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createInput(QByteArray,QAudioFormat)
        } else if (Shiboken::Converter< ::QAudioFormat >::isConvertible(pyArgs[1])) {
            overloadId = 0; // createInput(QByteArray,QAudioFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEnginePluginFunc_createInput_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "format");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "format";
                else if (Shiboken::Converter< ::QAudioFormat >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QAudioEnginePluginFunc_createInput_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createInput(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        QAudioFormat cppArg1_tmp = QAudioFormat();
        ::QAudioFormat cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QAudioFormat >::toCpp(pyArgs[1]) : cppArg1_tmp;

        if(!PyErr_Occurred()) {
            // createInput(QByteArray,QAudioFormat)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createInput()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QAbstractAudioInput * cppResult = cppSelf->createInput(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QAbstractAudioInput * >::toPython(cppResult);

            // Ownership transferences.
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAudioEnginePluginFunc_createInput_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudioFormat = QAudioFormat()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEnginePlugin.createInput", overloads);
        return 0;
}

static PyObject* Sbk_QAudioEnginePluginFunc_createOutput(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QAudioEnginePlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QAudioEnginePlugin* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createOutput", &(pyArgs[0]), &(pyArgs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createOutput(QByteArray,QAudioFormat)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createOutput(QByteArray,QAudioFormat)
        } else if (Shiboken::Converter< ::QAudioFormat >::isConvertible(pyArgs[1])) {
            overloadId = 0; // createOutput(QByteArray,QAudioFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAudioEnginePluginFunc_createOutput_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "format");
            if (value) {
                if (pyArgs[1])
                    errorArgName = "format";
                else if (Shiboken::Converter< ::QAudioFormat >::isConvertible(value))
                    pyArgs[1] = value;
                else
                    goto Sbk_QAudioEnginePluginFunc_createOutput_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return 0;
        ::QByteArray cppArg0 = Shiboken::Converter< ::QByteArray >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        QAudioFormat cppArg1_tmp = QAudioFormat();
        ::QAudioFormat cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QAudioFormat >::toCpp(pyArgs[1]) : cppArg1_tmp;

        if(!PyErr_Occurred()) {
            // createOutput(QByteArray,QAudioFormat)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.createOutput()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QAbstractAudioOutput * cppResult = cppSelf->createOutput(cppArg0, cppArg1);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QAbstractAudioOutput * >::toPython(cppResult);

            // Ownership transferences.
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAudioEnginePluginFunc_createOutput_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtMultimedia.QAudioFormat = QAudioFormat()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAudioEnginePlugin.createOutput", overloads);
        return 0;
}

static PyObject* Sbk_QAudioEnginePluginFunc_keys(PyObject* self)
{
    ::QAudioEnginePlugin* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QAudioEnginePlugin* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // keys()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAudioEnginePlugin.keys()' not implemented.");
                return 0;
            }
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QStringList cppResult = const_cast<const ::QAudioEnginePlugin*>(cppSelf)->keys();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QAudioEnginePlugin_methods[] = {
    {"availableDevices", (PyCFunction)Sbk_QAudioEnginePluginFunc_availableDevices, METH_O},
    {"createDeviceInfo", (PyCFunction)Sbk_QAudioEnginePluginFunc_createDeviceInfo, METH_VARARGS},
    {"createInput", (PyCFunction)Sbk_QAudioEnginePluginFunc_createInput, METH_VARARGS|METH_KEYWORDS},
    {"createOutput", (PyCFunction)Sbk_QAudioEnginePluginFunc_createOutput, METH_VARARGS|METH_KEYWORDS},
    {"keys", (PyCFunction)Sbk_QAudioEnginePluginFunc_keys, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QAudioEnginePlugin_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QAudioEnginePlugin_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
static int mi_offsets[] = { -1, -1, -1, -1, -1, -1, -1 };
int*
Sbk_QAudioEnginePlugin_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const QAudioEnginePlugin* class_ptr = reinterpret_cast<const QAudioEnginePlugin*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QObject*>((QAudioEnginePlugin*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QAudioEngineFactoryInterface*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QAudioEngineFactoryInterface*>((QAudioEnginePlugin*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QFactoryInterface*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QFactoryInterface*>((QAudioEngineFactoryInterface*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* Sbk_QAudioEnginePluginSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QAudioEnginePlugin* me = reinterpret_cast< ::QAudioEnginePlugin*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast< ::QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX]))
        return static_cast< ::QAudioEngineFactoryInterface*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QFACTORYINTERFACE_IDX]))
        return static_cast< ::QFactoryInterface*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QAudioEnginePlugin_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtMultimedia.QAudioEnginePlugin",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QAudioEnginePlugin_traverse,
    /*tp_clear*/            Sbk_QAudioEnginePlugin_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QAudioEnginePlugin_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QAudioEnginePlugin_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static void* Sbk_QAudioEnginePlugin_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QObject >()))
        return dynamic_cast< ::QAudioEnginePlugin*>(reinterpret_cast< ::QObject*>(cptr));
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::QFactoryInterface >()))
        return dynamic_cast< ::QAudioEnginePlugin*>(reinterpret_cast< ::QFactoryInterface*>(cptr));
    return 0;
}


void init_QAudioEnginePlugin(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEPLUGIN_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QAudioEnginePlugin_Type);

    PyObject* Sbk_QAudioEnginePlugin_Type_bases = PyTuple_Pack(2,
        (PyObject*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX],
        (PyObject*)SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX]);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QAudioEnginePlugin", "QAudioEnginePlugin*",
        &Sbk_QAudioEnginePlugin_Type, &Shiboken::callCppDestructor< ::QAudioEnginePlugin >, (SbkObjectType*)SbkPySide_QtMultimediaTypes[SBK_QAUDIOENGINEFACTORYINTERFACE_IDX], Sbk_QAudioEnginePlugin_Type_bases)) {
        return;
    }

    MultipleInheritanceInitFunction func = Sbk_QAudioEnginePlugin_mi_init;
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QAudioEnginePlugin_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QAudioEnginePlugin_Type, &Sbk_QAudioEnginePluginSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(&Sbk_QAudioEnginePlugin_Type, &Sbk_QAudioEnginePlugin_typeDiscovery);


    Shiboken::TypeResolver::createObjectTypeResolver< ::QAudioEnginePlugin >("QAudioEnginePlugin*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QAudioEnginePlugin >("QAudioEnginePlugin$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QAudioEnginePlugin >(typeid(::QAudioEnginePlugin).name());
    Shiboken::TypeResolver::createObjectTypeResolver< ::QAudioEnginePlugin >(typeid(::QAudioEnginePluginWrapper).name());
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QAudioEnginePlugin_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QAudioEnginePlugin_Type, &::QAudioEnginePlugin::staticMetaObject, sizeof(::QAudioEnginePlugin));
}
