/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <pyside.h>
#include "pyside_qtmultimedia_python.h"



// Extra includes

void cleanTypesAttributes(void) {
    for (int i = 0, imax = SBK_QtMultimedia_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject*>(SbkPySide_QtMultimediaTypes[i]);
        if (pyType && PyObject_HasAttrString(pyType, "staticMetaObject"))
            PyObject_SetAttrString(pyType, "staticMetaObject", Py_None);
    }
}
// Global functions ------------------------------------------------------------

static PyMethodDef QtMultimedia_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QAudio(PyObject* module);
void init_QAudioDeviceInfo(PyObject* module);
void init_QAudioFormat(PyObject* module);
void init_QVideoFrame(PyObject* module);
void init_QAbstractVideoBuffer(PyObject* module);
void init_QVideoSurfaceFormat(PyObject* module);
void init_QAudioEngineFactoryInterface(PyObject* module);
void init_QAbstractVideoSurface(PyObject* module);
void init_QAudioOutput(PyObject* module);
void init_QAudioInput(PyObject* module);
void init_QAudioEnginePlugin(PyObject* module);
void init_QAbstractAudioInput(PyObject* module);
void init_QAbstractAudioOutput(PyObject* module);
void init_QAbstractAudioDeviceInfo(PyObject* module);

// Current module's type array.
PyTypeObject** SbkPySide_QtMultimediaTypes;
// Required modules' type arrays.
PyTypeObject** SbkPySide_QtGuiTypes;
PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

#ifdef IS_PY3K
static int QtMultimedia_moduleTraverse(PyObject*, visitproc, void *)
{
    PySide::runCleanupFunctions();
}

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtMultimedia",
    /* m_doc      */ 0,
    /* m_size     */ -1,
    /* m_methods  */ QtMultimedia_methods,
    /* m_reload   */ 0,
    /* m_traverse */ QtMultimedia_moduleTraverse,
    /* m_clear    */ 0,
    /* m_free     */ 0
};

#endif
SBK_MODULE_INIT_FUNCTION_BEGIN(QtMultimedia)
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtGui"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtGuiTypes = Shiboken::Module::getTypes(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtCore"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject* cppApi[SBK_QtMultimedia_IDX_COUNT];
    SbkPySide_QtMultimediaTypes = cppApi;

#ifdef IS_PY3K
    PyObject* module = Shiboken::Module::create("QtMultimedia", &moduledef);
#else
    PyObject* module = Shiboken::Module::create("QtMultimedia", QtMultimedia_methods);
#endif

    // Initialize classes in the type system
    init_QAudio(module);
    init_QAudioDeviceInfo(module);
    init_QAudioFormat(module);
    init_QVideoFrame(module);
    init_QAbstractVideoBuffer(module);
    init_QVideoSurfaceFormat(module);
    init_QAudioEngineFactoryInterface(module);
    init_QAbstractVideoSurface(module);
    init_QAudioOutput(module);
    init_QAudioInput(module);
    init_QAudioEnginePlugin(module);
    init_QAbstractAudioInput(module);
    init_QAbstractAudioOutput(module);
    init_QAbstractAudioDeviceInfo(module);

    // Register primitive types on TypeResolver

    Shiboken::Module::registerTypes(module, SbkPySide_QtMultimediaTypes);

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtMultimedia");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);
SBK_MODULE_INIT_FUNCTION_END
