/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qhostinfo_wrapper.h"

// Extra includes
#include <QList>
#include <qhostaddress.h>
#include <qhostinfo.h>
#include <qobject.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHostInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QHostInfo >()))
        return -1;

    ::QHostInfo* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHostInfo(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QHostInfo", &(pyArgs[0])))
        return -1;


    // Overloaded function decisor
    // 0: QHostInfo(QHostInfo)
    // 1: QHostInfo(int)
    if (numArgs == 0) {
        overloadId = 1; // QHostInfo(int)
    } else if (SbkNumber_Check(pyArgs[0])) {
        overloadId = 1; // QHostInfo(int)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QHostInfo >::isConvertible(pyArgs[0])) {
        overloadId = 0; // QHostInfo(QHostInfo)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostInfo_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QHostInfo(QHostInfo)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QHostInfo cppArg0 = Shiboken::Converter< ::QHostInfo >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QHostInfo(QHostInfo)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QHostInfo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QHostInfo(int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "lookupId");
                if (value) {
                    if (pyArgs[0])
                        errorArgName = "lookupId";
                    else if (SbkNumber_Check(value))
                        pyArgs[0] = value;
                    else
                        goto Sbk_QHostInfo_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHostInfo(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cppArg0 = pyArgs[0] ? Shiboken::Converter< int >::toCpp(pyArgs[0]) : -1;

            if(!PyErr_Occurred()) {
                // QHostInfo(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QHostInfo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QHostInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QHostInfo_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QHostInfo_Init_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostInfo", "int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHostInfo", overloads);
        return -1;
}

static PyObject* Sbk_QHostInfoFunc_abortHostLookup(PyObject* self, PyObject* pyArg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: abortHostLookup(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // abortHostLookup(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostInfoFunc_abortHostLookup_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // abortHostLookup(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QHostInfo::abortHostLookup(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHostInfoFunc_abortHostLookup_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QHostInfo.abortHostLookup", overloads);
        return 0;
}

static PyObject* Sbk_QHostInfoFunc_addresses(PyObject* self)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // addresses()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QList<QHostAddress > cppResult = const_cast<const ::QHostInfo*>(cppSelf)->addresses();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QHostAddress > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostInfoFunc_error(PyObject* self)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // error()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QHostInfo::HostInfoError cppResult = const_cast<const ::QHostInfo*>(cppSelf)->error();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QHostInfo::HostInfoError >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostInfoFunc_errorString(PyObject* self)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // errorString()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QHostInfo*>(cppSelf)->errorString();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostInfoFunc_fromName(PyObject* self, PyObject* pyArg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromName(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // fromName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostInfoFunc_fromName_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // fromName(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QHostInfo cppResult = QHostInfo::fromName(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QHostInfo >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHostInfoFunc_fromName_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QHostInfo.fromName", overloads);
        return 0;
}

static PyObject* Sbk_QHostInfoFunc_hostName(PyObject* self)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // hostName()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::QHostInfo*>(cppSelf)->hostName();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostInfoFunc_localDomainName(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // localDomainName()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = QHostInfo::localDomainName();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostInfoFunc_localHostName(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // localHostName()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = QHostInfo::localHostName();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostInfoFunc_lookupId(PyObject* self)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // lookupId()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            int cppResult = const_cast<const ::QHostInfo*>(cppSelf)->lookupId();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< int >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHostInfoFunc_setAddresses(PyObject* self, PyObject* pyArg)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAddresses(QList<QHostAddress>)
    if (Shiboken::Converter< ::QList<QHostAddress > >::isConvertible(pyArg)) {
        overloadId = 0; // setAddresses(QList<QHostAddress>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostInfoFunc_setAddresses_TypeError;

    // Call function/method
    {
        ::QList<QHostAddress > cppArg0 = Shiboken::Converter< ::QList<QHostAddress > >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setAddresses(QList<QHostAddress>)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAddresses(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHostInfoFunc_setAddresses_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QHostInfo.setAddresses", overloads);
        return 0;
}

static PyObject* Sbk_QHostInfoFunc_setError(PyObject* self, PyObject* pyArg)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setError(QHostInfo::HostInfoError)
    if (Shiboken::Converter< ::QHostInfo::HostInfoError >::isConvertible(pyArg)) {
        overloadId = 0; // setError(QHostInfo::HostInfoError)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostInfoFunc_setError_TypeError;

    // Call function/method
    {
        QHostInfo::HostInfoError cppArg0 = Shiboken::Converter< ::QHostInfo::HostInfoError >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setError(QHostInfo::HostInfoError)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setError(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHostInfoFunc_setError_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QHostInfo.HostInfoError", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QHostInfo.setError", overloads);
        return 0;
}

static PyObject* Sbk_QHostInfoFunc_setErrorString(PyObject* self, PyObject* pyArg)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setErrorString(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setErrorString(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostInfoFunc_setErrorString_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setErrorString(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setErrorString(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHostInfoFunc_setErrorString_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QHostInfo.setErrorString", overloads);
        return 0;
}

static PyObject* Sbk_QHostInfoFunc_setHostName(PyObject* self, PyObject* pyArg)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHostName(QString)
    if (Shiboken::Converter< ::QString >::isConvertible(pyArg)) {
        overloadId = 0; // setHostName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostInfoFunc_setHostName_TypeError;

    // Call function/method
    {
        ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setHostName(QString)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setHostName(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHostInfoFunc_setHostName_TypeError:
        const char* overloads[] = {"unicode", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QHostInfo.setHostName", overloads);
        return 0;
}

static PyObject* Sbk_QHostInfoFunc_setLookupId(PyObject* self, PyObject* pyArg)
{
    ::QHostInfo* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QHostInfo* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLookupId(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setLookupId(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHostInfoFunc_setLookupId_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLookupId(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLookupId(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHostInfoFunc_setLookupId_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtNetwork.QHostInfo.setLookupId", overloads);
        return 0;
}

static PyObject* Sbk_QHostInfo___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QHostInfo& cppSelf = *(Shiboken::Converter< ::QHostInfo* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QHostInfo >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QHostInfo_methods[] = {
    {"abortHostLookup", (PyCFunction)Sbk_QHostInfoFunc_abortHostLookup, METH_O|METH_STATIC},
    {"addresses", (PyCFunction)Sbk_QHostInfoFunc_addresses, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QHostInfoFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QHostInfoFunc_errorString, METH_NOARGS},
    {"fromName", (PyCFunction)Sbk_QHostInfoFunc_fromName, METH_O|METH_STATIC},
    {"hostName", (PyCFunction)Sbk_QHostInfoFunc_hostName, METH_NOARGS},
    {"localDomainName", (PyCFunction)Sbk_QHostInfoFunc_localDomainName, METH_NOARGS|METH_STATIC},
    {"localHostName", (PyCFunction)Sbk_QHostInfoFunc_localHostName, METH_NOARGS|METH_STATIC},
    {"lookupId", (PyCFunction)Sbk_QHostInfoFunc_lookupId, METH_NOARGS},
    {"setAddresses", (PyCFunction)Sbk_QHostInfoFunc_setAddresses, METH_O},
    {"setError", (PyCFunction)Sbk_QHostInfoFunc_setError, METH_O},
    {"setErrorString", (PyCFunction)Sbk_QHostInfoFunc_setErrorString, METH_O},
    {"setHostName", (PyCFunction)Sbk_QHostInfoFunc_setHostName, METH_O},
    {"setLookupId", (PyCFunction)Sbk_QHostInfoFunc_setLookupId, METH_O},

    {"__copy__", (PyCFunction)Sbk_QHostInfo___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

static int Sbk_QHostInfo_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QHostInfo_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QHostInfo_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtNetwork.QHostInfo",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QHostInfo_traverse,
    /*tp_clear*/            Sbk_QHostInfo_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QHostInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QHostInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QHostInfo(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QHOSTINFO_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QHostInfo_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QHostInfo", "QHostInfo",
        &Sbk_QHostInfo_Type, &Shiboken::callCppDestructor< ::QHostInfo >)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'HostInfoError'.
    SbkPySide_QtNetworkTypes[SBK_QHOSTINFO_HOSTINFOERROR_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_QHostInfo_Type,
        "HostInfoError",
        "PySide.QtNetwork.QHostInfo.HostInfoError",
        "QHostInfo::HostInfoError");
    if (!SbkPySide_QtNetworkTypes[SBK_QHOSTINFO_HOSTINFOERROR_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtNetworkTypes[SBK_QHOSTINFO_HOSTINFOERROR_IDX],
        &Sbk_QHostInfo_Type, "NoError", (long) QHostInfo::NoError))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtNetworkTypes[SBK_QHOSTINFO_HOSTINFOERROR_IDX],
        &Sbk_QHostInfo_Type, "HostNotFound", (long) QHostInfo::HostNotFound))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_QtNetworkTypes[SBK_QHOSTINFO_HOSTINFOERROR_IDX],
        &Sbk_QHostInfo_Type, "UnknownError", (long) QHostInfo::UnknownError))
        return ;
    // End of 'HostInfoError' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::QHostInfo >("QHostInfo");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QHostInfo >("QHostInfo*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QHostInfo >(typeid(::QHostInfo).name());
    qRegisterMetaType< ::QHostInfo::HostInfoError >("QHostInfo::HostInfoError");
}
