/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <pyside.h>
#include "pyside_qtscript_python.h"



// Extra includes

void cleanTypesAttributes(void) {
    for (int i = 0, imax = SBK_QtScript_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject*>(SbkPySide_QtScriptTypes[i]);
        if (pyType && PyObject_HasAttrString(pyType, "staticMetaObject"))
            PyObject_SetAttrString(pyType, "staticMetaObject", Py_None);
    }
}
// Global functions ------------------------------------------------------------

static PyMethodDef QtScript_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QScriptValueIterator(PyObject* module);
void init_QScriptEngineAgent(PyObject* module);
void init_QScriptProgram(PyObject* module);
void init_QScriptString(PyObject* module);
void init_QScriptContextInfo(PyObject* module);
void init_QScriptContext(PyObject* module);
void init_QScriptClassPropertyIterator(PyObject* module);
void init_QScriptClass(PyObject* module);
void init_QScriptValue(PyObject* module);
void init_QScriptable(PyObject* module);
void init_QScriptExtensionInterface(PyObject* module);
void init_QScriptExtensionPlugin(PyObject* module);
void init_QScriptEngine(PyObject* module);

// Current module's type array.
PyTypeObject** SbkPySide_QtScriptTypes;
// Required modules' type arrays.
PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

#ifdef IS_PY3K
static int QtScript_moduleTraverse(PyObject*, visitproc, void *)
{
    PySide::runCleanupFunctions();
}

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtScript",
    /* m_doc      */ 0,
    /* m_size     */ -1,
    /* m_methods  */ QtScript_methods,
    /* m_reload   */ 0,
    /* m_traverse */ QtScript_moduleTraverse,
    /* m_clear    */ 0,
    /* m_free     */ 0
};

#endif
SBK_MODULE_INIT_FUNCTION_BEGIN(QtScript)
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtCore"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject* cppApi[SBK_QtScript_IDX_COUNT];
    SbkPySide_QtScriptTypes = cppApi;

#ifdef IS_PY3K
    PyObject* module = Shiboken::Module::create("QtScript", &moduledef);
#else
    PyObject* module = Shiboken::Module::create("QtScript", QtScript_methods);
#endif

    // Initialize classes in the type system
    init_QScriptValueIterator(module);
    init_QScriptEngineAgent(module);
    init_QScriptProgram(module);
    init_QScriptString(module);
    init_QScriptContextInfo(module);
    init_QScriptContext(module);
    init_QScriptClassPropertyIterator(module);
    init_QScriptClass(module);
    init_QScriptValue(module);
    init_QScriptable(module);
    init_QScriptExtensionInterface(module);
    init_QScriptExtensionPlugin(module);
    init_QScriptEngine(module);

    // Register primitive types on TypeResolver

    Shiboken::Module::registerTypes(module, SbkPySide_QtScriptTypes);

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtScript");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);
SBK_MODULE_INIT_FUNCTION_END
