/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <pyside.h>
#include "pyside_qtsql_python.h"



// Extra includes

void cleanTypesAttributes(void) {
    for (int i = 0, imax = SBK_QtSql_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject*>(SbkPySide_QtSqlTypes[i]);
        if (pyType && PyObject_HasAttrString(pyType, "staticMetaObject"))
            PyObject_SetAttrString(pyType, "staticMetaObject", Py_None);
    }
}
// Global functions ------------------------------------------------------------

static PyMethodDef QtSql_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QSql(PyObject* module);
void init_QSqlResult(PyObject* module);
void init_QSqlRecord(PyObject* module);
void init_QSqlIndex(PyObject* module);
void init_QSqlField(PyObject* module);
void init_QSqlError(PyObject* module);
void init_QSqlRelation(PyObject* module);
void init_QSqlDatabase(PyObject* module);
void init_QSqlQuery(PyObject* module);
void init_QSqlDriverCreatorBase(PyObject* module);
void init_QSqlRelationalDelegate(PyObject* module);
void init_QSqlQueryModel(PyObject* module);
void init_QSqlTableModel(PyObject* module);
void init_QSqlRelationalTableModel(PyObject* module);
void init_QSqlDriver(PyObject* module);

// Current module's type array.
PyTypeObject** SbkPySide_QtSqlTypes;
// Required modules' type arrays.
PyTypeObject** SbkPySide_QtGuiTypes;
PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

#ifdef IS_PY3K
static int QtSql_moduleTraverse(PyObject*, visitproc, void *)
{
    PySide::runCleanupFunctions();
}

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtSql",
    /* m_doc      */ 0,
    /* m_size     */ -1,
    /* m_methods  */ QtSql_methods,
    /* m_reload   */ 0,
    /* m_traverse */ QtSql_moduleTraverse,
    /* m_clear    */ 0,
    /* m_free     */ 0
};

#endif
SBK_MODULE_INIT_FUNCTION_BEGIN(QtSql)
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtGui"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtGuiTypes = Shiboken::Module::getTypes(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtCore"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject* cppApi[SBK_QtSql_IDX_COUNT];
    SbkPySide_QtSqlTypes = cppApi;

#ifdef IS_PY3K
    PyObject* module = Shiboken::Module::create("QtSql", &moduledef);
#else
    PyObject* module = Shiboken::Module::create("QtSql", QtSql_methods);
#endif

    // Initialize classes in the type system
    init_QSql(module);
    init_QSqlResult(module);
    init_QSqlRecord(module);
    init_QSqlIndex(module);
    init_QSqlField(module);
    init_QSqlError(module);
    init_QSqlRelation(module);
    init_QSqlDatabase(module);
    init_QSqlQuery(module);
    init_QSqlDriverCreatorBase(module);
    init_QSqlRelationalDelegate(module);
    init_QSqlQueryModel(module);
    init_QSqlTableModel(module);
    init_QSqlRelationalTableModel(module);
    init_QSqlDriver(module);

    // Register primitive types on TypeResolver

    Shiboken::Module::registerTypes(module, SbkPySide_QtSqlTypes);

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtSql");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);
SBK_MODULE_INIT_FUNCTION_END
