/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qttest_python.h"

#include "qtest_pysideqtoucheventsequence_wrapper.h"

// Extra includes
#include <pysideqtesttouch.h>
#include <qevent.h>
#include <qpoint.h>
#include <qwidget.h>

using namespace QTest;


// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QTest_PySideQTouchEventSequenceFunc_commit(PyObject* self)
{
    ::QTest::PySideQTouchEventSequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTest::PySideQTouchEventSequence* >::toCpp(self);

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // commit()
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->commit();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTest_PySideQTouchEventSequenceFunc_move(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTest::PySideQTouchEventSequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTest::PySideQTouchEventSequence* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.move(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.move(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:move", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: move(int,QPoint,QWidget*)
    if (numArgs >= 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // move(int,QPoint,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[2])) {
            overloadId = 0; // move(int,QPoint,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTest_PySideQTouchEventSequenceFunc_move_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "widget");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "widget";
                else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QTest_PySideQTouchEventSequenceFunc_move_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.move(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QPoint cppArg1 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[1]);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return 0;
        ::QWidget * cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[2]) : 0;

        if(!PyErr_Occurred()) {
            // move(int,QPoint,QWidget*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTest::PySideQTouchEventSequence * cppResult = cppSelf->move(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTest::PySideQTouchEventSequence * >::toPython(cppResult);

            // Ownership transferences.
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTest_PySideQTouchEventSequenceFunc_move_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QPoint, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtTest.QTouchEventSequence.move", overloads);
        return 0;
}

static PyObject* Sbk_QTest_PySideQTouchEventSequenceFunc_press(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTest::PySideQTouchEventSequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTest::PySideQTouchEventSequence* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.press(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.press(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:press", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: press(int,QPoint,QWidget*)
    if (numArgs >= 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // press(int,QPoint,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[2])) {
            overloadId = 0; // press(int,QPoint,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTest_PySideQTouchEventSequenceFunc_press_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "widget");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "widget";
                else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QTest_PySideQTouchEventSequenceFunc_press_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.press(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QPoint cppArg1 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[1]);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return 0;
        ::QWidget * cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[2]) : 0;

        if(!PyErr_Occurred()) {
            // press(int,QPoint,QWidget*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTest::PySideQTouchEventSequence * cppResult = cppSelf->press(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTest::PySideQTouchEventSequence * >::toPython(cppResult);

            // Ownership transferences.
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTest_PySideQTouchEventSequenceFunc_press_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QPoint, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtTest.QTouchEventSequence.press", overloads);
        return 0;
}

static PyObject* Sbk_QTest_PySideQTouchEventSequenceFunc_release(PyObject* self, PyObject* args, PyObject* kwds)
{
    ::QTest::PySideQTouchEventSequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTest::PySideQTouchEventSequence* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.release(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.release(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:release", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return 0;


    // Overloaded function decisor
    // 0: release(int,QPoint,QWidget*)
    if (numArgs >= 2
        && SbkNumber_Check(pyArgs[0])
        && Shiboken::Converter< ::QPoint >::isConvertible(pyArgs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // release(int,QPoint,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyArgs[2])) {
            overloadId = 0; // release(int,QPoint,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTest_PySideQTouchEventSequenceFunc_release_TypeError;

    // Call function/method
    {
        if (kwds) {
            const char* errorArgName = 0;
            PyObject* value = PyDict_GetItemString(kwds, "widget");
            if (value) {
                if (pyArgs[2])
                    errorArgName = "widget";
                else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                    pyArgs[2] = value;
                else
                    goto Sbk_QTest_PySideQTouchEventSequenceFunc_release_TypeError;
            }
            if (errorArgName) {
                PyErr_Format(PyExc_TypeError, "PySide.QtTest.QTouchEventSequence.release(): got multiple values for keyword argument '%s'", errorArgName);
                return 0;
            }
        }
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArgs[0]);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return 0;
        ::QPoint cppArg1 = Shiboken::Converter< ::QPoint >::toCpp(pyArgs[1]);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return 0;
        ::QWidget * cppArg2 = pyArgs[2] ? Shiboken::Converter< ::QWidget * >::toCpp(pyArgs[2]) : 0;

        if(!PyErr_Occurred()) {
            // release(int,QPoint,QWidget*)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTest::PySideQTouchEventSequence * cppResult = cppSelf->release(cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTest::PySideQTouchEventSequence * >::toPython(cppResult);

            // Ownership transferences.
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTest_PySideQTouchEventSequenceFunc_release_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QPoint, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtTest.QTouchEventSequence.release", overloads);
        return 0;
}

static PyObject* Sbk_QTest_PySideQTouchEventSequenceFunc_stationary(PyObject* self, PyObject* pyArg)
{
    ::QTest::PySideQTouchEventSequence* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QTest::PySideQTouchEventSequence* >::toCpp(self);
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: stationary(int)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // stationary(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTest_PySideQTouchEventSequenceFunc_stationary_TypeError;

    // Call function/method
    {
        int cppArg0 = Shiboken::Converter< int >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // stationary(int)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QTest::PySideQTouchEventSequence * cppResult = cppSelf->stationary(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QTest::PySideQTouchEventSequence * >::toPython(cppResult);

            // Ownership transferences.
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTest_PySideQTouchEventSequenceFunc_stationary_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtTest.QTouchEventSequence.stationary", overloads);
        return 0;
}

static PyMethodDef Sbk_QTest_PySideQTouchEventSequence_methods[] = {
    {"commit", (PyCFunction)Sbk_QTest_PySideQTouchEventSequenceFunc_commit, METH_NOARGS},
    {"move", (PyCFunction)Sbk_QTest_PySideQTouchEventSequenceFunc_move, METH_VARARGS|METH_KEYWORDS},
    {"press", (PyCFunction)Sbk_QTest_PySideQTouchEventSequenceFunc_press, METH_VARARGS|METH_KEYWORDS},
    {"release", (PyCFunction)Sbk_QTest_PySideQTouchEventSequenceFunc_release, METH_VARARGS|METH_KEYWORDS},
    {"stationary", (PyCFunction)Sbk_QTest_PySideQTouchEventSequenceFunc_stationary, METH_O},

    {0} // Sentinel
};

} // extern "C"

static int Sbk_QTest_PySideQTouchEventSequence_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QTest_PySideQTouchEventSequence_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTest_PySideQTouchEventSequence_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtTest.QTest.QTouchEventSequence",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QTest_PySideQTouchEventSequence_traverse,
    /*tp_clear*/            Sbk_QTest_PySideQTouchEventSequence_clear,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTest_PySideQTouchEventSequence_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTest_PySideQTouchEventSequence(PyObject* enclosingClass)
{
    SbkPySide_QtTestTypes[SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTest_PySideQTouchEventSequence_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(enclosingClass, "QTouchEventSequence", "QTest::PySideQTouchEventSequence*",
        &Sbk_QTest_PySideQTouchEventSequence_Type, &Shiboken::callCppDestructor< ::QTest::PySideQTouchEventSequence >, 0, 0, true)) {
        return;
    }


    Shiboken::TypeResolver::createObjectTypeResolver< ::QTest::PySideQTouchEventSequence >("QTest::PySideQTouchEventSequence*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QTest::PySideQTouchEventSequence >("QTouchEventSequence*");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QTest::PySideQTouchEventSequence >(typeid(::QTest::PySideQTouchEventSequence).name());
}
