/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <pyside.h>
#include "pyside_qtwebkit_python.h"



// Extra includes

void cleanTypesAttributes(void) {
    for (int i = 0, imax = SBK_QtWebKit_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject*>(SbkPySide_QtWebKitTypes[i]);
        if (pyType && PyObject_HasAttrString(pyType, "staticMetaObject"))
            PyObject_SetAttrString(pyType, "staticMetaObject", Py_None);
    }
}
// Global functions ------------------------------------------------------------

static PyMethodDef QtWebKit_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_WebCore(PyObject* module);
void init_QWebHistory(PyObject* module);
void init_QWebHistoryItem(PyObject* module);
void init_QWebElementCollection(PyObject* module);
void init_QWebElement(PyObject* module);
void init_QWebSecurityOrigin(PyObject* module);
void init_QWebDatabase(PyObject* module);
void init_QWebSettings(PyObject* module);
void init_QWebHitTestResult(PyObject* module);
void init_QWebInspector(PyObject* module);
void init_QWebHistoryInterface(PyObject* module);
void init_QWebPage(PyObject* module);
void init_QWebPage_ExtensionReturn(PyObject* module);
void init_QWebPage_ChooseMultipleFilesExtensionReturn(PyObject* module);
void init_QWebPage_ExtensionOption(PyObject* module);
void init_QWebPage_ChooseMultipleFilesExtensionOption(PyObject* module);
void init_QWebPage_ErrorPageExtensionReturn(PyObject* module);
void init_QWebPage_ErrorPageExtensionOption(PyObject* module);
void init_QWebPluginFactory(PyObject* module);
void init_QWebPluginFactory_MimeType(PyObject* module);
void init_QWebPluginFactory_Plugin(PyObject* module);
void init_QWebView(PyObject* module);
void init_QGraphicsWebView(PyObject* module);
void init_QWebFrame(PyObject* module);

// Current module's type array.
PyTypeObject** SbkPySide_QtWebKitTypes;
// Required modules' type arrays.
PyTypeObject** SbkPySide_QtCoreTypes;
PyTypeObject** SbkPySide_QtGuiTypes;
PyTypeObject** SbkPySide_QtNetworkTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

#ifdef IS_PY3K
static int QtWebKit_moduleTraverse(PyObject*, visitproc, void *)
{
    PySide::runCleanupFunctions();
}

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtWebKit",
    /* m_doc      */ 0,
    /* m_size     */ -1,
    /* m_methods  */ QtWebKit_methods,
    /* m_reload   */ 0,
    /* m_traverse */ QtWebKit_moduleTraverse,
    /* m_clear    */ 0,
    /* m_free     */ 0
};

#endif
SBK_MODULE_INIT_FUNCTION_BEGIN(QtWebKit)
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtCore"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtGui"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtGuiTypes = Shiboken::Module::getTypes(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtNetwork"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtNetworkTypes = Shiboken::Module::getTypes(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject* cppApi[SBK_QtWebKit_IDX_COUNT];
    SbkPySide_QtWebKitTypes = cppApi;

#ifdef IS_PY3K
    PyObject* module = Shiboken::Module::create("QtWebKit", &moduledef);
#else
    PyObject* module = Shiboken::Module::create("QtWebKit", QtWebKit_methods);
#endif

    // Initialize classes in the type system
    init_WebCore(module);
    init_QWebHistory(module);
    init_QWebHistoryItem(module);
    init_QWebElementCollection(module);
    init_QWebElement(module);
    init_QWebSecurityOrigin(module);
    init_QWebDatabase(module);
    init_QWebSettings(module);
    init_QWebHitTestResult(module);
    init_QWebInspector(module);
    init_QWebHistoryInterface(module);
    init_QWebPage(module);
    init_QWebPage_ExtensionReturn(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ChooseMultipleFilesExtensionReturn(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ExtensionOption(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ChooseMultipleFilesExtensionOption(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ErrorPageExtensionReturn(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPage_ErrorPageExtensionOption(SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX]->tp_dict);
    init_QWebPluginFactory(module);
    init_QWebPluginFactory_MimeType(SbkPySide_QtWebKitTypes[SBK_QWEBPLUGINFACTORY_IDX]->tp_dict);
    init_QWebPluginFactory_Plugin(SbkPySide_QtWebKitTypes[SBK_QWEBPLUGINFACTORY_IDX]->tp_dict);
    init_QWebView(module);
    init_QGraphicsWebView(module);
    init_QWebFrame(module);

    // Register primitive types on TypeResolver

    Shiboken::Module::registerTypes(module, SbkPySide_QtWebKitTypes);

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtWebKit");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);
SBK_MODULE_INIT_FUNCTION_END
