/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <pyside.h>
#include "pyside_qtxml_python.h"



// Extra includes

void cleanTypesAttributes(void) {
    for (int i = 0, imax = SBK_QtXml_IDX_COUNT; i < imax; i++) {
        PyObject *pyType = reinterpret_cast<PyObject*>(SbkPySide_QtXmlTypes[i]);
        if (pyType && PyObject_HasAttrString(pyType, "staticMetaObject"))
            PyObject_SetAttrString(pyType, "staticMetaObject", Py_None);
    }
}
// Global functions ------------------------------------------------------------

static PyMethodDef QtXml_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QXmlDeclHandler(PyObject* module);
void init_QXmlLexicalHandler(PyObject* module);
void init_QXmlEntityResolver(PyObject* module);
void init_QXmlDTDHandler(PyObject* module);
void init_QXmlErrorHandler(PyObject* module);
void init_QXmlContentHandler(PyObject* module);
void init_QXmlDefaultHandler(PyObject* module);
void init_QXmlLocator(PyObject* module);
void init_QXmlReader(PyObject* module);
void init_QXmlSimpleReader(PyObject* module);
void init_QXmlParseException(PyObject* module);
void init_QXmlInputSource(PyObject* module);
void init_QXmlAttributes(PyObject* module);
void init_QXmlNamespaceSupport(PyObject* module);
void init_QDomNamedNodeMap(PyObject* module);
void init_QDomNodeList(PyObject* module);
void init_QDomNode(PyObject* module);
void init_QDomDocument(PyObject* module);
void init_QDomDocumentType(PyObject* module);
void init_QDomProcessingInstruction(PyObject* module);
void init_QDomEntityReference(PyObject* module);
void init_QDomEntity(PyObject* module);
void init_QDomNotation(PyObject* module);
void init_QDomElement(PyObject* module);
void init_QDomAttr(PyObject* module);
void init_QDomCharacterData(PyObject* module);
void init_QDomComment(PyObject* module);
void init_QDomText(PyObject* module);
void init_QDomCDATASection(PyObject* module);
void init_QDomDocumentFragment(PyObject* module);
void init_QDomImplementation(PyObject* module);

// Current module's type array.
PyTypeObject** SbkPySide_QtXmlTypes;
// Required modules' type arrays.
PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

#ifdef IS_PY3K
static int QtXml_moduleTraverse(PyObject*, visitproc, void *)
{
    PySide::runCleanupFunctions();
}

static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtXml",
    /* m_doc      */ 0,
    /* m_size     */ -1,
    /* m_methods  */ QtXml_methods,
    /* m_reload   */ 0,
    /* m_traverse */ QtXml_moduleTraverse,
    /* m_clear    */ 0,
    /* m_free     */ 0
};

#endif
SBK_MODULE_INIT_FUNCTION_BEGIN(QtXml)
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide.QtCore"));
        if (requiredModule.isNull())
            SBK_MODULE_INIT_ERROR;
        SbkPySide_QtCoreTypes = Shiboken::Module::getTypes(requiredModule);
    }

    // Create an array of wrapper types for the current module.
    static PyTypeObject* cppApi[SBK_QtXml_IDX_COUNT];
    SbkPySide_QtXmlTypes = cppApi;

#ifdef IS_PY3K
    PyObject* module = Shiboken::Module::create("QtXml", &moduledef);
#else
    PyObject* module = Shiboken::Module::create("QtXml", QtXml_methods);
#endif

    // Initialize classes in the type system
    init_QXmlDeclHandler(module);
    init_QXmlLexicalHandler(module);
    init_QXmlEntityResolver(module);
    init_QXmlDTDHandler(module);
    init_QXmlErrorHandler(module);
    init_QXmlContentHandler(module);
    init_QXmlDefaultHandler(module);
    init_QXmlLocator(module);
    init_QXmlReader(module);
    init_QXmlSimpleReader(module);
    init_QXmlParseException(module);
    init_QXmlInputSource(module);
    init_QXmlAttributes(module);
    init_QXmlNamespaceSupport(module);
    init_QDomNamedNodeMap(module);
    init_QDomNodeList(module);
    init_QDomNode(module);
    init_QDomDocument(module);
    init_QDomDocumentType(module);
    init_QDomProcessingInstruction(module);
    init_QDomEntityReference(module);
    init_QDomEntity(module);
    init_QDomNotation(module);
    init_QDomElement(module);
    init_QDomAttr(module);
    init_QDomCharacterData(module);
    init_QDomComment(module);
    init_QDomText(module);
    init_QDomCDATASection(module);
    init_QDomDocumentFragment(module);
    init_QDomImplementation(module);

    // Register primitive types on TypeResolver

    Shiboken::Module::registerTypes(module, SbkPySide_QtXmlTypes);

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtXml");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);
SBK_MODULE_INIT_FUNCTION_END
