/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qsourcelocation_wrapper.h"

// Extra includes
#include <qsourcelocation.h>
#include <qurl.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSourceLocation_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSourceLocation >()))
        return -1;

    ::QSourceLocation* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXmlPatterns.QSourceLocation(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QSourceLocation", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])))
        return -1;


    // Overloaded function decisor
    // 0: QSourceLocation()
    // 1: QSourceLocation(QSourceLocation)
    // 2: QSourceLocation(QUrl,int,int)
    if (numArgs == 0) {
        overloadId = 0; // QSourceLocation()
    } else if (Shiboken::Converter< ::QUrl >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QSourceLocation(QUrl,int,int)
        } else if (SbkNumber_Check(pyArgs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QSourceLocation(QUrl,int,int)
            } else if (SbkNumber_Check(pyArgs[2])) {
                overloadId = 2; // QSourceLocation(QUrl,int,int)
            }
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::QSourceLocation >::isConvertible(pyArgs[0])) {
        overloadId = 1; // QSourceLocation(QSourceLocation)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSourceLocation_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // QSourceLocation()
        {

            if(!PyErr_Occurred()) {
                // QSourceLocation()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSourceLocation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // QSourceLocation(QSourceLocation)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSourceLocation cppArg0 = Shiboken::Converter< ::QSourceLocation >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // QSourceLocation(QSourceLocation)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSourceLocation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // QSourceLocation(QUrl,int,int)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "line");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "line";
                    else if (SbkNumber_Check(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_QSourceLocation_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "column");
                if (value) {
                    if (pyArgs[2])
                        errorArgName = "column";
                    else if (SbkNumber_Check(value))
                        pyArgs[2] = value;
                    else
                        goto Sbk_QSourceLocation_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXmlPatterns.QSourceLocation(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0 = Shiboken::Converter< ::QUrl >::toCpp(pyArgs[0]);
            int cppArg1 = pyArgs[1] ? Shiboken::Converter< int >::toCpp(pyArgs[1]) : -1;
            int cppArg2 = pyArgs[2] ? Shiboken::Converter< int >::toCpp(pyArgs[2]) : -1;

            if(!PyErr_Occurred()) {
                // QSourceLocation(QUrl,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::QSourceLocation(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QSourceLocation >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSourceLocation_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSourceLocation_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QSourceLocation", "PySide.QtCore.QUrl, int = -1, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QSourceLocation", overloads);
        return -1;
}

static PyObject* Sbk_QSourceLocationFunc_column(PyObject* self)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // column()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qint64 cppResult = const_cast<const ::QSourceLocation*>(cppSelf)->column();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< long long >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSourceLocationFunc_isNull(PyObject* self)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // isNull()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::QSourceLocation*>(cppSelf)->isNull();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSourceLocationFunc_line(PyObject* self)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // line()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            qint64 cppResult = const_cast<const ::QSourceLocation*>(cppSelf)->line();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< long long >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSourceLocationFunc_setColumn(PyObject* self, PyObject* pyArg)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColumn(qint64)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setColumn(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSourceLocationFunc_setColumn_TypeError;

    // Call function/method
    {
        qint64 cppArg0 = Shiboken::Converter< long long >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setColumn(qint64)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setColumn(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSourceLocationFunc_setColumn_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtXmlPatterns.QSourceLocation.setColumn", overloads);
        return 0;
}

static PyObject* Sbk_QSourceLocationFunc_setLine(PyObject* self, PyObject* pyArg)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLine(qint64)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setLine(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSourceLocationFunc_setLine_TypeError;

    // Call function/method
    {
        qint64 cppArg0 = Shiboken::Converter< long long >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setLine(qint64)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setLine(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSourceLocationFunc_setLine_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtXmlPatterns.QSourceLocation.setLine", overloads);
        return 0;
}

static PyObject* Sbk_QSourceLocationFunc_setUri(PyObject* self, PyObject* pyArg)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUri(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(pyArg)) {
        overloadId = 0; // setUri(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSourceLocationFunc_setUri_TypeError;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return 0;
        ::QUrl cppArg0 = Shiboken::Converter< ::QUrl >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setUri(QUrl)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setUri(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSourceLocationFunc_setUri_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.QtXmlPatterns.QSourceLocation.setUri", overloads);
        return 0;
}

static PyObject* Sbk_QSourceLocationFunc_uri(PyObject* self)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // uri()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUrl cppResult = const_cast<const ::QSourceLocation*>(cppSelf)->uri();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSourceLocation___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QSourceLocation& cppSelf = *(Shiboken::Converter< ::QSourceLocation* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::QSourceLocation >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QSourceLocation_methods[] = {
    {"column", (PyCFunction)Sbk_QSourceLocationFunc_column, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QSourceLocationFunc_isNull, METH_NOARGS},
    {"line", (PyCFunction)Sbk_QSourceLocationFunc_line, METH_NOARGS},
    {"setColumn", (PyCFunction)Sbk_QSourceLocationFunc_setColumn, METH_O},
    {"setLine", (PyCFunction)Sbk_QSourceLocationFunc_setLine, METH_O},
    {"setUri", (PyCFunction)Sbk_QSourceLocationFunc_setUri, METH_O},
    {"uri", (PyCFunction)Sbk_QSourceLocationFunc_uri, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSourceLocation___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QSourceLocation___nb_bool(PyObject* self)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return -1;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

// Rich comparison
static PyObject* Sbk_QSourceLocation_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::QSourceLocation& cppSelf = *(Shiboken::Converter< ::QSourceLocation* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSourceLocation >::isConvertible(pyArg)) {
                // operator!=(const QSourceLocation & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QSourceLocation cppArg0 = Shiboken::Converter< ::QSourceLocation >::toCpp(pyArg);
                bool cppResult = cppSelf != cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSourceLocation >::isConvertible(pyArg)) {
                // operator==(const QSourceLocation & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::QSourceLocation cppArg0 = Shiboken::Converter< ::QSourceLocation >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QSourceLocation_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSourceLocation_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_QSourceLocation_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_QSourceLocation_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
extern "C"
{
static PyObject* Sbk_QSourceLocation__repr__(PyObject* self)
{
    ::QSourceLocation* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::QSourceLocation* >::toCpp(self);
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    int idx = str.indexOf('(');
    if (idx >= 0)
        str.replace(0, idx, Py_TYPE(self)->tp_name);
    PyObject* mod = PyDict_GetItemString(Py_TYPE(self)->tp_dict, "__module__");
    if (mod)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    else
        return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSourceLocation_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.QtXmlPatterns.QSourceLocation",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QSourceLocation__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_QSourceLocation_traverse,
    /*tp_clear*/            Sbk_QSourceLocation_clear,
    /*tp_richcompare*/      Sbk_QSourceLocation_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSourceLocation_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSourceLocation_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSourceLocation(PyObject* module)
{
    // type has number operators
    memset(&Sbk_QSourceLocation_Type.super.as_number, 0, sizeof(PyNumberMethods));
    SBK_NB_BOOL(Sbk_QSourceLocation_Type.super.as_number) = Sbk_QSourceLocation___nb_bool;
    Sbk_QSourceLocation_Type.super.ht_type.tp_as_number = &Sbk_QSourceLocation_Type.super.as_number;

    SbkPySide_QtXmlPatternsTypes[SBK_QSOURCELOCATION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSourceLocation_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(module, "QSourceLocation", "QSourceLocation",
        &Sbk_QSourceLocation_Type, &Shiboken::callCppDestructor< ::QSourceLocation >)) {
        return;
    }


    Shiboken::TypeResolver::createValueTypeResolver< ::QSourceLocation >("QSourceLocation");
    Shiboken::TypeResolver::createObjectTypeResolver< ::QSourceLocation >("QSourceLocation*");
    Shiboken::TypeResolver::createValueTypeResolver< ::QSourceLocation >(typeid(::QSourceLocation).name());
    qRegisterMetaType< ::QSourceLocation >("QSourceLocation");
}
