/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2011 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_mediasource_wrapper.h"

// Extra includes
#include <QList>
#include <QPair>
#include <abstractmediastream.h>
#include <mediasource.h>
#include <objectdescription.h>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qurl.h>

using namespace Phonon;


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Phonon_MediaSource_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Phonon::MediaSource >()))
        return -1;

    ::Phonon::MediaSource* cptr = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.phonon.MediaSource(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:MediaSource", &(pyArgs[0]), &(pyArgs[1])))
        return -1;


    // Overloaded function decisor
    // 0: MediaSource()
    // 1: MediaSource(Phonon::AbstractMediaStream*)
    // 2: MediaSource(Phonon::DiscType,QString)
    // 3: MediaSource(QIODevice*)
    // 4: MediaSource(Phonon::AudioCaptureDevice)
    // 5: MediaSource(Phonon::MediaSource)
    // 6: MediaSource(Phonon::VideoCaptureDevice)
    // 7: MediaSource(QPair<QByteArray,QString>)
    // 8: MediaSource(QString)
    // 9: MediaSource(QUrl)
    if (numArgs == 0) {
        overloadId = 0; // MediaSource()
    } else if (numArgs == 1
        && Shiboken::Converter< ::Phonon::VideoCaptureDevice >::isConvertible(pyArgs[0])) {
        overloadId = 6; // MediaSource(Phonon::VideoCaptureDevice)
    } else if (numArgs == 1
        && Shiboken::Converter< ::Phonon::AudioCaptureDevice >::isConvertible(pyArgs[0])) {
        overloadId = 4; // MediaSource(Phonon::AudioCaptureDevice)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QIODevice * >::isConvertible(pyArgs[0])) {
        overloadId = 3; // MediaSource(QIODevice*)
    } else if (Shiboken::Converter< ::Phonon::DiscType >::isConvertible(pyArgs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // MediaSource(Phonon::DiscType,QString)
        } else if (Shiboken::Converter< ::QString >::isConvertible(pyArgs[1])) {
            overloadId = 2; // MediaSource(Phonon::DiscType,QString)
        }
    } else if (numArgs == 1
        && Shiboken::Converter< ::Phonon::AbstractMediaStream * >::isConvertible(pyArgs[0])) {
        overloadId = 1; // MediaSource(Phonon::AbstractMediaStream*)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QString >::isConvertible(pyArgs[0])) {
        overloadId = 8; // MediaSource(QString)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QUrl >::isConvertible(pyArgs[0])) {
        overloadId = 9; // MediaSource(QUrl)
    } else if (numArgs == 1
        && Shiboken::Converter< ::QPair<QByteArray, QString > >::isConvertible(pyArgs[0])) {
        overloadId = 7; // MediaSource(QPair<QByteArray,QString>)
    } else if (numArgs == 1
        && Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(pyArgs[0])) {
        overloadId = 5; // MediaSource(Phonon::MediaSource)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaSource_Init_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // MediaSource()
        {

            if(!PyErr_Occurred()) {
                // MediaSource()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // MediaSource(Phonon::AbstractMediaStream*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Phonon::AbstractMediaStream * cppArg0 = Shiboken::Converter< ::Phonon::AbstractMediaStream * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // MediaSource(Phonon::AbstractMediaStream*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 2: // MediaSource(Phonon::DiscType,QString)
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "deviceName");
                if (value) {
                    if (pyArgs[1])
                        errorArgName = "deviceName";
                    else if (Shiboken::Converter< ::QString >::isConvertible(value))
                        pyArgs[1] = value;
                    else
                        goto Sbk_Phonon_MediaSource_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.phonon.MediaSource(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            Phonon::DiscType cppArg0 = Shiboken::Converter< ::Phonon::DiscType >::toCpp(pyArgs[0]);
            ::QString cppArg1 = pyArgs[1] ? Shiboken::Converter< ::QString >::toCpp(pyArgs[1]) : QString();

            if(!PyErr_Occurred()) {
                // MediaSource(Phonon::DiscType,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 3: // MediaSource(QIODevice*)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QIODevice * cppArg0 = Shiboken::Converter< ::QIODevice * >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // MediaSource(QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 4: // MediaSource(Phonon::AudioCaptureDevice)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Phonon::AudioCaptureDevice cppArg0 = Shiboken::Converter< ::Phonon::AudioCaptureDevice >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // MediaSource(Phonon::AudioCaptureDevice)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 5: // MediaSource(Phonon::MediaSource)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Phonon::MediaSource cppArg0 = Shiboken::Converter< ::Phonon::MediaSource >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // MediaSource(Phonon::MediaSource)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 6: // MediaSource(Phonon::VideoCaptureDevice)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::Phonon::VideoCaptureDevice cppArg0 = Shiboken::Converter< ::Phonon::VideoCaptureDevice >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // MediaSource(Phonon::VideoCaptureDevice)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 7: // MediaSource(QPair<QByteArray,QString>)
        {
            ::QPair<QByteArray, QString > cppArg0 = Shiboken::Converter< ::QPair<QByteArray, QString > >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // MediaSource(QPair<QByteArray,QString>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 8: // MediaSource(QString)
        {
            ::QString cppArg0 = Shiboken::Converter< ::QString >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // MediaSource(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 9: // MediaSource(QUrl)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0 = Shiboken::Converter< ::QUrl >::toCpp(pyArgs[0]);

            if(!PyErr_Occurred()) {
                // MediaSource(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new ::Phonon::MediaSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Phonon::MediaSource >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_Phonon_MediaSource_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_Phonon_MediaSource_Init_TypeError:
        const char* overloads[] = {"", "PySide.phonon.Phonon::AbstractMediaStream", "PySide.phonon.Phonon.DiscType, unicode = QString()", "PySide.QtCore.QIODevice", "PySide.phonon.Phonon::AudioCaptureDevice", "PySide.phonon.Phonon::MediaSource", "PySide.phonon.Phonon::VideoCaptureDevice", "QPair", "unicode", "PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.MediaSource", overloads);
        return -1;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_audioCaptureDevice(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // audioCaptureDevice()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Phonon::AudioCaptureDevice cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->audioCaptureDevice();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Phonon::AudioCaptureDevice >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_autoDelete(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // autoDelete()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->autoDelete();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< bool >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_deviceAccessList(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // deviceAccessList()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const QList<QPair<QByteArray, QString > > & cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->deviceAccessList();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QList<QPair<QByteArray, QString > > >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_deviceName(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // deviceName()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->deviceName();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_discType(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // discType()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Phonon::DiscType cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->discType();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Phonon::DiscType >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_fileName(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // fileName()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->fileName();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QString >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_setAutoDelete(PyObject* self, PyObject* pyArg)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoDelete(bool)
    if (SbkNumber_Check(pyArg)) {
        overloadId = 0; // setAutoDelete(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaSourceFunc_setAutoDelete_TypeError;

    // Call function/method
    {
        bool cppArg0 = Shiboken::Converter< bool >::toCpp(pyArg);

        if(!PyErr_Occurred()) {
            // setAutoDelete(bool)
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            cppSelf->setAutoDelete(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaSourceFunc_setAutoDelete_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(pyArg, "PySide.phonon.MediaSource.setAutoDelete", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_stream(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // stream()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Phonon::AbstractMediaStream * cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->stream();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Phonon::AbstractMediaStream * >::toPython(cppResult);
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_type(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // type()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Phonon::MediaSource::Type cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->type();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Phonon::MediaSource::Type >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_url(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // url()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUrl cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->url();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSourceFunc_videoCaptureDevice(PyObject* self)
{
    ::Phonon::MediaSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self);
    PyObject* pyResult = 0;

    // Call function/method
    {

        if(!PyErr_Occurred()) {
            // videoCaptureDevice()const
            PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            Phonon::VideoCaptureDevice cppResult = const_cast<const ::Phonon::MediaSource*>(cppSelf)->videoCaptureDevice();
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Converter< ::Phonon::VideoCaptureDevice >::toPython(cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaSource___copy__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::Phonon::MediaSource& cppSelf = *(Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self));
    PyObject* pyResult = Shiboken::Converter< ::Phonon::MediaSource >::toPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_Phonon_MediaSource_methods[] = {
    {"audioCaptureDevice", (PyCFunction)Sbk_Phonon_MediaSourceFunc_audioCaptureDevice, METH_NOARGS},
    {"autoDelete", (PyCFunction)Sbk_Phonon_MediaSourceFunc_autoDelete, METH_NOARGS},
    {"deviceAccessList", (PyCFunction)Sbk_Phonon_MediaSourceFunc_deviceAccessList, METH_NOARGS},
    {"deviceName", (PyCFunction)Sbk_Phonon_MediaSourceFunc_deviceName, METH_NOARGS},
    {"discType", (PyCFunction)Sbk_Phonon_MediaSourceFunc_discType, METH_NOARGS},
    {"fileName", (PyCFunction)Sbk_Phonon_MediaSourceFunc_fileName, METH_NOARGS},
    {"setAutoDelete", (PyCFunction)Sbk_Phonon_MediaSourceFunc_setAutoDelete, METH_O},
    {"stream", (PyCFunction)Sbk_Phonon_MediaSourceFunc_stream, METH_NOARGS},
    {"type", (PyCFunction)Sbk_Phonon_MediaSourceFunc_type, METH_NOARGS},
    {"url", (PyCFunction)Sbk_Phonon_MediaSourceFunc_url, METH_NOARGS},
    {"videoCaptureDevice", (PyCFunction)Sbk_Phonon_MediaSourceFunc_videoCaptureDevice, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_Phonon_MediaSource___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_Phonon_MediaSource_richcompare(PyObject* self, PyObject* pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    ::Phonon::MediaSource& cppSelf = *(Shiboken::Converter< ::Phonon::MediaSource* >::toCpp(self));
    SBK_UNUSED(cppSelf)
    PyObject* pyResult = 0;

    switch (op) {
        case Py_EQ:
            if (Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(pyArg)) {
                // operator==(const Phonon::MediaSource & rhs) const
                if (!Shiboken::Object::isValid(pyArg))
                    return 0;
                ::Phonon::MediaSource cppArg0 = Shiboken::Converter< ::Phonon::MediaSource >::toCpp(pyArg);
                bool cppResult = cppSelf == cppArg0;
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_Phonon_MediaSource_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_Phonon_MediaSource_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static int Sbk_Phonon_MediaSource_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_traverse(self, visit, arg);
}
static int Sbk_Phonon_MediaSource_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject*>(&SbkObject_Type)->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_MediaSource_Type = { { {
    PyVarObject_HEAD_INIT(&SbkObjectType_Type, 0)
    /*tp_name*/             "PySide.phonon.Phonon.MediaSource",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    /*tp_doc*/              0,
    /*tp_traverse*/         Sbk_Phonon_MediaSource_traverse,
    /*tp_clear*/            Sbk_Phonon_MediaSource_clear,
    /*tp_richcompare*/      Sbk_Phonon_MediaSource_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_MediaSource_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_Phonon_MediaSource_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_Phonon_MediaSource(PyObject* enclosingClass)
{
    SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_MediaSource_Type);

    if (!Shiboken::ObjectType::introduceWrapperType(enclosingClass, "MediaSource", "Phonon::MediaSource",
        &Sbk_Phonon_MediaSource_Type, &Shiboken::callCppDestructor< ::Phonon::MediaSource >, 0, 0, true)) {
        return;
    }

    // Initialization of enums.

    // Initialization of enum 'Type'.
    SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX] = Shiboken::Enum::createScopedEnum(&Sbk_Phonon_MediaSource_Type,
        "Type",
        "PySide.phonon.Phonon.MediaSource.Type",
        "Phonon::MediaSource::Type");
    if (!SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX])
        return ;

    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX],
        &Sbk_Phonon_MediaSource_Type, "Invalid", (long) Phonon::MediaSource::Invalid))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX],
        &Sbk_Phonon_MediaSource_Type, "LocalFile", (long) Phonon::MediaSource::LocalFile))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX],
        &Sbk_Phonon_MediaSource_Type, "Url", (long) Phonon::MediaSource::Url))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX],
        &Sbk_Phonon_MediaSource_Type, "Disc", (long) Phonon::MediaSource::Disc))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX],
        &Sbk_Phonon_MediaSource_Type, "Stream", (long) Phonon::MediaSource::Stream))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX],
        &Sbk_Phonon_MediaSource_Type, "CaptureDevice", (long) Phonon::MediaSource::CaptureDevice))
        return ;
    if (!Shiboken::Enum::createScopedEnumItem(SbkPySide_phononTypes[SBK_PHONON_MEDIASOURCE_TYPE_IDX],
        &Sbk_Phonon_MediaSource_Type, "Empty", (long) Phonon::MediaSource::Empty))
        return ;
    // End of 'Type' enum.


    Shiboken::TypeResolver::createValueTypeResolver< ::Phonon::MediaSource >("Phonon::MediaSource");
    Shiboken::TypeResolver::createObjectTypeResolver< ::Phonon::MediaSource >("Phonon::MediaSource*");
    Shiboken::TypeResolver::createValueTypeResolver< ::Phonon::MediaSource >(typeid(::Phonon::MediaSource).name());
    qRegisterMetaType< ::Phonon::MediaSource >("MediaSource");
    qRegisterMetaType< ::Phonon::MediaSource >("Phonon::MediaSource");
    qRegisterMetaType< ::Phonon::MediaSource::Type >("MediaSource::Type");
    qRegisterMetaType< ::Phonon::MediaSource::Type >("Phonon::MediaSource::Type");
}
